// This file is automatically generated. Do not modify it.

#include "server/i18n_utils.h"

namespace kiwix {
namespace i18n {

namespace
{


const I18nString string_table_for_ar[] = {
  { u8"400-page-heading", u8"\u0637\u0644\u0628 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d" },
  { u8"400-page-title", u8"\u0637\u0644\u0628 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d" },
  { u8"404-page-heading", u8"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u064a\u0647" },
  { u8"404-page-title", u8"\u0627\u0644\u0645\u062d\u062a\u0648\u0649 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f" },
  { u8"500-page-heading", u8"\u0639\u0641\u0648\u0627\u064b\u060c \u0627\u0644\u0635\u0641\u062d\u0629 \u0644\u0627 \u062a\u0639\u0645\u0644." },
  { u8"500-page-text", u8"\u0644\u0627 \u064a\u0645\u0643\u0646 \u0625\u0631\u0633\u0627\u0644 \u0627\u0644\u0645\u0633\u0627\u0631 \u0627\u0644\u0645\u0637\u0644\u0648\u0628 \u0628\u0634\u0643\u0644 \u0635\u062d\u064a\u062d:" },
  { u8"500-page-title", u8"\u062e\u0637\u0623 \u062f\u0627\u062e\u0644\u064a \u0628\u0627\u0644\u062e\u0627\u062f\u0645" },
  { u8"book-category.other", u8"\u0623\u062e\u0631\u0649 {\u0643\u062a\u0628 \u0623\u062e\u0631\u064a}" },
  { u8"book-category.wikibooks", u8"\u0648\u064a\u0643\u064a \u0627\u0644\u0643\u062a\u0628" },
  { u8"book-category.wikinews", u8"\u0648\u064a\u0643\u064a \u0627\u0644\u0623\u062e\u0628\u0627\u0631" },
  { u8"book-category.wikipedia", u8"\u0648\u064a\u0643\u064a\u0628\u064a\u062f\u064a\u0627" },
  { u8"book-category.wikiquote", u8"\u0648\u064a\u0643\u064a \u0627\u0644\u0625\u0642\u062a\u0628\u0627\u0633" },
  { u8"book-category.wikisource", u8"\u0648\u064a\u0643\u064a \u0645\u0635\u062f\u0631" },
  { u8"book-category.wikispecies", u8"\u0648\u064a\u0643\u064a \u0623\u0646\u0648\u0627\u0639" },
  { u8"book-category.wikiversity", u8"\u0648\u064a\u0643\u064a \u0627\u0644\u062c\u0627\u0645\u0639\u0629" },
  { u8"book-category.wikivoyage", u8"\u0648\u064a\u0643\u064a \u0627\u0644\u0631\u062d\u0644\u0627\u062a" },
  { u8"book-category.wiktionary", u8"\u0648\u064a\u0643\u064a \u0627\u0644\u0642\u0627\u0645\u0648\u0633" },
  { u8"confusion-of-tongues", u8"\u0642\u062f \u064a\u0634\u0627\u0631\u0643 \u0641\u064a \u0627\u0644\u0628\u062d\u062b \u0643\u062a\u0627\u0628\u0627\u0646 \u0623\u0648 \u0623\u0643\u062b\u0631 \u0628\u0644\u063a\u0627\u062a \u0645\u062e\u062a\u0644\u0641\u0629\u060c \u0645\u0645\u0627 \u0642\u062f \u064a\u0624\u062f\u064a \u0625\u0644\u0649 \u0646\u062a\u0627\u0626\u062c \u0645\u062d\u064a\u0631\u0629." },
  { u8"direct-download-alt-text", u8"\u0627\u0644\u062a\u0646\u0632\u064a\u0644 \u0645\u0628\u0627\u0634\u0631\u0629 \u0639\u0628\u0631 \u0628\u0631\u0648\u062a\u0648\u0643\u0648\u0644 HTTP(S)" },
  { u8"fulltext-search-unavailable", u8"\u0627\u0644\u0628\u062d\u062b \u0641\u064a \u0643\u0627\u0645\u0644 \u0627\u0644\u0646\u0635 \u063a\u064a\u0631 \u0645\u062a\u0627\u062d" },
  { u8"hash-download-alt-text", u8"\u0639\u0631\u0636 \u0627\u0644\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0625\u062e\u062a\u0628\u0627\u0631\u064a \u0644\u062e\u0648\u0627\u0631\u0632\u0645\u064a\u0629 SHA-256 \u0644\u0644\u0645\u0644\u0641" },
  { u8"hash-download-link-text", u8"\u0627\u0644\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0625\u062e\u062a\u0628\u0627\u0631\u064a \u0644\u062e\u0648\u0627\u0631\u0632\u0645\u064a\u0629 SHA-256" },
  { u8"home-button-text", u8"\u0627\u0646\u062a\u0642\u0644 \u0625\u0644\u0649 \u0627\u0644\u0635\u0641\u062d\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u0629 \u0644\u0640 '{{{BOOK_TITLE}}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u0644\u064a\u0633 \u0637\u0644\u0628\u064b\u0627 \u0635\u0627\u0644\u062d\u064b\u0627 \u0644\u0644\u0645\u062d\u062a\u0648\u0649 \u0627\u0644\u0623\u0648\u0644\u064a." },
  { u8"library-button-text", u8"\u062a\u0648\u062c\u0647 \u0625\u0644\u064a \u0635\u0641\u062d\u0629 \u0627\u0644\u062a\u0631\u062d\u064a\u0628" },
  { u8"magnet-alt-text", u8"\u0627\u0644\u062a\u0646\u0632\u064a\u0644 \u0628\u0648\u0627\u0633\u0637\u0629 \u0627\u0644\u0631\u0627\u0628\u0637 \u0627\u0644\u062c\u0627\u0630\u0628" },
  { u8"magnet-link-text", u8"\u0631\u0627\u0628\u0637 \u062c\u0627\u0630\u0628" },
  { u8"name", u8"\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629" },
  { u8"no-book-found", u8"\u0644\u0627 \u064a\u0648\u062c\u062f \u0643\u062a\u0627\u0628 \u064a\u0637\u0627\u0628\u0642 \u0645\u0639\u0627\u064a\u064a\u0631 \u0627\u0644\u0627\u062e\u062a\u064a\u0627\u0631" },
  { u8"no-query", u8"\u0644\u0645 \u064a\u062a\u0645 \u062a\u0642\u062f\u064a\u0645 \u0645\u0644\u062e\u0635." },
  { u8"no-search-results", u8"\u0645\u062d\u0631\u0643 \u0627\u0644\u0628\u062d\u062b \u0641\u064a \u0643\u0627\u0645\u0644 \u0627\u0644\u0646\u0635 \u063a\u064a\u0631 \u0645\u062a\u0648\u0641\u0631 \u0644\u0647\u0630\u0627 \u0627\u0644\u0645\u062d\u062a\u0648\u064a." },
  { u8"no-such-book", u8"\u0644\u0627 \u064a\u0648\u062c\u062f \u0645\u062b\u0644 \u0647\u0630\u0627 \u0627\u0644\u0643\u062a\u0627\u0628: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u0644\u0645 \u064a\u062a\u0645 \u062a\u0642\u062f\u064a\u0645 \u0642\u064a\u0645\u0629 \u0644\u0644\u0648\u0633\u064a\u0637\u0629 {{ARGUMENT}}" },
  { u8"random-article-failure", u8"\u0644\u0644\u0623\u0633\u0641 ! \u0641\u0634\u0644 \u0641\u064a \u0627\u062e\u062a\u064a\u0627\u0631 \u0645\u0642\u0627\u0644 \u0639\u0634\u0648\u0627\u0626\u064a  :(" },
  { u8"random-page-button-text", u8"\u0627\u0630\u0647\u0628 \u0625\u0644\u0649 \u0635\u0641\u062d\u0629 \u0639\u0634\u0648\u0627\u0626\u064a\u0629" },
  { u8"raw-entry-not-found", u8"\u0644\u0627 \u064a\u0645\u0643\u0646 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0625\u062f\u062e\u0627\u0644 {{DATATYPE}} {{ENTRY}}" },
  { u8"searchbox-tooltip", u8"\u0627\u0628\u062d\u062b \u0639\u0646 '{{{BOOK_TITLE}}}'" },
  { u8"suggest-search", u8"\u0642\u0645 \u0628\u0625\u062c\u0631\u0627\u0621 \u0628\u062d\u062b \u0639\u0646 \u0627\u0644\u0646\u0635 \u0627\u0644\u0643\u0627\u0645\u0644 \u0644\u0640 <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"\u0637\u0644\u0628 \u0627\u0644\u0639\u062f\u064a\u062f \u0645\u0646 \u0627\u0644\u0643\u062a\u0628 {{NB_BOOKS}} \u062d\u064a\u062b \u0627\u0644\u062d\u062f {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"\u0627\u0644\u062a\u0646\u0632\u064a\u0644 \u0628\u0648\u0627\u0633\u0637\u0629 \u0628\u062a \u062a\u0648\u0631\u0646\u062a" },
  { u8"torrent-download-link-text", u8"\u0628\u062a \u062a\u0648\u0631\u0646\u062a" },
  { u8"unknown-error", u8"\u062e\u0637\u0623 \u063a\u064a\u0631 \u0645\u0639\u0631\u0648\u0641" },
  { u8"url-not-found", u8"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0639\u0646\u0648\u0627\u0646 URL \u0627\u0644\u0645\u0637\u0644\u0648\u0628 \"{{url}}\" \u0639\u0644\u0649 \u0647\u0630\u0627 \u0627\u0644\u062e\u0627\u062f\u0645." }
};


const I18nString string_table_for_bn[] = {
  { u8"404-advice.p1", u8"\u0986\u09aa\u09a8\u09bf \u09af\u09c7 \u09ac\u09bf\u09b7\u09af\u09bc\u09ac\u09b8\u09cd\u09a4\u09c1 \u0996\u09c1\u0981\u099c\u099b\u09c7\u09a8 \u09a4\u09be \u098f\u0996\u09a8\u0993 \u0989\u09aa\u09b2\u09ac\u09cd\u09a7 \u09a5\u09be\u0995\u09a4\u09c7 \u09aa\u09be\u09b0\u09c7, \u09a4\u09ac\u09c7 \u098f\u099f\u09bf \u099c\u09bf\u09ae \u09ab\u09be\u0987\u09b2\u09c7\u09b0 \u09ae\u09a7\u09cd\u09af\u09c7 \u0985\u09a8\u09cd\u09af \u0995\u09cb\u09a8\u0993 \u099c\u09be\u09af\u09bc\u0997\u09be\u09af\u09bc \u0985\u09ac\u09b8\u09cd\u09a5\u09bf\u09a4 \u09b9\u09a4\u09c7 \u09aa\u09be\u09b0\u09c7\u0964" },
  { u8"404-advice.p4", u8"\u0986\u09aa\u09a8\u09bf \u09af\u09c7 \u09a4\u09a5\u09cd\u09af \u0996\u09c1\u0981\u099c\u099b\u09c7\u09a8 \u09a4\u09be\u09b0 \u09b8\u09be\u09a5\u09c7 \u09b8\u09ae\u09cd\u09aa\u09b0\u09cd\u0995\u09bf\u09a4 \u0995\u09c0\u0993\u09af\u09bc\u09be\u09b0\u09cd\u09a1 \u09ac\u09be \u09b6\u09bf\u09b0\u09cb\u09a8\u09be\u09ae \u0996\u09c1\u0981\u099c\u09c1\u09a8\u0964" },
  { u8"404-img-text", u8"\u09aa\u09be\u0993\u09af\u09bc\u09be \u09af\u09be\u09af\u09bc\u09a8\u09bf!" },
  { u8"404-page-heading", u8"\u09aa\u09be\u0993\u09af\u09bc\u09be \u09af\u09be\u09af\u09bc\u09a8\u09bf" },
  { u8"500-page-heading", u8"\u0985\u09ad\u09cd\u09af\u09a8\u09cd\u09a4\u09b0\u09c0\u09a3 \u09b8\u09be\u09b0\u09cd\u09ad\u09be\u09b0 \u09a4\u09cd\u09b0\u09c1\u099f\u09bf" },
  { u8"500-page-title", u8"\u0985\u09ad\u09cd\u09af\u09a8\u09cd\u09a4\u09b0\u09c0\u09a3 \u09b8\u09be\u09b0\u09cd\u09ad\u09be\u09b0 \u09a4\u09cd\u09b0\u09c1\u099f\u09bf" },
  { u8"book-category.other", u8"\u0985\u09a8\u09cd\u09af\u09be\u09a8\u09cd\u09af" },
  { u8"book-category.wikibooks", u8"\u0989\u0987\u0995\u09bf\u09ac\u0987" },
  { u8"book-category.wikinews", u8"\u0989\u0987\u0995\u09bf\u09b8\u0982\u09ac\u09be\u09a6" },
  { u8"book-category.wikipedia", u8"\u0989\u0987\u0995\u09bf\u09aa\u09bf\u09a1\u09bf\u09af\u09bc\u09be" },
  { u8"book-category.wikiquote", u8"\u0989\u0987\u0995\u09bf\u0989\u0995\u09cd\u09a4\u09bf" },
  { u8"book-category.wikisource", u8"\u0989\u0987\u0995\u09bf\u09b8\u0982\u0995\u09b2\u09a8" },
  { u8"book-category.wikispecies", u8"\u0989\u0987\u0995\u09bf\u09aa\u09cd\u09b0\u099c\u09be\u09a4\u09bf" },
  { u8"book-category.wikiversity", u8"\u0989\u0987\u0995\u09bf\u09ac\u09bf\u09b6\u09cd\u09ac\u09ac\u09bf\u09a6\u09cd\u09af\u09be\u09b2\u09af\u09bc" },
  { u8"book-category.wikivoyage", u8"\u0989\u0987\u0995\u09bf\u09ad\u09cd\u09b0\u09ae\u09a3" },
  { u8"book-category.wiktionary", u8"\u0989\u0987\u0995\u09bf\u0985\u09ad\u09bf\u09a7\u09be\u09a8" },
  { u8"download-links-title", u8"\u09ac\u0987 \u09a1\u09be\u0989\u09a8\u09b2\u09cb\u09a1 \u0995\u09b0\u09c1\u09a8" },
  { u8"external-link-advice.p1", u8"\u0986\u09aa\u09a8\u09bf \u09af\u09c7 \u09b2\u09bf\u0999\u09cd\u0995\u099f\u09bf\u09a4\u09c7 \u09aa\u09cd\u09b0\u09ac\u09c7\u09b6 \u0995\u09b0\u09be\u09b0 \u099a\u09c7\u09b7\u09cd\u099f\u09be \u0995\u09b0\u099b\u09c7\u09a8 \u09a4\u09be \u0986\u09aa\u09a8\u09be\u09b0 \u0985\u09ab\u09b2\u09be\u0987\u09a8 \u09aa\u09cd\u09af\u09be\u0995\u09c7\u099c\u09c7\u09b0 \u0985\u0982\u09b6 \u09a8\u09af\u09bc \u098f\u09ac\u0982 \u098f\u09b0 \u099c\u09a8\u09cd\u09af \u0987\u09a8\u09cd\u099f\u09be\u09b0\u09a8\u09c7\u099f \u09b8\u0982\u09af\u09cb\u0997 \u09aa\u09cd\u09b0\u09af\u09bc\u09cb\u099c\u09a8\u0964" },
  { u8"external-link-advice.p2", u8"\u0986\u09aa\u09a8\u09bf \u09af\u09a6\u09bf \u0985\u09a8\u09b2\u09be\u0987\u09a8\u09c7 \u09af\u09c7\u09a4\u09c7 \u09aa\u09be\u09b0\u09c7\u09a8, \u09a4\u09be\u09b9\u09b2\u09c7 \u09b2\u09bf\u0999\u09cd\u0995\u099f\u09bf \u0996\u09cb\u09b2\u09be\u09b0 \u099a\u09c7\u09b7\u09cd\u099f\u09be \u0995\u09b0\u09a4\u09c7 \u09aa\u09be\u09b0\u09c7\u09a8\u0964" },
  { u8"external-link-advice.p3", u8"\u0985\u09a8\u09cd\u09af\u09a5\u09be\u09af\u09bc, \u0986\u09aa\u09a8\u09bf \u0986\u09aa\u09a8\u09be\u09b0 \u09ac\u09cd\u09b0\u09be\u0989\u099c\u09be\u09b0\u09c7\u09b0 \u09aa\u09bf\u099b\u09a8 \u09ac\u09cb\u09a4\u09be\u09ae \u09ac\u09cd\u09af\u09ac\u09b9\u09be\u09b0 \u0995\u09b0\u09c7 \u0986\u09aa\u09a8\u09be\u09b0 ZIM-\u098f\u09b0 \u0985\u09ab\u09b2\u09be\u0987\u09a8 \u09ac\u09bf\u09b7\u09af\u09bc\u09ac\u09b8\u09cd\u09a4\u09c1\u09a4\u09c7 \u09ab\u09bf\u09b0\u09c7 \u09af\u09c7\u09a4\u09c7 \u09aa\u09be\u09b0\u09c7\u09a8\u0964" },
  { u8"external-link-intro", u8"\u0986\u09aa\u09a8\u09bf \u0985\u09a8\u09b2\u09be\u0987\u09a8\u09c7 \u09af\u09be\u0993\u09af\u09bc\u09be\u09b0 \u099c\u09a8\u09cd\u09af \u0995\u09bf\u0989\u0987\u0995\u09cd\u09b8\u09c7\u09b0 \u099c\u09bf\u09ae \u09b0\u09bf\u09a1\u09be\u09b0 \u099b\u09c7\u09a1\u09bc\u09c7 \u09a6\u09bf\u09a4\u09c7 \u099a\u09b2\u09c7\u099b\u09c7\u09a8" },
  { u8"home-button-text", u8"'{{BOOK_TITLE}}'-\u098f\u09b0 \u09aa\u09cd\u09b0\u09a7\u09be\u09a8 \u09aa\u09be\u09a4\u09be\u09af\u09bc \u099a\u09b2\u09c1\u09a8" },
  { u8"library-button-text", u8"\u09b8\u09cd\u09ac\u09be\u0997\u09a4 \u09aa\u09be\u09a4\u09be\u09af\u09bc \u099a\u09b2\u09c1\u09a8" },
  { u8"name", u8"\u09ac\u09be\u0982\u09b2\u09be" },
  { u8"new-404-page-heading", u8"\u0993\u09b9! \u09aa\u09be\u09a4\u09be \u0996\u09c1\u0981\u099c\u09c7 \u09aa\u09be\u0993\u09af\u09bc\u09be \u09af\u09be\u09af\u09bc\u09a8\u09bf" },
  { u8"new-404-page-title", u8"\u09aa\u09be\u09a4\u09be \u09aa\u09be\u0993\u09af\u09bc\u09be \u09af\u09be\u09af\u09bc\u09a8\u09bf" },
  { u8"path-was-not-found", u8"\u0985\u09a8\u09c1\u09b0\u09cb\u09a7 \u0995\u09b0\u09be \u09aa\u09a5\u099f\u09bf \u09aa\u09be\u0993\u09af\u09bc\u09be \u09af\u09be\u09af\u09bc\u09a8\u09bf:" },
  { u8"preview-book", u8"\u09aa\u09cd\u09b0\u09be\u0995\u09a6\u09b0\u09cd\u09b6\u09a8" },
  { u8"search", u8"\u0985\u09a8\u09c1\u09b8\u09a8\u09cd\u09a7\u09be\u09a8" },
  { u8"search-result-book-info", u8"{{BOOK_TITLE}} \u09a5\u09c7\u0995\u09c7" },
  { u8"searchbox-tooltip", u8"'{{BOOK_TITLE}}' \u0985\u09a8\u09c1\u09b8\u09a8\u09cd\u09a7\u09be\u09a8 \u0995\u09b0\u09c1\u09a8" },
  { u8"welcome-to-kiwix-server", u8"\u0995\u09bf\u0989\u0987\u0995\u09cd\u09b8 \u09b8\u09be\u09b0\u09cd\u09ad\u09be\u09b0\u09c7 \u09b8\u09cd\u09ac\u09be\u0997\u09a4\u09ae" },
  { u8"word-count", u8"{{COUNT}}\u099f\u09bf \u09b6\u09ac\u09cd\u09a6" }
};


const I18nString string_table_for_br[] = {
  { u8"400-page-heading", u8"Reked amwiriek" },
  { u8"400-page-title", u8"Reked amwiriek" },
  { u8"404-page-heading", u8"N'eo ket bet kavet" },
  { u8"500-page-heading", u8"Fazi diabarzh ar servijer" },
  { u8"500-page-title", u8"Fazi diabarzh ar servijer" },
  { u8"book-filtering-all-categories", u8"An holl rummado\u00f9" },
  { u8"book-filtering-all-languages", u8"An holl yezho\u00f9" },
  { u8"count-of-matching-books", u8"{{COUNT}} levr" },
  { u8"direct-download-link-text", u8"Eeun" },
  { u8"download", u8"Pellgarga\u00f1" },
  { u8"download-links-heading", u8"Liammo\u00f9 pellgarga\u00f1 evit <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Pellgarga\u00f1 al levr" },
  { u8"empty-search-results-page-header", u8"Disoc\u2019h ebet kavet evit <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"filter-by-tag", u8"Sila\u00f1 gant an dikedenn \"{{TAG}}\"" },
  { u8"home-button-text", u8"Mont da bajenn degemer \"{{BOOK_TITLE}}\"" },
  { u8"library-button-text", u8"Mont d\u2019ar bajenn degemer" },
  { u8"name", u8"brezhoneg" },
  { u8"no-book-found", u8"N\u2019eus levr ebet a glot gant an dezverko\u00f9-se" },
  { u8"no-such-book", u8"N\u2019eus ket eus al levr-ma\u00f1: {{BOOK_NAME}}" },
  { u8"powered-by-kiwix-html", u8"Lusket gant&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Rakwelet" },
  { u8"random-article-failure", u8"Chaous! N\u2019hon eus ket gellet dibab ur pennad dre ziouer evidoc\u2019h :(" },
  { u8"random-page-button-text", u8"Mont d\u2019ur bajenn dre zegouezh" },
  { u8"search", u8"Klask" },
  { u8"search-result-book-info", u8"diouzh {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Disoc\u2019ho\u00f9 <b>{{START}}-{{END}}</b> diwar <b>{{COUNT}}</b> evit <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Klask: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Klask '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Paouez da sila\u00f1 gant an dikedenn \"{{TAG}}\"" },
  { u8"suggest-full-text-search", u8"E lec'h ema\u00f1 \"{{{SEARCH_TERMS}}}\"..." },
  { u8"unknown-error", u8"Fazi dianav" },
  { u8"url-not-found", u8"N\u2019eo ket bet kavet an URL \"{{url}}\" goulennet war ar servijer-ma\u00f1." },
  { u8"welcome-to-kiwix-server", u8"Degemer mat er servijer Kiwix" },
  { u8"word-count", u8"{{COUNT}} a c\u2019herio\u00f9" }
};


const I18nString string_table_for_cs[] = {
  { u8"400-page-heading", u8"Neplatn\u00fd po\u017eadavek" },
  { u8"400-page-title", u8"Neplatn\u00fd po\u017eadavek" },
  { u8"404-page-heading", u8"Nenalezeno" },
  { u8"404-page-title", u8"Obsah nenalezen" },
  { u8"500-page-heading", u8"Intern\u00ed chyba serveru" },
  { u8"500-page-title", u8"Intern\u00ed chyba serveru" },
  { u8"fulltext-search-unavailable", u8"Fulltextov\u00e9 vyhled\u00e1v\u00e1n\u00ed nen\u00ed k dispozici" },
  { u8"home-button-text", u8"P\u0159ej\u00edt na hlavn\u00ed str\u00e1nku '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} nen\u00ed platn\u00fd po\u017eadavek na nezpracovan\u00fd obsah." },
  { u8"library-button-text", u8"P\u0159ej\u00edt na uv\u00edtac\u00ed str\u00e1nku" },
  { u8"name", u8"\u010ce\u0161tina" },
  { u8"no-book-found", u8"V\u00fdb\u011brov\u00fdm krit\u00e9ri\u00edm nevyhovuje \u017e\u00e1dn\u00e1 kniha" },
  { u8"no-query", u8"Nebyl poskytnut \u017e\u00e1dn\u00fd dotaz." },
  { u8"no-search-results", u8"Fulltextov\u00fd vyhled\u00e1va\u010d nen\u00ed pro tento obsah dostupn\u00fd." },
  { u8"no-such-book", u8"\u017d\u00e1dn\u00e1 takov\u00e1 kniha: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Pro argument {{ARGUMENT}} nebyla zad\u00e1na \u017e\u00e1dn\u00e1 hodnota" },
  { u8"random-article-failure", u8"Jejda! Nepoda\u0159ilo se vybrat n\u00e1hodn\u00fd \u010dl\u00e1nek :(" },
  { u8"random-page-button-text", u8"P\u0159ej\u00edt na n\u00e1hodn\u011b vybranou str\u00e1nku" },
  { u8"raw-entry-not-found", u8"Nelze naj\u00edt polo\u017eku {{DATATYPE}} {{ENTRY}}" },
  { u8"searchbox-tooltip", u8"Hledat '{{BOOK_TITLE}}'" },
  { u8"suggest-full-text-search", u8"obsahuj\u00edc\u00ed '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Prove\u010fte fulltextov\u00e9 vyhled\u00e1v\u00e1n\u00ed <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Bylo po\u017eadov\u00e1no p\u0159\u00edli\u0161 mnoho knih ({{NB_BOOKS}}), kde je limit {{LIMIT}}" },
  { u8"url-not-found", u8"Po\u017eadovan\u00e1 adresa URL \"{{url}}\" nebyla na tomto serveru nalezena." }
};


const I18nString string_table_for_dag[] = {
  { u8"400-page-heading", u8"Suhigu din bi ni\u014b vi\u025bny\u025bla" },
  { u8"400-page-title", u8"Suhigu din bi ni\u014b vi\u025bny\u025bla" },
  { u8"404-page-heading", u8"Kani" },
  { u8"404-page-title", u8"Lahabali kani" },
  { u8"500-page-heading", u8"Puuni tum tumda chiri\u014b" },
  { u8"500-page-text", u8"Puuni tum tumda chiri\u014b ni\u014bya. Ti ni\u014b yolitem za\u014b j\u025bndi li :/" },
  { u8"500-page-title", u8"Puuni tum tumda chiri\u014b" },
  { u8"book-filtering-all-categories", u8"Pubu zaa" },
  { u8"book-filtering-all-languages", u8"Bala zaa" },
  { u8"confusion-of-tongues", u8"Buku nima ayi bee gari balli ko\u014bkoba ny\u025b din y\u025bn be vihigu \u014b\u0254 ni ka di ni tooi ch\u025b ka di laasabu wali." },
  { u8"count-of-matching-books", u8"{{COUNT}} Buku(nima)" },
  { u8"direct-download-alt-text", u8"Tibi deebu" },
  { u8"direct-download-link-text", u8"Tibi" },
  { u8"download", u8"Deebu" },
  { u8"download-links-heading", u8"Deemi soli za\u014b n-ti <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Deemi buku" },
  { u8"empty-search-results-page-header", u8"Cha\u0263ili daa kani za\u014b n-ti\n <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"fulltext-search-unavailable", u8"Lahabali pali vihigu kani" },
  { u8"hash-download-alt-text", u8"Deebu dali\u014b" },
  { u8"hash-download-link-text", u8"Sha256 hash" },
  { u8"home-button-text", u8"Cham ya\u0263ili ma\u014bma\u014b za\u014b n-ti\n'{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} ny\u025bla din suhibu bi ni\u014b vi\u025bny\u025bla za\u014b n-ti lahabali kahili." },
  { u8"invalid-request", u8"URL \"{{{url}}}\" sh\u025bli b\u025b ni daa suhi \u014b\u0254 ny\u025bla din bi suhi vi\u025bny\u025bla." },
  { u8"library-button-text", u8"Cham sol\u0254\u0263u" },
  { u8"name", u8"Silimiinsili" },
  { u8"no-book-found", u8"Buku kani lu zahim a ni piigi ya\u0263a sh\u025bli" },
  { u8"no-query", u8"Y\u025blsh\u025bli bi yiina" },
  { u8"no-such-book", u8"Lala buku kani:{{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Dariza sh\u025bli bi ti za\u014b n-ti nangban'kpeeni {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Din ni\u014b li ny\u025b &nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Da\u014byuli" },
  { u8"random-article-failure", u8"Oops! Za\u0263isiya ni di gahim piigi lahabali :(" },
  { u8"random-page-button-text", u8"Cham gahim piigi ya\u0263ili" },
  { u8"raw-entry-not-found", u8"Ku tooi nya {{DATATYPE}} kp\u025bbu {{ENTRY}}" },
  { u8"search", u8"Vihima" },
  { u8"search-result-book-info", u8"yina {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Cha\u0263ili nima <b>{{START}}-{{END}}</b> of <b>{{COUNT}}</b> for <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Vihima:{{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Vihima '{{BOOK_TITLE}}'" },
  { u8"suggest-full-text-search", u8"Gbubi la '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Ni\u014bmi lahabali pali vihigu za\u014b n-ti <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Buku nima pam ka b\u025b daa suhi ({{NB_BOOKS}}) din ni ka tariga ny\u025b {{LIMIT}}" },
  { u8"unknown-error", u8"Chiri\u014b din bi tooi ba\u014b" },
  { u8"url-not-found", u8"URL \"{{url}}\" sh\u025bli b\u025b ni daa suhi daa kani n-ti tum tumda \u014b\u0254." },
  { u8"welcome-page-overzealous-filter", u8"Labisibu kani. A ni yu ni a\n<a href=\"{{URL}}\">reset filter</a>?" },
  { u8"welcome-to-kiwix-server", u8"Maraba Kiwix tum tumda" },
  { u8"word-count", u8"{{COUNT}} bachi nima" }
};


const I18nString string_table_for_de[] = {
  { u8"400-page-heading", u8"Ung\u00fcltige Anfrage" },
  { u8"400-page-title", u8"Ung\u00fcltige Anfrage" },
  { u8"404-page-heading", u8"Nicht gefunden" },
  { u8"404-page-title", u8"Inhalt nicht gefunden" },
  { u8"500-page-heading", u8"Interner Server-Fehler" },
  { u8"500-page-text", u8"Es ist ein interner Serverfehler aufgetreten. Das tut uns leid :/" },
  { u8"500-page-title", u8"Interner Server-Fehler" },
  { u8"book-category.other", u8"Andere" },
  { u8"book-category.wikibooks", u8"Wikibooks" },
  { u8"book-category.wikinews", u8"Wikinews" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversity" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wiktionary" },
  { u8"book-filtering-all-categories", u8"Alle Kategorien" },
  { u8"book-filtering-all-languages", u8"Alle Sprachen" },
  { u8"confusion-of-tongues", u8"Zwei oder mehr B\u00fccher unterschiedlicher Sprachen werden durchsucht, was zu un\u00fcbersichtlichen Ergebnissen f\u00fchren kann." },
  { u8"count-of-matching-books", u8"{{COUNT}} B\u00fccher" },
  { u8"direct-download-alt-text", u8"Direktes Herunterladen \u00fcber HTTP(S)" },
  { u8"direct-download-link-text", u8"Direkt" },
  { u8"download", u8"Herunterladen" },
  { u8"download-links-heading", u8"Download Links f\u00fcr <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Buch herunterladen" },
  { u8"empty-search-results-page-header", u8"F\u00fcr <b>\u201e{{{SEARCH_PATTERN}}}\u201c</b> wurden keine Ergebnisse gefunden." },
  { u8"filter-by-tag", u8"Nach Tag \"{{{TAG}}}\" filtern" },
  { u8"fulltext-search-unavailable", u8"Die Volltestsuche steht nicht zur Verf\u00fcgung." },
  { u8"hash-download-alt-text", u8"SHA-256-Dateipr\u00fcfsumme anzeigen" },
  { u8"hash-download-link-text", u8"SHA-256 Pr\u00fcfsumme" },
  { u8"home-button-text", u8"Zur Hauptseite von '{{{BOOK_TITLE}}}' gehen" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} ist keine g\u00fcltige Anfrage f\u00fcr unverarbeiteten Inhalt" },
  { u8"invalid-request", u8"Die angeforderte URL \u201e{{{url}}}\u201c ist keine g\u00fcltige Anfrage." },
  { u8"library-button-text", u8"Zur Willkommensseite gehen" },
  { u8"library-opds-feed-all-entries", u8"ODPS Feed der Bibliothek - Alle Eintr\u00e4ge" },
  { u8"library-opds-feed-parameterised", u8"ODPS Feed der Bibliothek - Eintr\u00e4ge mit {{#LANG}\nSprache {{LANG}} {{/LANG}}{{#CATEGORY}}\nKategorie: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTag: {{TAG}}{{/TAG}}{{#Q}}\nQuery: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Download \u00fcber Magnet-Link" },
  { u8"magnet-link-text", u8"Magnet Link" },
  { u8"name", u8"Deutsch" },
  { u8"no-book-found", u8"Keine B\u00fccher entsprechen den Auswahlkriterien" },
  { u8"no-query", u8"Keine Suchanfrage gegeben." },
  { u8"no-search-results", u8"Die Volltextsuche ist f\u00fcr diesen Inhalt nicht verf\u00fcgbar." },
  { u8"no-such-book", u8"Buch nicht gefunden: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Kein Wert f\u00fcr den Parameter {{ARGUMENT}} gegeben" },
  { u8"powered-by-kiwix-html", u8"Angetrieben durch &nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Vorschau" },
  { u8"random-article-failure", u8"Hoppla! Konnte keinen zuf\u00e4lligen Artikel ausw\u00e4hlen :(" },
  { u8"random-page-button-text", u8"Zu einer zuf\u00e4llig ausgew\u00e4hlten Seite gehen" },
  { u8"raw-entry-not-found", u8"Eintrag {{ENTRY}} des Typs {{DATATYPE}} konnte nicht gefunden werden." },
  { u8"search", u8"Suchen" },
  { u8"search-result-book-info", u8"von {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Ergebnisse <b>{{START}}-{{END}}</b> von <b>{{COUNT}}</b> f\u00fcr <b>\u201e{{{SEARCH_PATTERN}}}\u201c</b>" },
  { u8"search-results-page-title", u8"Suche: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"'{{{BOOK_TITLE}}}' durchsuchen" },
  { u8"stop-filtering-by-tag", u8"Filterung nach Tag \"{{{TAG}}}\" aufheben" },
  { u8"suggest-full-text-search", u8"enth\u00e4lt '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"F\u00fchre eine Volltextsuche nach <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a> durch" },
  { u8"too-many-books", u8"Zu viele B\u00fccher angefragt ({{NB_BOOKS}}), die Beschr\u00e4nkung liegt bei {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Herunterladen \u00fcber BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Unbekannter Fehler" },
  { u8"url-not-found", u8"Die angeforderte URL \"{{url}}\" konnte auf diesem Server nicht gefunden werden." },
  { u8"welcome-page-overzealous-filter", u8"Keine Ergebnisse gefunden. M\u00f6chten Sie den <a href=\"{{URL}}\">Filter zur\u00fccksetzen</a>?" },
  { u8"welcome-to-kiwix-server", u8"Wilkommen beim Kiwix Server" },
  { u8"word-count", u8"{{COUNT}} W\u00f6rter" }
};


const I18nString string_table_for_dga[] = {
  { u8"book-filtering-all-categories", u8"Zagre zaa" },
  { u8"book-filtering-all-languages", u8"K\u0254k\u0254r\u025b\u025b zaa" },
  { u8"count-of-matching-books", u8"{{COUNT}}  gama" },
  { u8"direct-download-alt-text", u8"Toribu tagebo" },
  { u8"direct-download-link-text", u8"Toribu" },
  { u8"download", u8"Tagebo" },
  { u8"filter-by-tag", u8"Guy yi kpuli {{TAG}}" },
  { u8"hash-download-alt-text", u8"Tage bonmannaa" },
  { u8"magnet-alt-text", u8"Tage kurimaraa" },
  { u8"magnet-link-text", u8"Kurimaraa sobie" },
  { u8"search", u8"Bo" },
  { u8"stop-filtering-by-tag", u8"Bare gy\u025b\u025bbo kpuli {{TAG}}" },
  { u8"welcome-page-overzealous-filter", u8"Duoro kyebe. <a href=\"{{URL}}\">E na bo\u0254ra ka fo</a>?" }
};


const I18nString string_table_for_el[] = {
  { u8"book-filtering-all-categories", u8"\u038c\u03bb\u03b5\u03c2 \u03bf\u03b9 \u03ba\u03b1\u03c4\u03b7\u03b3\u03bf\u03c1\u03af\u03b5\u03c2" },
  { u8"book-filtering-all-languages", u8"\u038c\u03bb\u03b5\u03c2 \u03bf\u03b9 \u03b3\u03bb\u03ce\u03c3\u03c3\u03b5\u03c2" },
  { u8"caution-warning", u8"\u03a0\u03c1\u03bf\u03c3\u03bf\u03c7\u03ae!" },
  { u8"count-of-matching-books", u8"{{COUNT}} \u03b2\u03b9\u03b2\u03bb\u03af\u03bf(\u03b1)" },
  { u8"direct-download-alt-text", u8"\u03ac\u03bc\u03b5\u03c3\u03b7 \u03bb\u03ae\u03c8\u03b7" },
  { u8"direct-download-link-text", u8"\u0391\u03c0\u03b5\u03c5\u03b8\u03b5\u03af\u03b1\u03c2" },
  { u8"download", u8"\u039b\u03ae\u03c8\u03b7" },
  { u8"download-links-heading", u8"\u039b\u03ae\u03c8\u03b7 \u03c3\u03c5\u03bd\u03b4\u03ad\u03c3\u03bc\u03c9\u03bd \u03b3\u03b9\u03b1 <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"\u039a\u03b1\u03c4\u03b5\u03b2\u03ac\u03c3\u03c4\u03b5 \u03c4\u03bf \u03b2\u03b9\u03b2\u03bb\u03af\u03bf" },
  { u8"filter-by-tag", u8"\u03a6\u03b9\u03bb\u03c4\u03c1\u03ac\u03c1\u03b9\u03c3\u03bc\u03b1 \u03ba\u03b1\u03c4\u03ac \u03b5\u03c4\u03b9\u03ba\u03ad\u03c4\u03b1 \"{{{TAG}}}\"" },
  { u8"hash-download-alt-text", u8"\u03bb\u03ae\u03c8\u03b7 \u03b1\u03bd\u03b1\u03b3\u03bd\u03c9\u03c1\u03b9\u03c3\u03c4\u03b9\u03ba\u03bf\u03cd" },
  { u8"magnet-alt-text", u8"\u03bb\u03ae\u03c8\u03b7 \u03bc\u03b1\u03b3\u03bd\u03ae\u03c4\u03b7" },
  { u8"name", u8"\u0391\u03b3\u03b3\u03bb\u03b9\u03ba\u03ac" },
  { u8"no-such-book", u8"\u0394\u03b5\u03bd \u03c5\u03c0\u03ac\u03c1\u03c7\u03b5\u03b9 \u03c4\u03ad\u03c4\u03bf\u03b9\u03bf \u03b2\u03b9\u03b2\u03bb\u03af\u03bf: {{BOOK_NAME}}" },
  { u8"powered-by-kiwix-html", u8"\u039c\u03b5 \u03c4\u03b7\u03bd \u03c5\u03c0\u03bf\u03c3\u03c4\u03ae\u03c1\u03b9\u03be\u03b7 by&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"\u03a0\u03c1\u03bf\u03b5\u03c0\u03b9\u03c3\u03ba\u03cc\u03c0\u03b7\u03c3\u03b7" },
  { u8"search", u8"\u0391\u03bd\u03b1\u03b6\u03ae\u03c4\u03b7\u03c3\u03b7" },
  { u8"search-result-book-info", u8"\u03b1\u03c0\u03cc {{BOOK_TITLE}}" },
  { u8"stop-filtering-by-tag", u8"\u0394\u03b9\u03b1\u03ba\u03bf\u03c0\u03ae \u03c6\u03b9\u03bb\u03c4\u03c1\u03b1\u03c1\u03af\u03c3\u03bc\u03b1\u03c4\u03bf\u03c2 \u03ba\u03b1\u03c4\u03ac \u03b5\u03c4\u03b9\u03ba\u03ad\u03c4\u03b1 \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"\u03c0\u03b5\u03c1\u03b9\u03ad\u03c7\u03b5\u03b9 '{{{SEARCH_TERMS}}}'..." },
  { u8"torrent-download-alt-text", u8"\u039b\u03ae\u03c8\u03b7 \u03bc\u03ad\u03c3\u03c9 BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"\u0386\u03b3\u03bd\u03c9\u03c3\u03c4\u03bf \u03c3\u03c6\u03ac\u03bb\u03bc\u03b1" },
  { u8"welcome-page-overzealous-filter", u8"\u039a\u03b1\u03bd\u03ad\u03bd\u03b1 \u03b1\u03c0\u03bf\u03c4\u03ad\u03bb\u03b5\u03c3\u03bc\u03b1. \u0398\u03ad\u03bb\u03b5\u03c4\u03b5 \u03bd\u03b1 <a href=\"{{URL}}\">\u03b5\u03c0\u03b1\u03bd\u03b1\u03c6\u03ad\u03c1\u03b5\u03c4\u03b5 \u03c4\u03bf \u03c6\u03af\u03bb\u03c4\u03c1\u03bf</a>;" },
  { u8"welcome-to-kiwix-server", u8"\u039a\u03b1\u03bb\u03ce\u03c2 \u03bf\u03c1\u03af\u03c3\u03b1\u03c4\u03b5 \u03c3\u03c4\u03bf\u03bd \u03b4\u03b9\u03b1\u03ba\u03bf\u03bc\u03b9\u03c3\u03c4\u03ae Kiwix" },
  { u8"word-count", u8"{{COUNT}} \u03bb\u03ad\u03be\u03b5\u03b9\u03c2" }
};


const I18nString string_table_for_en[] = {
  { u8"400-page-heading", u8"Invalid request" },
  { u8"400-page-title", u8"Invalid request" },
  { u8"404-advice.p1", u8"The content you're looking for may still be available, but it might be located at a different place within the ZIM file." },
  { u8"404-advice.p2", u8"Please:" },
  { u8"404-advice.p3", u8"Try using the search function to find the content you want" },
  { u8"404-advice.p4", u8"Look for keywords or titles related to the information you're seeking" },
  { u8"404-advice.p5", u8"This approach should help you locate the desired content, even if the original link isn't working properly." },
  { u8"404-img-text", u8"Not found!" },
  { u8"404-page-heading", u8"Not Found" },
  { u8"404-page-title", u8"Content not found" },
  { u8"500-img-text", u8"Page isn't working" },
  { u8"500-page-heading", u8"Oops. Page isn't working." },
  { u8"500-page-text", u8"The requested path cannot be properly delivered:" },
  { u8"500-page-title", u8"Internal Server Error" },
  { u8"book-category.gutenberg", u8"Gutenberg" },
  { u8"book-category.iFixit", u8"iFixit" },
  { u8"book-category.mooc", u8"MOOC" },
  { u8"book-category.other", u8"Other" },
  { u8"book-category.phet", u8"Phet" },
  { u8"book-category.stack_exchange", u8"Stack Exchange" },
  { u8"book-category.ted", u8"Ted" },
  { u8"book-category.vikidia", u8"Vikidia" },
  { u8"book-category.wikibooks", u8"Wikibooks" },
  { u8"book-category.wikihow", u8"wikiHow" },
  { u8"book-category.wikinews", u8"Wikinews" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversity" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wiktionary" },
  { u8"book-filtering-all-categories", u8"All categories" },
  { u8"book-filtering-all-languages", u8"All languages" },
  { u8"caution-warning", u8"Caution!" },
  { u8"confusion-of-tongues", u8"Two or more books in different languages would participate in search, which may lead to confusing results." },
  { u8"count-of-matching-books", u8"{{COUNT}} book(s)" },
  { u8"direct-download-alt-text", u8"Download directly via HTTP(S)" },
  { u8"direct-download-link-text", u8"Direct" },
  { u8"download", u8"Download" },
  { u8"download-links-heading", u8"Download links for <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Download book" },
  { u8"empty-search-results-page-header", u8"No results were found for <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"external-link-advice.p1", u8"The link you're trying to access is not part of your offline package and requires an internet connection." },
  { u8"external-link-advice.p2", u8"If you can go online, you can attempt to open the link." },
  { u8"external-link-advice.p3", u8"You can otherwise return to your ZIM's offline content by using your browser's back button." },
  { u8"external-link-detected", u8"External Link Detected" },
  { u8"external-link-intro", u8"You are about to leave Kiwix's ZIM reader to go online to" },
  { u8"filter-by-tag", u8"Filter by tag \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"Fulltext search unavailable" },
  { u8"hash-download-alt-text", u8"Display SHA-256 file checksum" },
  { u8"hash-download-link-text", u8"SHA-256 checksum" },
  { u8"home-button-text", u8"Go to the main page of '{{{BOOK_TITLE}}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} is not a valid request for raw content." },
  { u8"invalid-request", u8"The requested URL \"{{{url}}}\" is not a valid request." },
  { u8"library-button-text", u8"Go to welcome page" },
  { u8"library-opds-feed-all-entries", u8"Library OPDS Feed - All entries" },
  { u8"library-opds-feed-parameterised", u8"Library OPDS Feed - entries matching {{#LANG}}\nLanguage: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategory: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\nQuery: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Download via Magnet link" },
  { u8"magnet-link-text", u8"Magnet link" },
  { u8"name", u8"English" },
  { u8"new-404-page-heading", u8"Oops. Page not found." },
  { u8"new-404-page-title", u8"Page not found" },
  { u8"no-book-found", u8"No book matches selection criteria" },
  { u8"no-query", u8"No query provided." },
  { u8"no-search-results", u8"The fulltext search engine is not available for this content." },
  { u8"no-such-book", u8"No such book: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"No value provided for argument {{ARGUMENT}}" },
  { u8"non-translated-text", u8"{{MSG}}" },
  { u8"path-was-not-found", u8"The requested path was not found:" },
  { u8"powered-by-kiwix-html", u8"Powered by&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Preview" },
  { u8"random-article-failure", u8"Oops! Failed to pick a random article :(" },
  { u8"random-page-button-text", u8"Go to a randomly selected page" },
  { u8"raw-entry-not-found", u8"Cannot find {{DATATYPE}} entry {{ENTRY}}" },
  { u8"search", u8"Search" },
  { u8"search-result-book-info", u8"from {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Results <b>{{START}}-{{END}}</b> of <b>{{COUNT}}</b> for <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Search: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Search '{{{BOOK_TITLE}}}'" },
  { u8"stop-filtering-by-tag", u8"Stop filtering by tag \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"containing '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Make a full text search for <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Loading Content" },
  { u8"too-many-books", u8"Too many books requested ({{NB_BOOKS}}) where limit is {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Download via BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Unknown error" },
  { u8"url-not-found", u8"The requested URL \"{{url}}\" was not found on this server." },
  { u8"welcome-page-overzealous-filter", u8"No result. Would you like to <a href=\"{{URL}}\">reset filter</a>?" },
  { u8"welcome-to-kiwix-server", u8"Welcome to Kiwix Server" },
  { u8"word-count", u8"{{COUNT}} words" }
};


const I18nString string_table_for_es[] = {
  { u8"400-page-heading", u8"Solicitud inv\u00e1lida" },
  { u8"400-page-title", u8"Solicitud inv\u00e1lida" },
  { u8"404-advice.p1", u8"El contenido que est\u00e1 buscando podr\u00eda estar disponible pero podr\u00eda estar localizado en un lugar diferente dentro del archivo ZIM." },
  { u8"404-advice.p2", u8"Por favor:" },
  { u8"404-advice.p3", u8"Intente usar la funci\u00f3n de b\u00fasqueda para encontrar el contenido que desea" },
  { u8"404-advice.p4", u8"Mire por palabras clave o t\u00edtulos relacionados a la informaci\u00f3n que est\u00e1 buscando" },
  { u8"404-advice.p5", u8"Este m\u00e9todo deber\u00eda ayudarle a localizar el contenido deseado incluso si el enlace original no funciona correctamente." },
  { u8"404-img-text", u8"\u00a1No encontrado!" },
  { u8"404-page-heading", u8"No encontrado" },
  { u8"404-page-title", u8"Contenido no encontrado" },
  { u8"500-img-text", u8"La p\u00e1gina no est\u00e1 funcionando" },
  { u8"500-page-heading", u8"Ups. La p\u00e1gina no funciona." },
  { u8"500-page-text", u8"La pagina solicitada no se puede cargar correctamente:" },
  { u8"500-page-title", u8"Error interno del servidor" },
  { u8"book-category.gutenberg", u8"Gutenberg" },
  { u8"book-category.iFixit", u8"iFixit" },
  { u8"book-category.mooc", u8"MOOC" },
  { u8"book-category.other", u8"Otros" },
  { u8"book-category.phet", u8"Phet" },
  { u8"book-category.stack_exchange", u8"Stack Exchange" },
  { u8"book-category.ted", u8"Ted" },
  { u8"book-category.vikidia", u8"Vikidia" },
  { u8"book-category.wikibooks", u8"Wikilibros" },
  { u8"book-category.wikihow", u8"wikiHow" },
  { u8"book-category.wikinews", u8"Wikinoticias" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikiespecies" },
  { u8"book-category.wikiversity", u8"Wikiversidad" },
  { u8"book-category.wikivoyage", u8"Wikiviajes" },
  { u8"book-category.wiktionary", u8"Wikcionario" },
  { u8"book-filtering-all-categories", u8"Todas las categor\u00edas" },
  { u8"book-filtering-all-languages", u8"Todos los idiomas" },
  { u8"caution-warning", u8"\u00a1Precauci\u00f3n!" },
  { u8"confusion-of-tongues", u8"Dos o m\u00e1s libros en diferentes idiomas participar\u00edan en la b\u00fasqueda, lo que puede llevar a resultados confusos." },
  { u8"count-of-matching-books", u8"{{COUNT}} libro(s)" },
  { u8"direct-download-alt-text", u8"Descargar directamente v\u00eda HTTP(S)" },
  { u8"direct-download-link-text", u8"Directamente" },
  { u8"download", u8"Descargar" },
  { u8"download-links-heading", u8"Enlaces de descarga para <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Descargar libro" },
  { u8"empty-search-results-page-header", u8"No se encontraron resultados para <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"external-link-advice.p1", u8"El enlace al que est\u00e1 tratando de acceder no es parte de su descarga sin conexi\u00f3n y requiere de conexi\u00f3n a internet." },
  { u8"external-link-advice.p2", u8"Si usted puede conectarse en linea puede intentar abrir el enlace." },
  { u8"external-link-advice.p3", u8"De lo contrario, puede volver al contenido sin conexi\u00f3n de su ZIM utilizando el bot\u00f3n atr\u00e1s del navegador." },
  { u8"external-link-detected", u8"Enlace externo detectado" },
  { u8"external-link-intro", u8"Usted est\u00e1 apunto de abandonar el lector ZIM de Kiwix para ir a" },
  { u8"filter-by-tag", u8"Filtrar por etiqueta \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"B\u00fasqueda de texto completo no disponible" },
  { u8"hash-download-alt-text", u8"Mostrar la suma de verificaci\u00f3n de archivos SHA-256" },
  { u8"hash-download-link-text", u8"Suma de verificaci\u00f3n SHA-256" },
  { u8"home-button-text", u8"Ir a la p\u00e1gina principal de '{{{BOOK_TITLE}}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} no es una solicitud v\u00e1lida de contenido en crudo." },
  { u8"invalid-request", u8"La URL solicitada \"{{{url}}}\" no es una solicitud v\u00e1lida." },
  { u8"library-button-text", u8"Ir a la p\u00e1gina de bienvenida" },
  { u8"library-opds-feed-all-entries", u8"Biblioteca OPDS Feed - Todas las entradas" },
  { u8"library-opds-feed-parameterised", u8"Feed OPDS de la biblioteca: entradas que coinciden con {{#LANG}}\nLanguage: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategory: {{CATEGORY}} {{/CATEGORY}} {{#TAG}}\nEtiqueta: {{TAG}} {{/TAG}}{{#Q}}\nConsulta: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Descargar mediante enlace Magnet" },
  { u8"magnet-link-text", u8"Enlace magn\u00e9tico" },
  { u8"name", u8"Espa\u00f1ol" },
  { u8"new-404-page-heading", u8"Ups. P\u00e1gina no encontrado." },
  { u8"new-404-page-title", u8"P\u00e1gina no encontrada" },
  { u8"no-book-found", u8"Ning\u00fan libro coincide con los criterios de selecci\u00f3n" },
  { u8"no-query", u8"No se ha proporcionado ninguna consulta." },
  { u8"no-search-results", u8"El motor de b\u00fasqueda de texto completo no est\u00e1 disponible para este contenido." },
  { u8"no-such-book", u8"No existe el libro: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"No se ha proporcionado ning\u00fan valor para el argumento {{ARGUMENT}}" },
  { u8"path-was-not-found", u8"La pagina solicitada no se ha encontrado:" },
  { u8"powered-by-kiwix-html", u8"Desarrollado por&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Previsualizar" },
  { u8"random-article-failure", u8"\u00a1Ups! Error al elegir un art\u00edculo aleatorio :(" },
  { u8"random-page-button-text", u8"Ir a una p\u00e1gina seleccionada al azar" },
  { u8"raw-entry-not-found", u8"No se puede encontrar la entrada {{DATATYPE}} {{ENTRY}}" },
  { u8"search", u8"Buscar" },
  { u8"search-result-book-info", u8"a partir de {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Resultados <b>{{START}}-{{END}}</b> de <b>{{COUNT}}</b> para <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Buscar: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Buscar '{{{BOOK_TITLE}}}'" },
  { u8"stop-filtering-by-tag", u8"Dejar de filtrar por etiqueta \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"que contenga \"{{{SEARCH_TERMS}}}\"..." },
  { u8"suggest-search", u8"Haga una b\u00fasqueda de texto completo para <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Cargando contenido" },
  { u8"too-many-books", u8"Demasiadas solicitudes de libros ({{NB_BOOKS}}) donde el l\u00edmite es {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Descargar a trav\u00e9s de BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Error desconocido" },
  { u8"url-not-found", u8"La URL solicitada \"{{url}}\" no se encontr\u00f3 en este servidor." },
  { u8"welcome-page-overzealous-filter", u8"Sin resultados. \u00bfQuieres <a href=\"{{URL}}\">restablecer el filtro</a> ?" },
  { u8"welcome-to-kiwix-server", u8"Bienvenido al servidor Kiwix" },
  { u8"word-count", u8"{{COUNT}} palabras" }
};


const I18nString string_table_for_fi[] = {
  { u8"400-page-heading", u8"Virheellinen pyynt\u00f6" },
  { u8"400-page-title", u8"Virheellinen pyynt\u00f6" },
  { u8"404-img-text", u8"Ei l\u00f6ytynyt!" },
  { u8"404-page-heading", u8"Ei l\u00f6ytynyt" },
  { u8"404-page-title", u8"Sis\u00e4lt\u00f6\u00e4 ei l\u00f6ytynyt" },
  { u8"500-img-text", u8"Sivu ei toimi" },
  { u8"500-page-heading", u8"Hupsista. Sivu ei toimi." },
  { u8"500-page-title", u8"Sis\u00e4inen palvelinvirhe" },
  { u8"book-category.other", u8"Muu" },
  { u8"book-category.wikibooks", u8"Wikikirjasto" },
  { u8"book-category.wikinews", u8"Wikiuutiset" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikisitaatit" },
  { u8"book-category.wikisource", u8"Wikiaineisto" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiopisto" },
  { u8"book-category.wikivoyage", u8"Wikimatkat" },
  { u8"book-category.wiktionary", u8"Wikisanakirja" },
  { u8"book-filtering-all-categories", u8"Kaikki luokat" },
  { u8"book-filtering-all-languages", u8"Kaikki kielet" },
  { u8"caution-warning", u8"Huomio!" },
  { u8"count-of-matching-books", u8"{{COUNT}} kirja(a)" },
  { u8"download", u8"Lataa" },
  { u8"download-links-title", u8"Lataa kirja" },
  { u8"external-link-detected", u8"Ulkoinen linkki havaittu" },
  { u8"external-link-intro", u8"Olet poistumassa Kiwixin ZIM-lukijasta siirty\u00e4ksesi verkkoon" },
  { u8"filter-by-tag", u8"Suodata tunnisteen \u201d{{TAG}}\u201d mukaan" },
  { u8"home-button-text", u8"Siirry kirjan '{{{BOOK_TITLE}}}' etusivulle" },
  { u8"library-button-text", u8"Siirry tervetulosivulle" },
  { u8"magnet-alt-text", u8"lataa magnet" },
  { u8"magnet-link-text", u8"Magnet-linkki" },
  { u8"name", u8"suomi" },
  { u8"new-404-page-heading", u8"Hupsista. Artikkelia ei l\u00f6ytynyt." },
  { u8"new-404-page-title", u8"Sivua ei l\u00f6ytynyt" },
  { u8"no-such-book", u8"Kirjaa {{BOOK_NAME}} ei ole olemassa" },
  { u8"path-was-not-found", u8"Pyydetty\u00e4 polkua ei l\u00f6ytynyt:" },
  { u8"preview-book", u8"Esikatsele" },
  { u8"random-page-button-text", u8"Siirry satunnaiselle sivulle" },
  { u8"search", u8"Hae" },
  { u8"search-results-page-title", u8"Haku: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Hae kirjasta '{{{BOOK_TITLE}}}'" },
  { u8"suggest-full-text-search", u8"sis\u00e4lt\u00e4\u00e4 '{{{SEARCH_TERMS}}}'..." },
  { u8"text-loading-content", u8"Ladataan sis\u00e4lt\u00f6\u00e4" },
  { u8"torrent-download-alt-text", u8"lataa torrent-tiedosto" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Tuntematon virhe" },
  { u8"url-not-found", u8"Pyydetty\u00e4 URL-osoitetta \"{{url}}\" ei l\u00f6ytynyt t\u00e4lt\u00e4 palvelimelta." },
  { u8"word-count", u8"{{COUNT}} sanaa" }
};


const I18nString string_table_for_fr[] = {
  { u8"400-page-heading", u8"Requ\u00eate non valide" },
  { u8"400-page-title", u8"Requ\u00eate non valide" },
  { u8"404-advice.p1", u8"Le contenu que vous recherchez peut toujours \u00eatre disponible, mais il peut \u00eatre positionn\u00e9 \u00e0 un endroit diff\u00e9rent dans le fichier ZIM." },
  { u8"404-advice.p2", u8"Veuillez :" },
  { u8"404-advice.p3", u8"Essayer d\u2019utiliser la fonction de recherche pour trouver le contenu que vous souhaitez" },
  { u8"404-advice.p4", u8"Rechercher des mots-cl\u00e9s ou des titres li\u00e9s aux informations que vous recherchez" },
  { u8"404-advice.p5", u8"Cette approche devrait vous aider \u00e0 localiser le contenu souhait\u00e9, m\u00eame si le lien d\u2019origine ne fonctionne pas correctement." },
  { u8"404-img-text", u8"Non trouv\u00e9e !" },
  { u8"404-page-heading", u8"Non trouv\u00e9" },
  { u8"404-page-title", u8"Contenu non trouv\u00e9" },
  { u8"500-img-text", u8"La page ne fonctionne pas" },
  { u8"500-page-heading", u8"Oups, la page ne fonctionne pas." },
  { u8"500-page-text", u8"Le chemin demand\u00e9 ne peut pas \u00eatre fourni correctement :" },
  { u8"500-page-title", u8"Erreur interne du serveur" },
  { u8"book-category.other", u8"Autre" },
  { u8"book-category.wikibooks", u8"Wikilivres" },
  { u8"book-category.wikinews", u8"Wikinews" },
  { u8"book-category.wikipedia", u8"Wikip\u00e9dia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversit\u00e9" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wiktionnaire" },
  { u8"book-filtering-all-categories", u8"Toutes les cat\u00e9gories" },
  { u8"book-filtering-all-languages", u8"Toutes les langues" },
  { u8"caution-warning", u8"Attention\u202f!" },
  { u8"confusion-of-tongues", u8"Deux livres ou plus dans des langues diff\u00e9rentes participeraient \u00e0 la recherche, ce qui pourrait conduire \u00e0 des r\u00e9sultats confus." },
  { u8"count-of-matching-books", u8"{{COUNT}} livre(s)" },
  { u8"direct-download-alt-text", u8"T\u00e9l\u00e9charger directement via HTTP(S)" },
  { u8"direct-download-link-text", u8"Direct" },
  { u8"download", u8"T\u00e9l\u00e9charger" },
  { u8"download-links-heading", u8"Liens de t\u00e9l\u00e9chargement pour <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"T\u00e9l\u00e9charger le livre" },
  { u8"empty-search-results-page-header", u8"Aucun r\u00e9sultat n\u2019a \u00e9t\u00e9 trouv\u00e9 pour <b>\u00ab {{{SEARCH_PATTERN}}} \u00bb</b>" },
  { u8"external-link-advice.p1", u8"Le lien que vous essayez de suivre ne fait pas partie de votre forfait hors ligne et n\u00e9cessite une connexion Internet." },
  { u8"external-link-advice.p2", u8"Si vous pouvez vous connecter en ligne, vous pouvez essayer d\u2019ouvrir le lien." },
  { u8"external-link-advice.p3", u8"Vous pouvez \u00e9galement revenir au contenu hors ligne de votre ZIM en utilisant le bouton Retour de votre navigateur." },
  { u8"external-link-detected", u8"Lien externe d\u00e9tect\u00e9" },
  { u8"external-link-intro", u8"Vous \u00eates sur le point de quitter le lecteur ZIM de Kiwix pour vous connecter \u00e0" },
  { u8"filter-by-tag", u8"Filtrer par le tag \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"Recherche en texte int\u00e9gral non disponible" },
  { u8"hash-download-alt-text", u8"Affiche le hachage SHA-256 du fichier" },
  { u8"hash-download-link-text", u8"Hachage SHA-256" },
  { u8"home-button-text", u8"Aller \u00e0 la page principale de \u00ab\u202f{{{BOOK_TITLE}}}\u202f\u00bb" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} n\u2019est pas une requ\u00eate valide pour du contenu brut." },
  { u8"invalid-request", u8"L'URL demand\u00e9e \"{{{url}}}\" n'est pas une requ\u00eate valide." },
  { u8"library-button-text", u8"Aller \u00e0 la page de bienvenue" },
  { u8"library-opds-feed-all-entries", u8"Flux OPDS de la biblioth\u00e8que \u2013 Toutes les entr\u00e9es" },
  { u8"library-opds-feed-parameterised", u8"Flux OPDS de la biblioth\u00e8que \u2013 Entr\u00e9es correspondant \u00e0 {{#LANG}}\u202f:\n \u25aa Langue\u202f: {{LANG}} {{/LANG}}{{#CATEGORY}}\n \u25aa Cat\u00e9gorie\u202f: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\n \u25aa \u00c9tiquette\u202f: {{TAG}} {{/TAG}}{{#Q}}\n \u25aa Requ\u00eate\u202f: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"T\u00e9l\u00e9charger via le lien Magnet" },
  { u8"magnet-link-text", u8"Lien Magnet" },
  { u8"name", u8"Fran\u00e7ais" },
  { u8"new-404-page-heading", u8"Oups. Page non trouv\u00e9e." },
  { u8"new-404-page-title", u8"Page non trouv\u00e9e" },
  { u8"no-book-found", u8"Aucun livre ne correspond \u00e0 ces crit\u00e8res de s\u00e9lection" },
  { u8"no-query", u8"Aucune requ\u00eate fournie." },
  { u8"no-search-results", u8"Le moteur de recherche en texte int\u00e9gral n\u2019est pas disponible pour ce contenu." },
  { u8"no-such-book", u8"Aucun livre avec ce nom\u202f: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Aucune valeur fournie pour l\u2019argument {{ARGUMENT}}" },
  { u8"path-was-not-found", u8"Le chemin demand\u00e9 n\u2019a pas \u00e9t\u00e9 trouv\u00e9 :" },
  { u8"powered-by-kiwix-html", u8"Propuls\u00e9 par <a href=\"https://kiwix.org/\">Kiwix</a>" },
  { u8"preview-book", u8"Aper\u00e7u" },
  { u8"random-article-failure", u8"Oups\u202f! \u00c9chec de s\u00e9lection d\u2019un article al\u00e9atoire :(" },
  { u8"random-page-button-text", u8"Aller \u00e0 une page s\u00e9lectionn\u00e9e al\u00e9atoirement" },
  { u8"raw-entry-not-found", u8"Impossible de trouver l\u2019entr\u00e9e \u00ab\u202f{{ENTRY}}\u202f\u00bb de type \u00ab\u202f{{DATATYPE}}\u202f\u00bb" },
  { u8"search", u8"Rechercher" },
  { u8"search-result-book-info", u8"\u00e0 partir de {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"R\u00e9sultats <b>{{START}}-{{END}}</b> sur<b>\u00a0{{COUNT}}</b> pour <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Rechercher\u00a0:\u00a0{{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Rechercher \u00ab\u202f{{{BOOK_TITLE}}}\u202f\u00bb" },
  { u8"stop-filtering-by-tag", u8"Arr\u00eater de filtrer par le tag \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"contenant \u00ab\u202f{{{SEARCH_TERMS}}}\u202f\u00bb..." },
  { u8"suggest-search", u8"Faire une recherche en texte int\u00e9gral de \u00ab\u202f<a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>\u202f\u00bb" },
  { u8"text-loading-content", u8"Chargement du contenu" },
  { u8"too-many-books", u8"Trop de livres demand\u00e9s ({{NB_BOOKS}}) alors que la limite est de {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"T\u00e9l\u00e9charger via BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Erreur inconnue" },
  { u8"url-not-found", u8"L\u2019URL demand\u00e9e \u00ab\u202f{{url}}\u202f\u00bb est introuvable sur ce serveur." },
  { u8"welcome-page-overzealous-filter", u8"Aucun r\u00e9sultat. Souhaitez-vous <a href=\"{{URL}}\">r\u00e9initialiser le filtre</a>\u202f?" },
  { u8"welcome-to-kiwix-server", u8"Bienvenue sur le Serveur Kiwix" },
  { u8"word-count", u8"{{COUNT}}\u00a0mots" }
};


const I18nString string_table_for_ha[] = {
  { u8"400-page-heading", u8"nema mara inganci" },
  { u8"400-page-title", u8"nema mara inganci" },
  { u8"404-page-heading", u8"Ba a Samu ba" },
  { u8"404-page-title", u8"Ba a samo abun ciki ba" },
  { u8"500-page-heading", u8"Kuskuren na Cikin Saba" },
  { u8"500-page-text", u8"An sami kuskuren uwar garken ciki. Munyi nadama akan hakan :/" },
  { u8"500-page-title", u8"Kuskuren na Cikin Saba" },
  { u8"book-filtering-all-categories", u8"Dukkanin nau'o'in" },
  { u8"book-filtering-all-languages", u8"Duka harsuna" },
  { u8"confusion-of-tongues", u8"Littattafai biyu ko fiye a cikin harsuna daban-daban za su shiga cikin bincike, wanda zai iya haifar da sakamako mai ru\u0257ani." },
  { u8"count-of-matching-books", u8"{{COUNT}} littafi(s)" },
  { u8"direct-download-alt-text", u8"saukewa kai tsaye" },
  { u8"direct-download-link-text", u8"Kai tsaye" },
  { u8"download", u8"Sauke" },
  { u8"download-links-heading", u8"Bring out ways through which people can join hands together .{{BOOK_TITLE}}" },
  { u8"download-links-title", u8"Sauke littafin" },
  { u8"empty-search-results-page-header", u8"Ba a sami sakamakon <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"filter-by-tag", u8"Tace da alamar \"{{TAG}}\"" },
  { u8"fulltext-search-unavailable", u8"Babu binciken cikakken rubutu" },
  { u8"hash-download-alt-text", u8"sauke hash" },
  { u8"hash-download-link-text", u8"Sha256 hash" },
  { u8"home-button-text", u8"Jeka babban shafin '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} ba ingantaccen bu\u0199atun \u0257anyen abun ciki bane." },
  { u8"invalid-request", u8"URL \u0257in da ake nema \"{{{url}}}\" ba bu\u0199atu mai inganci bane." },
  { u8"library-button-text", u8"Je zuwa shafin maraba" },
  { u8"library-opds-feed-all-entries", u8"Ciyarwar OPDS Library - Duk shigarwar" },
  { u8"library-opds-feed-parameterised", u8" OPDS ciyar wa OPDS- entries matching {{#LANG}}\nLanguage: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategory: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\nQuery: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Magnet \u0257in saukewa" },
  { u8"magnet-link-text", u8"Magnet link" },
  { u8"name", u8"Turanci" },
  { u8"no-book-found", u8"Babu wani littafi da ya dace da ma'aunin za\u0253i" },
  { u8"no-query", u8"Ba a bayar da tambaya ba." },
  { u8"no-search-results", u8"Babu injin binciken cikakken rubutu don wannan abun ciki." },
  { u8"no-such-book", u8"Babu irin wannan littafin: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Babu \u0199ima da aka bayar don hujja {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"<a href=\"https://kiwix.org\">Kiwix</a> ne ke \u0199arfafa shi" },
  { u8"preview-book", u8"Dubawa" },
  { u8"random-article-failure", u8"Kash! An kasa \u0257aukar labarin bazuwar :(" },
  { u8"random-page-button-text", u8"Je zuwa shafin da aka za\u0253a ba da gangan ba" },
  { u8"raw-entry-not-found", u8"Ba a iya samun shigarwar {{DATATYPE}} {{ENTRY}}" },
  { u8"search", u8"Nema" },
  { u8"search-result-book-info", u8"daga {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Sakamako <b>{{START}}-{{END}}</b> na <b>{{COUNT}}</b> na <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Bincika: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Bincika '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Dakatar da tacewa ta hanyar \"{{TAG}}\"" },
  { u8"suggest-full-text-search", u8"dauke da ''{{{SEARCH_TERMS}}}''..." },
  { u8"suggest-search", u8"Yi cikakken bincike na rubutu don <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"An nemi littattafai da yawa ({{NB_BOOKS}}) inda iyaka shine {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"download torrent" },
  { u8"torrent-download-link-text", u8"Torrent fayil" },
  { u8"unknown-error", u8"Kuskuren da ba a sani ba" },
  { u8"url-not-found", u8"Ba a sami URL \u0257in da ake nema \"{{url}}\" akan wannan sabar ba." },
  { u8"welcome-page-overzealous-filter", u8"Babu sakamako. Kuna so a <a href=\"{{URL}}\">sake saita tace</a>?" },
  { u8"welcome-to-kiwix-server", u8"Barka da zowa manhajar Kiwix" },
  { u8"word-count", u8"{{COUNT}} kalmomi" }
};


const I18nString string_table_for_he[] = {
  { u8"400-page-heading", u8"\u05d1\u05e7\u05e9\u05d4 \u05d1\u05dc\u05ea\u05d9\u05be\u05ea\u05e7\u05d9\u05e0\u05d4" },
  { u8"400-page-title", u8"\u05d1\u05e7\u05e9\u05d4 \u05d1\u05dc\u05ea\u05d9\u05be\u05ea\u05e7\u05d9\u05e0\u05d4" },
  { u8"404-advice.p2", u8"\u05d1\u05d1\u05e7\u05e9\u05d4:" },
  { u8"404-advice.p3", u8"\u05dc\u05e0\u05e1\u05d5\u05ea \u05dc\u05d4\u05e9\u05ea\u05de\u05e9 \u05d1\u05d9\u05db\u05d5\u05dc\u05ea \u05d4\u05d7\u05d9\u05e4\u05d5\u05e9 \u05db\u05d3\u05d9 \u05dc\u05de\u05e6\u05d5\u05d0 \u05d0\u05ea \u05d4\u05ea\u05d5\u05db\u05df \u05d4\u05de\u05d1\u05d5\u05e7\u05e9" },
  { u8"404-img-text", u8"\u05dc\u05d0 \u05e0\u05de\u05e6\u05d0!" },
  { u8"404-page-heading", u8"\u05dc\u05d0 \u05e0\u05de\u05e6\u05d0" },
  { u8"404-page-title", u8"\u05d4\u05ea\u05d5\u05db\u05df \u05dc\u05d0 \u05e0\u05de\u05e6\u05d0" },
  { u8"500-img-text", u8"\u05d4\u05d3\u05e3 \u05dc\u05d0 \u05e2\u05d5\u05d1\u05d3" },
  { u8"500-page-heading", u8"\u05d0\u05d5\u05e4\u05e1. \u05d4\u05d3\u05e3 \u05dc\u05d0 \u05e2\u05d5\u05d1\u05d3." },
  { u8"500-page-text", u8"\u05d0\u05d9 \u05d0\u05e4\u05e9\u05e8 \u05dc\u05de\u05e1\u05d5\u05e8 \u05d0\u05ea \u05d4\u05e0\u05ea\u05d9\u05d1 \u05d4\u05de\u05d1\u05d5\u05e7\u05e9 \u05db\u05e8\u05d0\u05d5\u05d9:" },
  { u8"500-page-title", u8"\u05e9\u05d2\u05d9\u05d0\u05ea \u05e9\u05e8\u05ea \u05e4\u05e0\u05d9\u05de\u05d9\u05ea" },
  { u8"book-category.gutenberg", u8"\u05d2\u05d5\u05d8\u05e0\u05d1\u05e8\u05d2" },
  { u8"book-category.other", u8"\u05d0\u05d7\u05e8" },
  { u8"book-category.vikidia", u8"\u05d5\u05d9\u05e7\u05d9\u05d3\u05d9\u05d4" },
  { u8"book-category.wikibooks", u8"\u05d5\u05d9\u05e7\u05d9\u05e1\u05e4\u05e8" },
  { u8"book-category.wikinews", u8"\u05d5\u05d9\u05e7\u05d9\u05d7\u05d3\u05e9\u05d5\u05ea" },
  { u8"book-category.wikipedia", u8"\u05d5\u05d9\u05e7\u05d9\u05e4\u05d3\u05d9\u05d4" },
  { u8"book-category.wikiquote", u8"\u05d5\u05d9\u05e7\u05d9\u05e6\u05d9\u05d8\u05d5\u05d8" },
  { u8"book-category.wikisource", u8"\u05d5\u05d9\u05e7\u05d9\u05d8\u05e7\u05e1\u05d8 (Wikisource)" },
  { u8"book-category.wikispecies", u8"\u05d5\u05d9\u05e7\u05d9\u05de\u05d9\u05e0\u05d9\u05dd" },
  { u8"book-category.wikiversity", u8"\u05d5\u05d9\u05e7\u05d9\u05d1\u05e8\u05e1\u05d9\u05d8\u05d4" },
  { u8"book-category.wikivoyage", u8"\u05d5\u05d9\u05e7\u05d9\u05de\u05e1\u05e2" },
  { u8"book-category.wiktionary", u8"\u05d5\u05d9\u05e7\u05d9\u05de\u05d9\u05dc\u05d5\u05df" },
  { u8"book-filtering-all-categories", u8"\u05db\u05dc \u05d4\u05e7\u05d8\u05d2\u05d5\u05e8\u05d9\u05d5\u05ea" },
  { u8"book-filtering-all-languages", u8"\u05db\u05dc \u05d4\u05e9\u05e4\u05d5\u05ea" },
  { u8"caution-warning", u8"\u05d6\u05d4\u05d9\u05e8\u05d5\u05ea!" },
  { u8"confusion-of-tongues", u8"\u05e9\u05e0\u05d9 \u05e1\u05e4\u05e8\u05d9\u05dd \u05d0\u05d5 \u05d9\u05d5\u05ea\u05e8 \u05d1\u05e9\u05e4\u05d5\u05ea \u05e9\u05d5\u05e0\u05d5\u05ea \u05d9\u05e9\u05ea\u05ea\u05e4\u05d5 \u05d1\u05d7\u05d9\u05e4\u05d5\u05e9, \u05de\u05d4 \u05e9\u05e2\u05dc\u05d5\u05dc \u05dc\u05d4\u05d5\u05d1\u05d9\u05dc \u05dc\u05ea\u05d5\u05e6\u05d0\u05d5\u05ea \u05de\u05d1\u05dc\u05d1\u05dc\u05d5\u05ea." },
  { u8"count-of-matching-books", u8"{{COUNT}} \u05e1\u05e4\u05e8\u05d9\u05dd" },
  { u8"direct-download-alt-text", u8"\u05d4\u05d5\u05e8\u05d3\u05d4 \u05d9\u05e9\u05d9\u05e8\u05d4 \u05d3\u05e8\u05da HTTP(S)" },
  { u8"direct-download-link-text", u8"\u05d9\u05e9\u05d9\u05e8\u05d4" },
  { u8"download", u8"\u05d4\u05d5\u05e8\u05d3\u05d4" },
  { u8"download-links-heading", u8"\u05d4\u05d5\u05e8\u05d3\u05ea \u05e7\u05d9\u05e9\u05d5\u05e8\u05d9\u05dd \u05e2\u05d1\u05d5\u05e8 <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"\u05d4\u05d5\u05e8\u05d3\u05ea \u05e1\u05e4\u05e8" },
  { u8"empty-search-results-page-header", u8"\u05dc\u05d0 \u05e0\u05de\u05e6\u05d0\u05d5 \u05ea\u05d5\u05e6\u05d0\u05d5\u05ea \u05e2\u05d1\u05d5\u05e8 <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"external-link-advice.p2", u8"\u05d0\u05dd \u05d9\u05e9 \u05dc\u05da \u05d0\u05d9\u05da \u05dc\u05d4\u05ea\u05d7\u05d1\u05e8 \u05dc\u05d0\u05d9\u05e0\u05d8\u05e8\u05e0\u05d8, \u05d0\u05e4\u05e9\u05e8 \u05dc\u05e0\u05e1\u05d5\u05ea \u05dc\u05e4\u05ea\u05d5\u05d7 \u05d0\u05ea \u05d4\u05e7\u05d9\u05e9\u05d5\u05e8." },
  { u8"external-link-detected", u8"\u05d4\u05ea\u05d2\u05dc\u05d4 \u05e7\u05d9\u05e9\u05d5\u05e8 \u05d7\u05d9\u05e6\u05d5\u05e0\u05d9" },
  { u8"filter-by-tag", u8"\u05dc\u05e1\u05e0\u05df \u05dc\u05e4\u05d9 \u05d4\u05ea\u05d2 \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"\u05d7\u05d9\u05e4\u05d5\u05e9 \u05d1\u05d8\u05e7\u05e1\u05d8 \u05de\u05dc\u05d0 \u05d0\u05d9\u05e0\u05d5 \u05d6\u05de\u05d9\u05df" },
  { u8"hash-download-alt-text", u8"\u05d4\u05e6\u05d2\u05ea \u05e1\u05d9\u05db\u05d5\u05dd \u05d1\u05d9\u05e7\u05d5\u05e8\u05ea SHA-256" },
  { u8"hash-download-link-text", u8"\u05e1\u05d9\u05db\u05d5\u05dd \u05d1\u05d9\u05e7\u05d5\u05e8\u05ea Sha256" },
  { u8"home-button-text", u8"\u05de\u05e2\u05d1\u05e8 \u05dc\u05d3\u05e3 \u05d4\u05e8\u05d0\u05e9\u05d9 \u05e9\u05dc \u201a{{{BOOK_TITLE}}}\u2019" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u05d4\u05d5\u05d0 \u05dc\u05d0 \u05d1\u05e7\u05e9\u05d4 \u05ea\u05e7\u05d9\u05e0\u05d4 \u05e9\u05dc \u05ea\u05d5\u05db\u05df \u05d2\u05d5\u05dc\u05de\u05d9." },
  { u8"invalid-request", u8"\u05d4\u05db\u05ea\u05d5\u05d1\u05ea \u05d4\u05de\u05d1\u05d5\u05e7\u05e9\u05ea \"{{{url}}}\" \u05d0\u05d9\u05e0\u05d4 \u05d1\u05e7\u05e9\u05d4 \u05ea\u05e7\u05d9\u05e0\u05d4." },
  { u8"library-button-text", u8"\u05de\u05e2\u05d1\u05e8 \u05dc\u05d3\u05e3 \u05d4\u05d1\u05d9\u05ea \"\u05d1\u05e8\u05d5\u05da \u05d1\u05d5\u05d0\u05da\"" },
  { u8"library-opds-feed-all-entries", u8"\u05d4\u05d6\u05e0\u05ea \u05e1\u05e4\u05e8\u05d9\u05d9\u05ea OPDS - \u05db\u05dc \u05d4\u05e8\u05e9\u05d5\u05de\u05d5\u05ea" },
  { u8"library-opds-feed-parameterised", u8"\u05d4\u05d6\u05e0\u05ea \u05e1\u05e4\u05e8\u05d9\u05d9\u05ea OPDS - \u05e8\u05e9\u05d5\u05de\u05d5\u05ea \u05e9\u05ea\u05d5\u05d0\u05de\u05d5\u05ea \u05dc{{#LANG}}\n\u05e9\u05e4\u05d4: {{LANG}} {{/LANG}}{{#CATEGORY}}\n\u05e7\u05d8\u05d2\u05d5\u05e8\u05d9\u05d4: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\n\u05ea\u05d2: {{TAG}} {{/TAG}}{{#Q}}\n\u05e9\u05d0\u05d9\u05dc\u05ea\u05d4: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"\u05d4\u05d5\u05e8\u05d3\u05d4 \u05d1\u05d0\u05de\u05e6\u05e2\u05d5\u05ea \u05e7\u05d9\u05e9\u05d5\u05e8 magnet" },
  { u8"magnet-link-text", u8"\u05e7\u05d9\u05e9\u05d5\u05e8 Magnet" },
  { u8"name", u8"\u05e2\u05d1\u05e8\u05d9\u05ea" },
  { u8"new-404-page-heading", u8"\u05d0\u05d5\u05e4\u05e1. \u05d4\u05d3\u05e3 \u05dc\u05d0 \u05e0\u05de\u05e6\u05d0." },
  { u8"new-404-page-title", u8"\u05d4\u05d3\u05e3 \u05dc\u05d0 \u05e0\u05de\u05e6\u05d0" },
  { u8"no-book-found", u8"\u05d0\u05d9\u05df \u05e1\u05e4\u05e8 \u05e9\u05de\u05ea\u05d0\u05d9\u05dd \u05dc\u05ea\u05e0\u05d0\u05d9\u05dd \u05e9\u05e0\u05d1\u05d7\u05e8\u05d5" },
  { u8"no-query", u8"\u05dc\u05d0 \u05e1\u05d5\u05e4\u05e7\u05d4 \u05e9\u05d0\u05d9\u05dc\u05ea\u05d4." },
  { u8"no-search-results", u8"\u05de\u05e0\u05d5\u05e2 \u05d4\u05d7\u05d9\u05e4\u05d5\u05e9 \u05d1\u05d8\u05e7\u05e1\u05d8 \u05de\u05dc\u05d0 \u05d0\u05d9\u05e0\u05d5 \u05d6\u05de\u05d9\u05df \u05e2\u05d1\u05d5\u05e8 \u05d4\u05ea\u05d5\u05db\u05df \u05d4\u05d6\u05d4." },
  { u8"no-such-book", u8"\u05d0\u05d9\u05df \u05e1\u05e4\u05e8 \u05db\u05d6\u05d4: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u05dc\u05d0 \u05e1\u05d5\u05e4\u05e7 \u05e2\u05e8\u05da \u05dc\u05d0\u05e8\u05d2\u05d5\u05de\u05e0\u05d8 {{ARGUMENT}}" },
  { u8"path-was-not-found", u8"\u05d4\u05e0\u05ea\u05d9\u05d1 \u05d4\u05de\u05d1\u05d5\u05e7\u05e9 \u05dc\u05d0 \u05e0\u05de\u05e6\u05d0:" },
  { u8"powered-by-kiwix-html", u8"\u05de\u05d5\u05e4\u05e2\u05dc \u05e2\u05dc\u05be\u05d9\u05d3\u05d9&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"\u05ea\u05e6\u05d5\u05d2\u05d4 \u05de\u05e7\u05d3\u05d9\u05de\u05d4" },
  { u8"random-article-failure", u8"\u05d0\u05d5\u05d9! \u05dc\u05d0 \u05e2\u05d1\u05d3\u05d4 \u05d1\u05d7\u05d9\u05e8\u05ea \u05e2\u05e8\u05da \u05d0\u05e7\u05e8\u05d0\u05d9 :(" },
  { u8"random-page-button-text", u8"\u05de\u05e2\u05d1\u05e8 \u05dc\u05d3\u05e3 \u05e9\u05e0\u05d1\u05d7\u05e8 \u05d0\u05e7\u05e8\u05d0\u05d9\u05ea" },
  { u8"raw-entry-not-found", u8"\u05dc\u05d0 \u05e0\u05d9\u05ea\u05df \u05dc\u05de\u05e6\u05d5\u05d0 \u05d0\u05ea \u05e8\u05e9\u05d5\u05de\u05ea \u05d4\u05be{{DATATYPE}} \u05d1\u05e9\u05dd {{ENTRY}}" },
  { u8"search", u8"\u05d7\u05d9\u05e4\u05d5\u05e9" },
  { u8"search-result-book-info", u8"\u05de\u05ea\u05d5\u05da {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"\u05ea\u05d5\u05e6\u05d0\u05d5\u05ea <b>{{START}} \u05e2\u05d3 {{END}}</b> \u05de\u05ea\u05d5\u05da <b>{{COUNT}}</b> \u05e2\u05d1\u05d5\u05e8 <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"\u05d7\u05d9\u05e4\u05d5\u05e9: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"\u05d7\u05d9\u05e4\u05d5\u05e9 \u05d0\u05d7\u05e8 \u201a{{{BOOK_TITLE}}}\u2019" },
  { u8"stop-filtering-by-tag", u8"\u05dc\u05d4\u05e4\u05e1\u05d9\u05e7 \u05e1\u05d9\u05e0\u05d5\u05df \u05dc\u05e4\u05d9 \u05d4\u05ea\u05d2 \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"\u05de\u05db\u05d9\u05dc '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"\u05dc\u05e2\u05e9\u05d5\u05ea \u05d7\u05d9\u05e4\u05d5\u05e9 \u05d8\u05e7\u05e1\u05d8 \u05de\u05dc\u05d0 \u05e2\u05d1\u05d5\u05e8 <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"\u05d4\u05ea\u05d5\u05db\u05df \u05e0\u05d8\u05e2\u05df" },
  { u8"too-many-books", u8"\u05e0\u05ea\u05d1\u05e7\u05e9\u05d5 \u05d9\u05d5\u05ea\u05e8 \u05e1\u05e4\u05e8\u05d9\u05dd ({{NB_BOOKS}}) \u05d5\u05d4\u05de\u05d2\u05d1\u05dc\u05d4 \u05d4\u05d9\u05d0 {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"\u05d4\u05d5\u05e8\u05d3\u05d4 \u05d1\u05d0\u05de\u05e6\u05e2\u05d5\u05ea \u05d1\u05d9\u05d8\u05d5\u05e8\u05e0\u05d8" },
  { u8"torrent-download-link-text", u8"\u05d1\u05d9\u05d8\u05d5\u05e8\u05e0\u05d8" },
  { u8"unknown-error", u8"\u05e9\u05d2\u05d9\u05d0\u05d4 \u05d1\u05dc\u05ea\u05d9\u05be\u05d9\u05d3\u05d5\u05e2\u05d4" },
  { u8"url-not-found", u8"\u05d4\u05db\u05ea\u05d5\u05d1\u05ea \u05d4\u05de\u05d1\u05d5\u05e7\u05e9\u05ea \"{{url}}\" \u05dc\u05d0 \u05e0\u05de\u05e6\u05d0\u05d4 \u05d1\u05e9\u05e8\u05ea \u05d4\u05d6\u05d4." },
  { u8"welcome-page-overzealous-filter", u8"\u05d0\u05d9\u05df \u05ea\u05d5\u05e6\u05d0\u05d5\u05ea. \u05d4\u05d0\u05dd <a href=\"{{URL}}\">\u05dc\u05d0\u05e4\u05e1 \u05d0\u05ea \u05d4\u05de\u05e1\u05e0\u05df</a>?" },
  { u8"welcome-to-kiwix-server", u8"\u05d1\u05e8\u05d5\u05da \u05d1\u05d5\u05d0\u05da \u05dc\u05e9\u05e8\u05ea \u05e7\u05d9\u05d5\u05d5\u05d9\u05e7\u05e1" },
  { u8"word-count", u8"{{COUNT}} \u05de\u05d9\u05dc\u05d9\u05dd" }
};


const I18nString string_table_for_hi[] = {
  { u8"400-page-heading", u8"\u0905\u0935\u0948\u0927 \u0906\u0935\u0947\u0926\u0928" },
  { u8"400-page-title", u8"\u0905\u0935\u0948\u0927 \u0906\u0935\u0947\u0926\u0928" },
  { u8"404-page-heading", u8"\u0928\u0939\u0940\u0902 \u092e\u093f\u0932\u093e" },
  { u8"404-page-title", u8"\u0938\u093e\u092e\u0917\u094d\u0930\u0940 \u0928\u0939\u0940\u0902 \u092e\u093f\u0932\u0940" },
  { u8"500-page-heading", u8"\u0906\u0902\u0924\u0930\u093f\u0915 \u0938\u0930\u094d\u0935\u0930 \u0924\u094d\u0930\u0941\u091f\u093f" },
  { u8"500-page-title", u8"\u0906\u0902\u0924\u0930\u093f\u0915 \u0938\u0930\u094d\u0935\u0930 \u0924\u094d\u0930\u0941\u091f\u093f" },
  { u8"book-category.other", u8"\u0905\u0928\u094d\u092f" },
  { u8"book-category.wikibooks", u8"\u0935\u093f\u0915\u093f\u092a\u0941\u0938\u094d\u0924\u0915" },
  { u8"book-category.wikinews", u8"\u0935\u093f\u0915\u093f\u0938\u092e\u093e\u091a\u093e\u0930" },
  { u8"book-category.wikipedia", u8"\u0935\u093f\u0915\u093f\u092a\u0940\u0921\u093f\u092f\u093e" },
  { u8"book-category.wikiquote", u8"\u0935\u093f\u0915\u093f\u0938\u0942\u0915\u094d\u0924\u093f" },
  { u8"book-category.wikisource", u8"\u0935\u093f\u0915\u093f\u0938\u094d\u0930\u094b\u0924" },
  { u8"book-category.wikispecies", u8"\u0935\u093f\u0915\u093f\u092a\u094d\u0930\u091c\u093e\u0924\u093f" },
  { u8"book-category.wikiversity", u8"\u0935\u093f\u0915\u093f\u0935\u093f\u0936\u094d\u0935\u0935\u093f\u0926\u094d\u092f\u093e\u0932\u092f" },
  { u8"book-category.wikivoyage", u8"\u0935\u093f\u0915\u093f\u092f\u093e\u0924\u094d\u0930\u093e" },
  { u8"book-category.wiktionary", u8"\u0935\u093f\u0915\u093f\u0915\u094b\u0936" },
  { u8"book-filtering-all-categories", u8"\u0938\u092c \u0935\u0930\u094d\u0917" },
  { u8"book-filtering-all-languages", u8"\u0938\u092d\u0940 \u092d\u093e\u0937\u093e\u090f\u0901" },
  { u8"confusion-of-tongues", u8"\u0935\u093f\u092d\u093f\u0928\u094d\u0928 \u092d\u093e\u0937\u093e\u0913\u0902 \u0915\u0940 \u0926\u094b \u092f\u093e \u0926\u094b \u0938\u0947 \u0905\u0927\u093f\u0915 \u092a\u0941\u0938\u094d\u0924\u0915\u0947\u0902 \u0916\u094b\u091c \u092e\u0947\u0902 \u092d\u093e\u0917 \u0932\u0947\u0902\u0917\u0940, \u091c\u093f\u0938\u0938\u0947 \u092d\u094d\u0930\u092e\u093f\u0924 \u0915\u0930\u0928\u0947 \u0935\u093e\u0932\u0947 \u092a\u0930\u093f\u0923\u093e\u092e \u092e\u093f\u0932 \u0938\u0915\u0924\u0947 \u0939\u0948\u0902\u0964" },
  { u8"count-of-matching-books", u8"{{COUNT}} \u092a\u0941\u0938\u094d\u0924\u0915/\u092a\u0941\u0938\u094d\u0924\u0915\u0947\u0902" },
  { u8"direct-download-alt-text", u8"\u092a\u094d\u0930\u0924\u094d\u092f\u0915\u094d\u0937\u0924: \u0921\u093e\u0909\u0928\u0932\u094b\u0921" },
  { u8"direct-download-link-text", u8"\u092a\u094d\u0930\u0924\u094d\u092f\u0915\u094d\u0937" },
  { u8"download", u8"\u0921\u093e\u0909\u0928\u0932\u094b\u0921" },
  { u8"download-links-heading", u8"<b><i>{{BOOK_TITLE}}</i></b> \u0915\u0947 \u0932\u093f\u090f \u0921\u093e\u0909\u0928\u0932\u094b\u0921 \u0932\u093f\u0902\u0915" },
  { u8"download-links-title", u8"\u092a\u0941\u0938\u094d\u0924\u0915 \u0921\u093e\u0909\u0928\u0932\u094b\u0921 \u0915\u0930\u0947\u0902" },
  { u8"filter-by-tag", u8"\u091f\u0948\u0917 \"{{TAG}}\" \u0926\u094d\u0935\u093e\u0930\u093e \u092b\u093c\u093f\u0932\u094d\u091f\u0930 \u0915\u0930\u0947\u0902" },
  { u8"fulltext-search-unavailable", u8"\u092a\u0942\u0930\u094d\u0923\u092a\u093e\u0920 \u0916\u094b\u091c \u0905\u0928\u0941\u092a\u0932\u092c\u094d\u0927" },
  { u8"hash-download-alt-text", u8"\u0939\u0948\u0936 \u0921\u093e\u0909\u0928\u0932\u094b\u0921 \u0915\u0930\u0947\u0902" },
  { u8"hash-download-link-text", u8"\u0936\u093e256 \u0939\u0948\u0936" },
  { u8"home-button-text", u8"'{{BOOK_TITLE}}' \u0915\u0947 \u092e\u0941\u0916\u094d\u092f \u092a\u0943\u0937\u094d\u0920 \u092a\u0930 \u091c\u093e\u090f\u0901" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u0915\u091a\u094d\u091a\u0940 \u0938\u093e\u092e\u0917\u094d\u0930\u0940 \u0915\u0947 \u0932\u093f\u090f \u0935\u0948\u0927 \u0905\u0928\u0941\u0930\u094b\u0927 \u0928\u0939\u0940\u0902 \u0939\u0948\u0964" },
  { u8"library-button-text", u8"\u0938\u094d\u0935\u093e\u0917\u0924 \u092a\u0943\u0937\u094d\u0920 \u092a\u0930 \u091c\u093e\u090f\u0901" },
  { u8"library-opds-feed-all-entries", u8"\u0932\u093e\u0907\u092c\u094d\u0930\u0947\u0930\u0940 \u0913\u092a\u0940\u0921\u0940\u090f\u0938 \u092b\u093c\u0940\u0921 - \u0938\u092d\u0940 \u092a\u094d\u0930\u0935\u093f\u0937\u094d\u091f\u093f\u092f\u093e\u0901" },
  { u8"library-opds-feed-parameterised", u8"\u0932\u093e\u0907\u092c\u094d\u0930\u0947\u0930\u0940 \u0913\u092a\u0940\u0921\u0940\u090f\u0938 \u092b\u093c\u0940\u0921 - \u092e\u093f\u0932\u093e\u0928 \u0935\u093e\u0932\u0940 \u092a\u094d\u0930\u0935\u093f\u0937\u094d\u091f\u093f\u092f\u093e\u0901 {{#LANG}}\n\u092d\u093e\u0937\u093e: {{LANG}} {/LANG}}{{#CATEGORY}}\n\u0936\u094d\u0930\u0947\u0923\u0940: {{CATEGORY}} {/CATEGORY}} {{#TAG}}\n\u091f\u0948\u0917: {{TAG}} {{/TAG}}{{#Q}}\n\u0915\u094d\u0935\u0947\u0930\u0940: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"MAGNET \u0921\u093e\u0909\u0928\u0932\u094b\u0921 \u0915\u0930\u0947\u0902" },
  { u8"magnet-link-text", u8"MAGNET \u0932\u093f\u0902\u0915" },
  { u8"name", u8"\u0939\u093f\u0928\u094d\u0926\u0940" },
  { u8"no-book-found", u8"\u0915\u094b\u0908 \u092d\u0940 \u092a\u0941\u0938\u094d\u0924\u0915 \u091a\u092f\u0928 \u092e\u093e\u0928\u0926\u0902\u0921 \u0938\u0947 \u092e\u0947\u0932 \u0928\u0939\u0940\u0902 \u0916\u093e\u0924\u0940" },
  { u8"no-query", u8"\u0915\u094b\u0908 \u092a\u094d\u0930\u0936\u094d\u0928 \u0928\u0939\u0940\u0902 \u0926\u093f\u092f\u093e \u0917\u092f\u093e." },
  { u8"no-search-results", u8"\u0907\u0938 \u0938\u093e\u092e\u0917\u094d\u0930\u0940 \u0915\u0947 \u0932\u093f\u090f \u092a\u0942\u0930\u094d\u0923\u092a\u093e\u0920 \u0916\u094b\u091c \u0907\u0902\u091c\u0928 \u0909\u092a\u0932\u092c\u094d\u0927 \u0928\u0939\u0940\u0902 \u0939\u0948\u0964" },
  { u8"no-such-book", u8"\u0910\u0938\u0940 \u0915\u094b\u0908 \u0915\u093f\u0924\u093e\u092c \u0928\u0939\u0940\u0902: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u0924\u0930\u094d\u0915 \u0915\u0947 \u0932\u093f\u090f \u0915\u094b\u0908 \u092e\u0942\u0932\u094d\u092f \u092a\u094d\u0930\u0926\u093e\u0928 \u0928\u0939\u0940\u0902 \u0915\u093f\u092f\u093e \u0917\u092f\u093e {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"<a href=\"https://kiwix.org\">\u0915\u093f\u0935\u093f\u0915\u094d\u0938</a> \u0926\u094d\u0935\u093e\u0930\u093e \u0938\u0902\u091a\u093e\u0932\u093f\u0924" },
  { u8"preview-book", u8"\u092a\u0942\u0930\u094d\u0935\u093e\u0935\u0932\u094b\u0915\u0928" },
  { u8"random-article-failure", u8"\u0909\u092b\u093c! \u090f\u0915 \u092f\u093e\u0926\u0943\u091a\u094d\u091b\u093f\u0915 \u0932\u0947\u0916 \u091a\u0941\u0928\u0928\u0947 \u092e\u0947\u0902 \u0935\u093f\u092b\u0932 :(" },
  { u8"random-page-button-text", u8"\u092f\u093e\u0926\u0943\u091a\u094d\u091b\u093f\u0915 \u0930\u0942\u092a \u0938\u0947 \u091a\u092f\u0928\u093f\u0924 \u092a\u0943\u0937\u094d\u0920 \u092a\u0930 \u091c\u093e\u090f\u0901" },
  { u8"raw-entry-not-found", u8"{{DATATYPE}} \u092a\u094d\u0930\u0935\u093f\u0937\u094d\u091f\u093f {{ENTRY}} \u0928\u0939\u0940\u0902 \u092e\u093f\u0932 \u0938\u0915\u0940" },
  { u8"search", u8"\u0916\u094b\u091c\u0947\u0902" },
  { u8"searchbox-tooltip", u8"'{{BOOK_TITLE}}' \u0916\u094b\u091c\u0947\u0902" },
  { u8"stop-filtering-by-tag", u8"\"{{TAG}}\" \u091f\u0948\u0917 \u0926\u094d\u0935\u093e\u0930\u093e \u092b\u093c\u093f\u0932\u094d\u091f\u0930 \u0915\u0930\u0928\u093e \u092c\u0902\u0926 \u0915\u0930\u0947\u0902" },
  { u8"suggest-full-text-search", u8"\u091c\u093f\u0938\u092e\u0947\u0902 '{{{SEARCH_TERMS}}}' \u0936\u093e\u092e\u093f\u0932 \u0939\u0948..." },
  { u8"suggest-search", u8"<a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a> \u0915\u0947 \u0932\u093f\u090f \u092a\u0942\u0930\u094d\u0923 \u092a\u093e\u0920 \u0916\u094b\u091c \u0915\u0930\u0947\u0902" },
  { u8"too-many-books", u8"\u092c\u0939\u0941\u0924 \u0938\u093e\u0930\u0940 \u092a\u0941\u0938\u094d\u0924\u0915\u094b\u0902 \u0915\u093e \u0905\u0928\u0941\u0930\u094b\u0927 \u0915\u093f\u092f\u093e \u0917\u092f\u093e \u0939\u0948 ({{NB_BOOKS}}) \u091c\u0939\u093e\u0902 \u0938\u0940\u092e\u093e {{LIMIT}} \u0939\u0948" },
  { u8"torrent-download-alt-text", u8"\u091f\u094b\u0930\u0947\u0902\u091f \u0921\u093e\u0909\u0928\u0932\u094b\u0921 \u0915\u0930\u0947\u0902" },
  { u8"torrent-download-link-text", u8"\u091f\u094b\u0930\u0947\u0902\u091f \u092b\u093c\u093e\u0907\u0932" },
  { u8"url-not-found", u8"\u0905\u0928\u0941\u0930\u094b\u0927\u093f\u0924 URL \"{{url}}\" \u0907\u0938 \u0938\u0930\u094d\u0935\u0930 \u092a\u0930 \u0928\u0939\u0940\u0902 \u092e\u093f\u0932\u093e\u0964" },
  { u8"welcome-page-overzealous-filter", u8"\u0915\u094b\u0908 \u092a\u0930\u093f\u0923\u093e\u092e \u0928\u0939\u0940\u0902\u0964 \u0915\u094d\u092f\u093e \u0906\u092a <a href=\"{{URL}}\">\u092b\u093c\u093f\u0932\u094d\u091f\u0930 \u0930\u0940\u0938\u0947\u091f \u0915\u0930\u0928\u093e</a> \u091a\u093e\u0939\u0947\u0902\u0917\u0947?" },
  { u8"welcome-to-kiwix-server", u8"\u0915\u0940\u0935\u093f\u0915\u094d\u0938 \u0938\u0930\u094d\u0935\u0930 \u092e\u0947\u0902 \u0906\u092a\u0915\u093e \u0938\u094d\u0935\u093e\u0917\u0924 \u0939\u0948" }
};


const I18nString string_table_for_hu[] = {
  { u8"400-page-heading", u8"\u00c9rv\u00e9nytelen k\u00e9r\u00e9s" },
  { u8"400-page-title", u8"\u00c9rv\u00e9nytelen k\u00e9r\u00e9s" },
  { u8"404-advice.p1", u8"A keresett tartalom tov\u00e1bbra is el\u00e9rhet\u0151 lehet, de el\u0151fordulhat, hogy m\u00e1s helyen tal\u00e1lhat\u00f3 a ZIM-f\u00e1jlon bel\u00fcl." },
  { u8"404-img-text", u8"Nem tal\u00e1lhat\u00f3!" },
  { u8"404-page-heading", u8"Nem tal\u00e1lhat\u00f3" },
  { u8"404-page-title", u8"A tartalom nem tal\u00e1lhat\u00f3" },
  { u8"book-category.other", u8"Egy\u00e9b" },
  { u8"book-category.wikibooks", u8"Wikik\u00f6nyvek" },
  { u8"book-category.wikinews", u8"Wikih\u00edrek" },
  { u8"book-category.wikipedia", u8"Wikip\u00e9dia" },
  { u8"book-category.wikiquote", u8"Wikid\u00e9zet" },
  { u8"book-category.wikisource", u8"Wikiforr\u00e1s" },
  { u8"book-category.wikispecies", u8"Wikifajok" },
  { u8"book-category.wikiversity", u8"Wikiegyetem" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wikisz\u00f3t\u00e1r" },
  { u8"download", u8"Let\u00f6lt\u00e9s" },
  { u8"download-links-heading", u8"Let\u00f6lt\u00e9si hivatkoz\u00e1sok ehhez: <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"K\u00f6nyv let\u00f6lt\u00e9se" },
  { u8"hash-download-alt-text", u8"SHA-256 f\u00e1jl-ellen\u0151rz\u0151\u00f6sszeg megjelen\u00edt\u00e9se" },
  { u8"hash-download-link-text", u8"SHA-256 ellen\u0151rz\u0151\u00f6sszeg" },
  { u8"name", u8"Magyar" },
  { u8"new-404-page-heading", u8"Hopp\u00e1! Az oldal nem tal\u00e1lhat\u00f3." },
  { u8"new-404-page-title", u8"Az oldal nem tal\u00e1lhat\u00f3" },
  { u8"path-was-not-found", u8"A k\u00e9rt \u00fatvonal nem tal\u00e1lhat\u00f3:" },
  { u8"preview-book", u8"El\u0151n\u00e9zet" },
  { u8"search", u8"Keres\u00e9s" },
  { u8"text-loading-content", u8"Tartalom bet\u00f6lt\u00e9se" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Ismeretlen hiba" },
  { u8"welcome-to-kiwix-server", u8"\u00dcdv\u00f6zli a Kiwix-kiszolg\u00e1l\u00f3!" }
};


const I18nString string_table_for_hy[] = {
  { u8"400-page-heading", u8"\u0531\u0576\u057e\u0561\u057e\u0565\u0580 \u0570\u0561\u0580\u0581\u0578\u0582\u0574" },
  { u8"400-page-title", u8"\u0531\u0576\u057e\u0561\u057e\u0565\u0580 \u0570\u0561\u0580\u0581\u0578\u0582\u0574" },
  { u8"404-page-heading", u8"\u054d\u056d\u0561\u056c \u0570\u0561\u057d\u0581\u0565" },
  { u8"404-page-title", u8"\u054d\u056d\u0561\u056c \u0570\u0561\u057d\u0581\u0565" },
  { u8"500-img-text", u8"\u0537\u057b\u0568 \u0579\u056b \u0561\u0577\u056d\u0561\u057f\u0578\u0582\u0574" },
  { u8"book-category.other", u8"\u0531\u0575\u056c" },
  { u8"book-category.wikibooks", u8"\u054e\u056b\u0584\u056b\u0563\u0580\u0584\u0565\u0580" },
  { u8"book-category.wikinews", u8"\u054e\u056b\u0584\u056b\u056c\u0578\u0582\u0580\u0565\u0580" },
  { u8"book-category.wikipedia", u8"\u054e\u056b\u0584\u056b\u057a\u0565\u0564\u056b\u0561" },
  { u8"book-category.wikiquote", u8"\u054e\u056b\u0584\u056b\u0584\u0561\u0572\u057e\u0561\u056e\u0584" },
  { u8"book-category.wikisource", u8"\u054e\u056b\u0584\u056b\u0564\u0561\u0580\u0561\u0576" },
  { u8"book-category.wikispecies", u8"\u054e\u056b\u0584\u056b\u0581\u0565\u0572\u0565\u0580" },
  { u8"book-category.wikiversity", u8"\u054e\u056b\u0584\u056b\u056c\u057d\u0561\u0580\u0561\u0576" },
  { u8"book-category.wikivoyage", u8"\u054e\u056b\u0584\u056b\u0573\u0561\u0574\u0583\u0578\u0580\u0564" },
  { u8"book-category.wiktionary", u8"\u054e\u056b\u0584\u056b\u0562\u0561\u057c\u0561\u0580\u0561\u0576" },
  { u8"book-filtering-all-categories", u8"\u0532\u0578\u056c\u0578\u0580 \u056f\u0561\u057f\u0565\u0563\u0578\u0580\u056b\u0561\u0576\u0565\u0580" },
  { u8"home-button-text", u8"\u0534\u0565\u057a\u056b '{{BOOK_TITLE}}'\u058a\u056b \u0563\u056c\u056d\u0561\u057e\u0578\u0580 \u0567\u057b\u0568" },
  { u8"library-button-text", u8"\u0533\u0580\u0561\u0564\u0561\u0580\u0561\u0576\u056b \u0567\u057b" },
  { u8"name", u8"\u0540\u0561\u0575\u0565\u0580\u0565\u0576" },
  { u8"no-such-book", u8"\u0533\u056b\u0580\u0584\u0568 \u0562\u0561\u0581\u0561\u056f\u0561\u0575\u0578\u0582\u0574 \u0567\u055d {{BOOK_NAME}}" },
  { u8"random-page-button-text", u8"\u0532\u0561\u0581\u0565\u056c \u057a\u0561\u057f\u0561\u0570\u0561\u056f\u0561\u0576 \u0567\u057b" },
  { u8"searchbox-tooltip", u8"\u0548\u0580\u0578\u0576\u0565\u056c '{{BOOK_TITLE}}'\u058a\u0578\u0582\u0574" },
  { u8"suggest-full-text-search", u8"\u0578\u0580\u0578\u0576\u0565\u056c '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"\u0548\u0580\u0578\u0576\u0565\u056c <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"url-not-found", u8"\u054d\u056d\u0561\u056c \u0570\u0561\u057d\u0581\u0565\u055d {{url}}" }
};


const I18nString string_table_for_ia[] = {
  { u8"400-page-heading", u8"Requesta invalide" },
  { u8"400-page-title", u8"Requesta invalide" },
  { u8"404-advice.p1", u8"Le contento que tu cerca pote esser ancora disponibile, ma illo pote esser situate alterubi in le file ZIM." },
  { u8"404-advice.p2", u8"Per favor:" },
  { u8"404-advice.p3", u8"Tenta usar le function de recerca pro trovar le contento desirate" },
  { u8"404-advice.p4", u8"Cerca parolas-clave o titulos associate al information que tu cerca" },
  { u8"404-advice.p5", u8"Iste approche deberea adjutar te a localisar le contento desirate, mesmo si le ligamine original non functiona correctemente." },
  { u8"404-img-text", u8"Non trovate!" },
  { u8"404-page-heading", u8"Non trovate" },
  { u8"404-page-title", u8"Contento non trovate" },
  { u8"500-img-text", u8"Le pagina non functiona" },
  { u8"500-page-heading", u8"Le pagina non functiona." },
  { u8"500-page-text", u8"Le percurso requestate non pote esser livrate correctemente:" },
  { u8"500-page-title", u8"Error interne del servitor" },
  { u8"book-category.other", u8"Altere" },
  { u8"book-category.wikibooks", u8"Wikilibros" },
  { u8"book-category.wikinews", u8"Wikinovas" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversitate" },
  { u8"book-category.wikivoyage", u8"Wikiviage" },
  { u8"book-category.wiktionary", u8"Wiktionario" },
  { u8"book-filtering-all-categories", u8"Tote le categorias" },
  { u8"book-filtering-all-languages", u8"Tote le linguas" },
  { u8"caution-warning", u8"Attention!" },
  { u8"confusion-of-tongues", u8"Duo o plus libros in differente linguas participarea in le recerca, lo que pote menar a resultatos confuse." },
  { u8"count-of-matching-books", u8"{{COUNT}} libro(s)" },
  { u8"direct-download-alt-text", u8"Discargamento directe per HTTP(S)" },
  { u8"direct-download-link-text", u8"Directe" },
  { u8"download", u8"Discargar" },
  { u8"download-links-heading", u8"Discargar ligamines pro <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Discargar libro" },
  { u8"empty-search-results-page-header", u8"Necun resultato ha essite trovate pro <b>\u201c{{{SEARCH_PATTERN}}}\u201d</b>" },
  { u8"external-link-advice.p1", u8"Le ligamine al qual tu tenta acceder non face parte de nostre pacchetto de uso foras de linea e require un connexion a internet." },
  { u8"external-link-advice.p2", u8"Si tu pote connecter te al rete, tu pote tentar aperir le ligamine." },
  { u8"external-link-advice.p3", u8"Si non, tu pote retornar al contento de uso foras de linea de tu ZIM usante le button Retro del navigator." },
  { u8"external-link-detected", u8"Ligamine externe detegite" },
  { u8"external-link-intro", u8"Tu es sur le puncto de quitar le lector ZIM de Kiwix pro connecter te al rete e visitar" },
  { u8"filter-by-tag", u8"Filtrar per etiquetta \u201c{{{TAG}}}\u201d" },
  { u8"fulltext-search-unavailable", u8"Le recerca in texto complete es indisponibile" },
  { u8"hash-download-alt-text", u8"Monstrar le summa de controlo SHA-256 del file" },
  { u8"hash-download-link-text", u8"Summa de controlo SHA-256" },
  { u8"home-button-text", u8"Ir al pagina principal de \u2018{{{BOOK_TITLE}}}\u2019" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} non es un requesta valide pro contento brute." },
  { u8"invalid-request", u8"Le URL requestate \u201c{{{url}}}\u201d non es un requesta valide." },
  { u8"library-button-text", u8"Ir al pagina de benvenita" },
  { u8"library-opds-feed-all-entries", u8"Fluxo OPDS del bibliotheca \u2013 Tote le entratas" },
  { u8"library-opds-feed-parameterised", u8"Fluxo OPDS del bibliotheca \u2013 Entratas correspondente a {{#LANG}}\nLingua {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategoria: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nEtiquetta: {{TAG}} {{/TAG}}{{#Q}}\nConsulta: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Discargar con ligamine Magnet" },
  { u8"magnet-link-text", u8"Ligamine Magnet" },
  { u8"name", u8"interlingua" },
  { u8"new-404-page-heading", u8"Pagina non trovate." },
  { u8"new-404-page-title", u8"Pagina non trovate" },
  { u8"no-book-found", u8"Necun libro corresponde al criterios de selection" },
  { u8"no-query", u8"Necun consulta fornite." },
  { u8"no-search-results", u8"Le motor de recerca in texto complete non es disponibile pro iste contento." },
  { u8"no-such-book", u8"Necun tal libro: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Necun valor fornite pro le argumento {{ARGUMENT}}" },
  { u8"path-was-not-found", u8"Le percurso requestate non ha essite trovate:" },
  { u8"powered-by-kiwix-html", u8"Actionate per&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Previsualisation" },
  { u8"random-article-failure", u8"Ups! Non poteva eliger un articulo aleatori :(" },
  { u8"random-page-button-text", u8"Ir a un pagina seligite aleatorimente" },
  { u8"raw-entry-not-found", u8"Non pote trovar le entrata {{ENTRY}} del typo {{DATATYPE}}" },
  { u8"search", u8"Cercar" },
  { u8"search-result-book-info", u8"de {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Resultatos <b>{{START}}-{{END}}</b> de <b>{{COUNT}}</b> pro <b>\u201c{{{SEARCH_PATTERN}}}\u201d</b>" },
  { u8"search-results-page-title", u8"Cercar: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Cercar in \u2018{{{BOOK_TITLE}}}\u2019" },
  { u8"stop-filtering-by-tag", u8"Non plus filtrar per etiquetta \u201c{{{TAG}}}\u201d" },
  { u8"suggest-full-text-search", u8"continente '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Facer un recerca in texto complete de <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Carga contento" },
  { u8"too-many-books", u8"Troppo de libros demandate ({{NB_BOOKS}}); le limite es {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Discargar per medio de BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Error incognite" },
  { u8"url-not-found", u8"Le URL requestate \u201c{{url}}\u201d non ha essite trovate sur iste servitor." },
  { u8"welcome-page-overzealous-filter", u8"Nulle resultato. Vole tu <a href=\"{{URL}}\">reinitialisar le filtro</a>?" },
  { u8"welcome-to-kiwix-server", u8"Benvenite al servitor Kiwix" },
  { u8"word-count", u8"{{COUNT}} parolas" }
};


const I18nString string_table_for_id[] = {
  { u8"400-page-heading", u8"Permintaan tidak sah" },
  { u8"400-page-title", u8"Permintaan tidak sah" },
  { u8"404-page-heading", u8"Tidak Ditemukan" },
  { u8"404-page-title", u8"Konten tidak ditemukan" },
  { u8"500-page-heading", u8"Aduh. Halaman tidak bekerja." },
  { u8"500-page-text", u8"Jalur yang diminta tidak dapat diantar dengan benar:" },
  { u8"500-page-title", u8"Galat Peladen Internal" },
  { u8"book-category.other", u8"Lainnya" },
  { u8"book-category.wikibooks", u8"Wikibuku" },
  { u8"book-category.wikinews", u8"Wikiberita" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikikutip" },
  { u8"book-category.wikisource", u8"Wikisumber" },
  { u8"book-category.wikispecies", u8"Wikispesies" },
  { u8"book-category.wikiversity", u8"Wikiversitas" },
  { u8"book-category.wikivoyage", u8"Wikiwisata" },
  { u8"book-category.wiktionary", u8"Wikikamus" },
  { u8"book-filtering-all-categories", u8"Semua kategori" },
  { u8"book-filtering-all-languages", u8"Semua bahasa" },
  { u8"confusion-of-tongues", u8"Dua buku atau lebih dalam bahasa berbeda dapat muncul dalam hasil pencarian, yang dapat memicu hasil yang membingungkan." },
  { u8"count-of-matching-books", u8"{{COUNT}} buku" },
  { u8"direct-download-alt-text", u8"Unduh langsung melalui HTTP(S)" },
  { u8"direct-download-link-text", u8"Langsung" },
  { u8"download", u8"Unduh" },
  { u8"download-links-heading", u8"Tautan unduhan untuk <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Unduh buku" },
  { u8"empty-search-results-page-header", u8"Tidak ada hasil yang ditemukan untuk <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"filter-by-tag", u8"Saring berdasarkan tanda \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"Pencarian teks lengkap tidak tersedia" },
  { u8"hash-download-alt-text", u8"Tampilkan checksum berkas SHA-256" },
  { u8"hash-download-link-text", u8"Checksum SHA-256" },
  { u8"home-button-text", u8"Buka halaman utama '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} bukan permintaan yang sah untuk konten mentah." },
  { u8"invalid-request", u8"URL yang diminta \"{{{url}}}\" bukan permintaan yang sah." },
  { u8"library-button-text", u8"Pergi ke halaman selamat datang" },
  { u8"library-opds-feed-all-entries", u8"Umpan OPDS Perpustakaan - Semua entri" },
  { u8"library-opds-feed-parameterised", u8"Umpan OPDS Perpustakaan - entri yang cocok dengan {{#LANG}}\nBahasa: {{LANG}} {{/LANG}}{{#CATEGORY}}\nKategori: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTanda: {{TAG}} {{/TAG}}{{#Q}}\nKueri: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Unduh melalui tautan Magnet" },
  { u8"magnet-link-text", u8"Tautan magnet" },
  { u8"name", u8"Bahasa Inggris" },
  { u8"no-book-found", u8"Tidak ada buku yang sesuai kriteria yang dipilih" },
  { u8"no-query", u8"Tidak ada kueri yang diberikan." },
  { u8"no-search-results", u8"Mesin pencari teks lengkap tidak tersedia untuk konten ini." },
  { u8"no-such-book", u8"Tidak ada buku seperti ini: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Tidak ada nilai yang diberikan untuk argumen {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Didukung oleh <a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Pratayang" },
  { u8"random-article-failure", u8"Waduh! Gagal memilih artikel acak :(" },
  { u8"random-page-button-text", u8"Buka halaman yang dipilih secara acak" },
  { u8"raw-entry-not-found", u8"Tidak dapat menemukan entri {{DATATYPE}} {{ENTRY}}" },
  { u8"search", u8"Cari" },
  { u8"search-result-book-info", u8"dari {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Hasil <b>{{START}}-{{END}}</b> dari <b>{{COUNT}}</b> untuk <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Pencarian: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Cari '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Hentikan penyaringan berdasarkan tanda \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"mengandung '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Lakukan pencarian teks lengkap untuk <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Memuat Konten" },
  { u8"too-many-books", u8"Terlalu banyak buku yang diminta ({{NB_BOOKS}}), batasnya adalah {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Unduh melalui BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Kesalahan yang tidak diketahui" },
  { u8"url-not-found", u8"URL yang diminta \"{{url}}\" tidak ditemukan di peladen ini." },
  { u8"welcome-page-overzealous-filter", u8"Tidak ada hasil. Apakah Anda ingin <a href=\"{{URL}}\">mengatur ulang filter</a>?" },
  { u8"welcome-to-kiwix-server", u8"Selamat datang di Peladen Kiwix" },
  { u8"word-count", u8"{{COUNT}} kata" }
};


const I18nString string_table_for_ig[] = {
  { u8"400-page-heading", u8"Ar\u1ecbr\u1ecb\u1ecd na-ezighi ezi" },
  { u8"400-page-title", u8"Ar\u1ecbr\u1ecb\u1ecd na-ezighi ezi" },
  { u8"404-page-heading", u8"Ah\u1ee5gh\u1ecb" },
  { u8"404-page-title", u8"Ah\u1ee5gh\u1ecb \u1ecdd\u1ecbnaya" },
  { u8"500-page-heading", u8"Mperi Sava Ime" },
  { u8"500-page-text", u8"Enwere mperi ihe nkesa d\u1ecb n'ime. \u1ecc d\u1ecb any\u1ecb nwute na nke ah\u1ee5 :/" },
  { u8"500-page-title", u8"Mperi Sava Ime" },
  { u8"book-filtering-all-categories", u8"Nkeji niile" },
  { u8"book-filtering-all-languages", u8"As\u1ee5s\u1ee5 niile" },
  { u8"confusion-of-tongues", u8"Akw\u1ee5kw\u1ecd ab\u1ee5\u1ecd ma \u1ecd b\u1ee5 kar\u1ecba n'as\u1ee5s\u1ee5 d\u1ecb iche iche ga-esonye na nch\u1ecd, nke nwere ike ibute nsonaaz\u1ee5 mgbagwoju anya." },
  { u8"count-of-matching-books", u8"akw\u1ee5kw\u1ecd {{COUNT}}" },
  { u8"direct-download-alt-text", u8"nbudata ozugbo" },
  { u8"direct-download-link-text", u8"Gosi" },
  { u8"download", u8"Budata" },
  { u8"download-links-heading", u8"Budata njik\u1ecd maka <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Budata akw\u1ee5kw\u1ecd" },
  { u8"empty-search-results-page-header", u8"\u1eccnwegh\u1ecb r\u1ecbz\u1ecdlt ah\u1ee5r\u1ee5 maka <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"filter-by-tag", u8"Wep\u1ee5ta site na mkpado \"{{TAG}}\"" },
  { u8"fulltext-search-unavailable", u8"\u1eccch\u1ecbch\u1ecd ederede zuru ezu ad\u1ecbgh\u1ecb" },
  { u8"hash-download-alt-text", u8"budata hash" },
  { u8"hash-download-link-text", u8"Sha256 hash" },
  { u8"home-button-text", u8"Gaa na isi ibe nke '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} ab\u1ee5gh\u1ecb ar\u1ecbr\u1ecb\u1ecd ziri ezi maka \u1ecdd\u1ecbnaya raw." },
  { u8"invalid-request", u8"Ar\u1ecbr\u1ecb\u1ecd gbasara URL \"{{{url}}}\" e zighi ezi." },
  { u8"library-button-text", u8"Gaa na ibe nnabata" },
  { u8"library-opds-feed-all-entries", u8"\u1eccb\u00e1 akw\u1ee5kw\u1ecd OPDS Feed - Ihe niile" },
  { u8"library-opds-feed-parameterised", u8"\u1eccb\u00e1 akw\u1ee5kw\u1ecd OPDS nri - ndenye dabara na {{#LANG}}\nAs\u1ee5s\u1ee5: {{LANG}} {{/LANG}}{{#CATEGORY}}\n Kategori: {{CATEGORY}} {{/CATEGORY}} {{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\n Aj\u1ee5j\u1ee5: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"ibudata magnet" },
  { u8"magnet-link-text", u8"Njik\u1ecd magnet" },
  { u8"name", u8"Bekee" },
  { u8"no-book-found", u8"\u1ecc nwegh\u1ecb akw\u1ee5kw\u1ecd dabara na nh\u1ecdp\u1ee5ta nh\u1ecdr\u1ecd" },
  { u8"no-query", u8"\u1eccnwegh\u1ecb aj\u1ee5j\u1ee5 enyere." },
  { u8"no-search-results", u8"Igwe nch\u1ecdta ederede zuru oke ad\u1ecbgh\u1ecb maka \u1ecdd\u1ecbnaya a." },
  { u8"no-such-book", u8"Enwegh\u1ecb akw\u1ee5kw\u1ecd d\u1ecb ot\u00fa a: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u1ecc nwegh\u1ecb uru enyere maka ar\u1ee5m\u1ee5ka {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"<a href=\"https://kiwix.org\">Kiwix</a> kwadoro ya" },
  { u8"preview-book", u8"Ziwe nkirima\u00e0t\u1ee5\u0300" },
  { u8"random-article-failure", u8"Ee! \u1ecah\u1ecdr\u1ecd ak\u1ee5k\u1ecd enwegh\u1ecb usoro :(" },
  { u8"random-page-button-text", u8"Gaa na ibe ah\u1ecdp\u1ee5tara enwegh\u1ecb usoro" },
  { u8"raw-entry-not-found", u8"Enwegh\u1ecb ike \u1ecbch\u1ecdta ntinye {{DATATYPE}} {{ENTRY}}" },
  { u8"search", u8"Ch\u1ecd\u1ecd" },
  { u8"search-result-book-info", u8"sitere na {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"R\u1ecbz\u1ecdlt ga <b>{{START}}-{{END}}</b> nke <b>{{COUNT}}</b> maka <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Ch\u1ecd\u1ecd: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Ch\u1ecd\u1ecd '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Kw\u1ee5s\u1ecb nzacha site na mkpado \"{{TAG}}\"" },
  { u8"suggest-full-text-search", u8"nwere {{{SEARCH_TERMS}}}'" },
  { u8"suggest-search", u8"Mee \u1ecdch\u1ee5ch\u1ecd ederede zuru oke maka <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Ar\u1ecbr\u1ecb\u1ecd \u1ecdt\u1ee5t\u1ee5 akw\u1ee5kw\u1ecd ({{NB_BOOKS}}) ebe oke b\u1ee5 {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Budata torrent" },
  { u8"torrent-download-link-text", u8" fa\u1ecbl\u1ee5 nke Torrent" },
  { u8"unknown-error", u8"amagh\u1ecb m njehie" },
  { u8"url-not-found", u8"Ah\u1ee5gh\u1ecb URL a r\u1ecb\u1ecdr\u1ecd \"{{url}}\" na nkesa a." },
  { u8"welcome-page-overzealous-filter", u8"Enwegh\u1ecb nsonaaz\u1ee5. \u1ecc ga-amas\u1ecb g\u1ecb <a href=\"{{URL}}\">\u1ecbt\u1ecdghar\u1ecba nzacha</a> ?" },
  { u8"welcome-to-kiwix-server", u8"Nabata na Kiwix Server" },
  { u8"word-count", u8"Okwu {{COUNT}}" }
};


const I18nString string_table_for_it[] = {
  { u8"400-page-heading", u8"Richiesta non valida" },
  { u8"400-page-title", u8"Richiesta non valida" },
  { u8"404-img-text", u8"Non trovato!" },
  { u8"404-page-heading", u8"Non trovato" },
  { u8"404-page-title", u8"Contenuto non trovato" },
  { u8"500-page-heading", u8"Oops. La pagina non funziona." },
  { u8"500-page-text", u8"Il percorso richiesto non pu\u00f2 essere fornito correttamente:" },
  { u8"500-page-title", u8"Errore interno del server" },
  { u8"book-category.other", u8"Altro" },
  { u8"book-category.wikibooks", u8"Wikibooks" },
  { u8"book-category.wikinews", u8"Wikinotizie" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversit\u00e0" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wikizionario" },
  { u8"book-filtering-all-categories", u8"Tutte le categorie" },
  { u8"book-filtering-all-languages", u8"Tutte le lingue" },
  { u8"caution-warning", u8"Attenzione!" },
  { u8"count-of-matching-books", u8"{{COUNT}} libro/i" },
  { u8"direct-download-alt-text", u8"Scarica direttamente tramite HTTP(S)" },
  { u8"direct-download-link-text", u8"Download diretto" },
  { u8"download", u8"Scarica" },
  { u8"download-links-heading", u8"Link per scaricare <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Scarica libro" },
  { u8"empty-search-results-page-header", u8"Non \u00e8 stato trovato alcun risultato per <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"home-button-text", u8"Vai alla pagina principale di '{{{BOOK_TITLE}}}'" },
  { u8"invalid-request", u8"L'URL richiesto \"{{{url}}}\" non \u00e8 una richiesta valida." },
  { u8"library-button-text", u8"Vai alla pagina di benvenuto" },
  { u8"magnet-alt-text", u8"Scarica tramite collegamento Magnet" },
  { u8"name", u8"italiano" },
  { u8"new-404-page-heading", u8"Oops. Pagina non trovata." },
  { u8"new-404-page-title", u8"Pagina non trovata" },
  { u8"no-book-found", u8"Nessun libro corrisponde ai criteri di selezione" },
  { u8"no-such-book", u8"Nessun libro con questo nome: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Nessun valore fornito per l'argomento {{ARGUMENT}}" },
  { u8"preview-book", u8"Anteprima" },
  { u8"random-article-failure", u8"Ops! Impossibile selezionare un articolo casuale :(" },
  { u8"random-page-button-text", u8"Vai a una pagina selezionata casualmente" },
  { u8"search", u8"Cerca" },
  { u8"search-result-book-info", u8"da {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Risultati <b>{{START}}-{{END}}</b> di <b>{{COUNT}}</b> per <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Cerca: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Cerca '{{{BOOK_TITLE}}}'" },
  { u8"suggest-full-text-search", u8"contenente '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Effettua una ricerca di testo completo per <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Caricamento contenuto" },
  { u8"too-many-books", u8"Troppi libri richiesti ({{NB_BOOKS}}) dove il limite \u00e8 {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Scarica tramite BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Errore sconosciuto" },
  { u8"url-not-found", u8"L'URL richiesto \"{{url}}\" non \u00e8 stato trovato in questo server." },
  { u8"welcome-page-overzealous-filter", u8"Nessun risultato. Vuoi <a href=\"{{URL}}\">reimpostare il filtro</a>?" },
  { u8"welcome-to-kiwix-server", u8"Benvenuti al server Kiwix" },
  { u8"word-count", u8"{{COUNT}} parole" }
};


const I18nString string_table_for_ja[] = {
  { u8"400-page-heading", u8"\u7121\u52b9\u306a\u30ea\u30af\u30a8\u30b9\u30c8\u3067\u3059" },
  { u8"400-page-title", u8"\u7121\u52b9\u306a\u30ea\u30af\u30a8\u30b9\u30c8\u3067\u3059" },
  { u8"404-page-heading", u8"\u898b\u3064\u304b\u308a\u307e\u305b\u3093" },
  { u8"404-page-title", u8"\u30b3\u30f3\u30c6\u30f3\u30c4\u304c\u898b\u3064\u304b\u308a\u307e\u305b\u3093\u3067\u3057\u305f" },
  { u8"500-page-heading", u8"\u5185\u90e8\u30b5\u30fc\u30d0\u30fc\u30a8\u30e9\u30fc" },
  { u8"500-page-title", u8"\u5185\u90e8\u30b5\u30fc\u30d0\u30fc\u30a8\u30e9\u30fc" },
  { u8"book-filtering-all-categories", u8"\u3059\u3079\u3066\u306e\u30ab\u30c6\u30b4\u30ea\u30fc" },
  { u8"book-filtering-all-languages", u8"\u3059\u3079\u3066\u306e\u8a00\u8a9e" },
  { u8"direct-download-alt-text", u8"\u76f4\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9" },
  { u8"direct-download-link-text", u8"\u76f4\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9\u30ea\u30f3\u30af" },
  { u8"download", u8"\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9" },
  { u8"fulltext-search-unavailable", u8"\u5168\u6587\u691c\u7d22\u306f\u5229\u7528\u3067\u304d\u307e\u305b\u3093" },
  { u8"hash-download-alt-text", u8"\u30cf\u30c3\u30b7\u30e5\u3092\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9" },
  { u8"hash-download-link-text", u8"Sha256 \u30cf\u30c3\u30b7\u30e5" },
  { u8"library-button-text", u8"\u30a6\u30a7\u30eb\u30ab\u30e0\u30da\u30fc\u30b8\u306b\u79fb\u52d5" },
  { u8"magnet-alt-text", u8"\u30de\u30b0\u30cd\u30c3\u30c8\u3092\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9" },
  { u8"magnet-link-text", u8"\u30de\u30b0\u30cd\u30c3\u30c8\u30ea\u30f3\u30af" },
  { u8"name", u8"\u65e5\u672c\u8a9e" },
  { u8"no-query", u8"\u30af\u30a8\u30ea\u3092\u6307\u5b9a\u3057\u3066\u3044\u307e\u305b\u3093\u3002" },
  { u8"no-search-results", u8"\u3053\u306e\u30b3\u30f3\u30c6\u30f3\u30c4\u3067\u306f\u5168\u6587\u691c\u7d22\u30a8\u30f3\u30b8\u30f3\u304c\u5229\u7528\u3067\u304d\u307e\u305b\u3093" },
  { u8"preview-book", u8"\u30d7\u30ec\u30d3\u30e5\u30fc" },
  { u8"random-page-button-text", u8"\u7121\u4f5c\u70ba\u306b\u9078\u3070\u308c\u305f\u30da\u30fc\u30b8\u306b\u79fb\u52d5\u3059\u308b" },
  { u8"search", u8"\u691c\u7d22" },
  { u8"torrent-download-alt-text", u8"Torrent\u3092\u30c0\u30a6\u30f3\u30ed\u30fc\u30c9" },
  { u8"torrent-download-link-text", u8"Torrent\u30d5\u30a1\u30a4\u30eb" }
};


const I18nString string_table_for_ko[] = {
  { u8"400-page-heading", u8"\uc798\ubabb\ub41c \uc694\uccad" },
  { u8"400-page-title", u8"\uc798\ubabb\ub41c \uc694\uccad" },
  { u8"404-advice.p3", u8"\uc6d0\ud558\ub294 \ucf58\ud150\uce20\ub97c \ucc3e\uc73c\ub824\uba74 \uac80\uc0c9 \uae30\ub2a5\uc744 \uc0ac\uc6a9\ud574 \ubcf4\uc138\uc694" },
  { u8"404-img-text", u8"\ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4!" },
  { u8"404-page-heading", u8"\ucc3e\uc744 \uc218 \uc5c6\uc74c" },
  { u8"404-page-title", u8"\ub0b4\uc6a9\uc774 \uc5c6\uc2b5\ub2c8\ub2e4" },
  { u8"500-img-text", u8"\ubb38\uc11c\uac00 \ub3d9\uc791\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4" },
  { u8"500-page-heading", u8"\uc8c4\uc1a1\ud569\ub2c8\ub2e4. \ubb38\uc11c\uac00 \ub3d9\uc791\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4." },
  { u8"500-page-text", u8"\uc694\uccad\ub41c \uacbd\ub85c\ub97c \uc81c\ub300\ub85c \uc804\ub2ec\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4:" },
  { u8"500-page-title", u8"\ub0b4\ubd80 \uc11c\ubc84 \uc624\ub958" },
  { u8"book-category.other", u8"\uae30\ud0c0" },
  { u8"book-category.wikibooks", u8"\uc704\ud0a4\ucc45" },
  { u8"book-category.wikinews", u8"\uc704\ud0a4\ub274\uc2a4" },
  { u8"book-category.wikipedia", u8"\uc704\ud0a4\ubc31\uacfc" },
  { u8"book-category.wikiquote", u8"\uc704\ud0a4\uc778\uc6a9\uc9d1" },
  { u8"book-category.wikisource", u8"\uc704\ud0a4\ubb38\ud5cc" },
  { u8"book-category.wikispecies", u8"\uc704\ud0a4\uc0dd\ubb3c\uc885" },
  { u8"book-category.wikiversity", u8"\uc704\ud0a4\ubc30\uc6c0\ud130" },
  { u8"book-category.wikivoyage", u8"\uc704\ud0a4\uc5ec\ud589" },
  { u8"book-category.wiktionary", u8"\uc704\ud0a4\ub0b1\ub9d0\uc0ac\uc804" },
  { u8"book-filtering-all-categories", u8"\ubaa8\ub4e0 \ubd84\ub958" },
  { u8"book-filtering-all-languages", u8"\ubaa8\ub4e0 \uc5b8\uc5b4" },
  { u8"caution-warning", u8"\uacbd\uace0!" },
  { u8"count-of-matching-books", u8"\ucc45 {{COUNT}}\uad8c" },
  { u8"direct-download-alt-text", u8"HTTP(S)\ub97c \ud1b5\ud574 \uc9c1\uc811 \ub2e4\uc6b4\ub85c\ub4dc" },
  { u8"direct-download-link-text", u8"\uc9c1\uc811" },
  { u8"download", u8"\ub2e4\uc6b4\ub85c\ub4dc" },
  { u8"download-links-heading", u8"<b><i>{{BOOK_TITLE}}</i></b>\uc758 \ub9c1\ud06c \ub2e4\uc6b4\ub85c\ub4dc" },
  { u8"download-links-title", u8"\ucc45 \ub2e4\uc6b4\ub85c\ub4dc" },
  { u8"empty-search-results-page-header", u8"<b>\"{{{SEARCH_PATTERN}}}\"</b>\uc758 \uacb0\uacfc\uac00 \uc5c6\uc2b5\ub2c8\ub2e4" },
  { u8"external-link-detected", u8"\uc678\ubd80 \ub9c1\ud06c\uac00 \ubc1c\uacac\ub418\uc5c8\uc2b5\ub2c8\ub2e4" },
  { u8"filter-by-tag", u8"\"{{{TAG}}}\" \ud0dc\uadf8\ub85c \ud544\ud130\ub9c1" },
  { u8"fulltext-search-unavailable", u8"\uc804\ubb38 \uac80\uc0c9\uc744 \uc0ac\uc6a9\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4" },
  { u8"hash-download-alt-text", u8"SHA-256 \ud30c\uc77c \uccb4\ud06c\uc12c \ud45c\uc2dc" },
  { u8"hash-download-link-text", u8"SHA-256 \uccb4\ud06c\uc12c" },
  { u8"home-button-text", u8"'{{{BOOK_TITLE}}}'\uc758 \uba54\uc778 \ud398\uc774\uc9c0\ub85c \uc774\ub3d9" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \uac12\uc740 \uc6d0\uc2dc \ucf58\ud150\uce20\uc5d0 \ub300\ud55c \uc720\ud6a8\ud55c \uc694\uccad\uc774 \uc544\ub2d9\ub2c8\ub2e4." },
  { u8"invalid-request", u8"\"{{{url}}}\" \uc694\uccad URL\uc740 \uc720\ud6a8\ud55c \uc694\uccad\uc774 \uc544\ub2d9\ub2c8\ub2e4." },
  { u8"library-opds-feed-all-entries", u8"\ub77c\uc774\ube0c\ub7ec\ub9ac OPDS \ud53c\ub4dc - \ubaa8\ub4e0 \ud56d\ubaa9" },
  { u8"library-opds-feed-parameterised", u8"\ub77c\uc774\ube0c\ub7ec\ub9ac OPDS \ud53c\ub4dc - {{#LANG}} \uc77c\uce58 \ud56d\ubaa9\n\uc5b8\uc5b4: {{LANG}} {{/LANG}}{{#CATEGORY}}\n\ubd84\ub958: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\n\ud0dc\uadf8: {{TAG}} {{/TAG}}{{#Q}}\n\ucffc\ub9ac: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"\ub9c8\uadf8\ub137 \ub9c1\ud06c\ub97c \ud1b5\ud574 \ub2e4\uc6b4\ub85c\ub4dc" },
  { u8"magnet-link-text", u8"\ub9c8\uadf8\ub137 \ub9c1\ud06c" },
  { u8"name", u8"\ud55c\uad6d\uc5b4" },
  { u8"new-404-page-heading", u8"\uc774\ub7f0. \ud398\uc774\uc9c0\ub97c \ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4." },
  { u8"new-404-page-title", u8"\ud398\uc774\uc9c0\ub97c \ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4" },
  { u8"no-book-found", u8"\uc120\ud0dd \uae30\uc900\uc5d0 \ud574\ub2f9\ud558\ub294 \ucc45\uc774 \uc5c6\uc2b5\ub2c8\ub2e4" },
  { u8"no-query", u8"\uc9c0\uc815\ub41c \ucffc\ub9ac\uac00 \uc5c6\uc2b5\ub2c8\ub2e4." },
  { u8"no-search-results", u8"\uc774 \ucf58\ud150\uce20\uc5d0\ub294 \uc804\ubb38 \uac80\uc0c9 \uc5d4\uc9c4\uc744 \uc0ac\uc6a9\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4." },
  { u8"no-such-book", u8"\ud574\ub2f9 \ucc45\uc774 \uc5c6\uc2b5\ub2c8\ub2e4: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"{{ARGUMENT}} \uc778\uc218\uc5d0 \uc9c0\uc815\ub41c \uac12\uc774 \uc5c6\uc2b5\ub2c8\ub2e4" },
  { u8"path-was-not-found", u8"\uc694\uccad\ud55c \uacbd\ub85c\ub97c \ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4:" },
  { u8"powered-by-kiwix-html", u8"<a href=\"https://kiwix.org\">Kiwix</a>\uc5d0\uc11c \uc81c\uacf5" },
  { u8"preview-book", u8"\ubbf8\ub9ac \ubcf4\uae30" },
  { u8"random-article-failure", u8"\uc774\ub7f0! \uc784\uc758 \ubb38\uc11c\ub97c \uc120\ud0dd\ud558\uc9c0 \ubabb\ud588\uc2b5\ub2c8\ub2e4 :(" },
  { u8"random-page-button-text", u8"\ubb34\uc791\uc704\ub85c \uc120\ud0dd\ub41c \ubb38\uc11c\ub85c \uc774\ub3d9" },
  { u8"raw-entry-not-found", u8"{{DATATYPE}} \ud56d\ubaa9\uc778 {{ENTRY}} \ud56d\ubaa9\uc744 \ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4" },
  { u8"search", u8"\uac80\uc0c9" },
  { u8"search-result-book-info", u8"{{BOOK_TITLE}}\uc5d0\uc11c" },
  { u8"search-results-page-header", u8"<b>\"{{{SEARCH_PATTERN}}}\"</b>\uc5d0 \ub300\ud55c <b>{{COUNT}}</b>\uac1c \uc911 <b>{{START}}-{{END}}</b> \uacb0\uacfc" },
  { u8"search-results-page-title", u8"\uac80\uc0c9: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"'{{{BOOK_TITLE}}}' \uac80\uc0c9" },
  { u8"stop-filtering-by-tag", u8"\"{{{TAG}}}\" \ud0dc\uadf8\ub85c \ud544\ud130\ub9c1 \uc911\uc9c0" },
  { u8"suggest-full-text-search", u8"'{{{SEARCH_TERMS}}}' \ud3ec\ud568..." },
  { u8"suggest-search", u8"<a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>\uc5d0 \ub300\ud55c \uc804\ubb38 \uac80\uc0c9\uc744 \uc218\ud589\ud574 \ubcf4\uc138\uc694" },
  { u8"too-many-books", u8"\uc694\uccad\ub41c \ucc45\uc774 \ub108\ubb34 \ub9ce\uc2b5\ub2c8\ub2e4. ({{NB_BOOKS}}) \ud55c\ub3c4\ub294 {{LIMIT}}\uc785\ub2c8\ub2e4." },
  { u8"torrent-download-alt-text", u8"\ube44\ud2b8\ud1a0\ub80c\ud2b8\ub97c \ud1b5\ud574 \ub2e4\uc6b4\ub85c\ub4dc" },
  { u8"torrent-download-link-text", u8"\ube44\ud2b8\ud1a0\ub80c\ud2b8" },
  { u8"unknown-error", u8"\uc54c \uc218 \uc5c6\ub294 \uc624\ub958" },
  { u8"url-not-found", u8"\"{{url}}\" \uc694\uccad URL\uc740 \uc774 \uc11c\ubc84\uc5d0\uc11c \ucc3e\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4." },
  { u8"welcome-page-overzealous-filter", u8"\uacb0\uacfc\uac00 \uc5c6\uc2b5\ub2c8\ub2e4. <a href=\"{{URL}}\">\ud544\ud130\ub97c \uc7ac\uc124\uc815</a>\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?" },
  { u8"welcome-to-kiwix-server", u8"Kiwix Server\uc5d0 \uc624\uc2e0 \uac83\uc744 \ud658\uc601\ud569\ub2c8\ub2e4" },
  { u8"word-count", u8"\ub2e8\uc5b4 {{COUNT}}\uac1c" }
};


const I18nString string_table_for_ku_latn[] = {
  { u8"400-page-heading", u8"Xwesteka nederbasdar" },
  { u8"400-page-title", u8"Xwesteka nederbasdar" },
  { u8"404-page-heading", u8"Nehat d\u00eetin" },
  { u8"404-page-title", u8"Naverok nehat d\u00eetin" },
  { u8"500-page-heading", u8"\u00c7ewtiya Server\u00ea y\u00ea Daxil\u00ee" },
  { u8"500-page-title", u8"\u00c7ewtiya Server\u00ea y\u00ea Daxil\u00ee" },
  { u8"confusion-of-tongues", u8"Du an z\u00eadetir kit\u00eab\u00ean bi ziman\u00ean cih\u00ea w\u00ea be\u015fdar\u00ee l\u00eager\u00een\u00ea bibin, ev j\u00ee dibe ku bibe sedema tevliheviya encaman." },
  { u8"fulltext-search-unavailable", u8"L\u00eager\u00eena Temam\u00ea Niv\u00ees\u00ea Neberdest e" },
  { u8"home-button-text", u8"Here r\u00fbpela destp\u00eak\u00ea y\u00ea {{BOOK_TITLE}}" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} ne daxwazeke derbasdar e ji bo naveroka xav." },
  { u8"library-button-text", u8"Here r\u00fbpela x\u00earhatin\u00ea" },
  { u8"name", u8"kurd\u00ee" },
  { u8"no-book-found", u8"Ti kit\u00eabek\u00ea ku li kr\u00eeter\u00ean te b\u00ea peyda neb\u00fb" },
  { u8"no-query", u8"Ti ti\u015ftek\u00ee xwest\u00ee n\u00eene." },
  { u8"no-search-results", u8"Motora l\u00eager\u00een\u00ea y\u00ea temam\u00ea metn\u00ea ne berdest e ji bo v\u00ea naverok\u00ea." },
  { u8"no-such-book", u8"Kit\u00eabeke wisa n\u00eene: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Ti ti\u015ft nehatiye diyarkirin ji bo mijara {{ARGUMENT}}" },
  { u8"random-article-failure", u8"Ha ho! Bi ser neket ku gotareke ketober bibij\u00eare :(" },
  { u8"random-page-button-text", u8"Here r\u00fbpeleke ketober bijart\u00ee" },
  { u8"raw-entry-not-found", u8"H\u00eamana {{ENTRY}} {{DATATYPE}} peyda neb\u00fb" },
  { u8"searchbox-tooltip", u8"Li {{BOOK_TITLE}} bigere" },
  { u8"suggest-full-text-search", u8"'{{{SEARCH_TERMS}}}' dihew\u00eene..." },
  { u8"suggest-search", u8"Ji bo <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a> l\u00eager\u00eeneke niv\u00eesa temam\u00ee p\u00eak b\u00eene" },
  { u8"too-many-books", u8"Pir z\u00eade kit\u00eab hatiye xwestin ({{NB_BOOKS}}) ku s\u00eenor {{LIMIT}} ye" },
  { u8"url-not-found", u8"URLya xwest\u00ee \"{{url}}\" li ser v\u00ea server\u00ea nehate d\u00eetin." }
};


const I18nString string_table_for_lb[] = {
  { u8"404-img-text", u8"Net fonnt!" },
  { u8"404-page-heading", u8"Net fonnt" },
  { u8"404-page-title", u8"Inhalt net fonnt" },
  { u8"500-img-text", u8"S\u00e4it funktion\u00e9iert net" },
  { u8"500-page-heading", u8"Ups. D'S\u00e4it funktion\u00e9iert net." },
  { u8"500-page-text", u8"Et ass en interne Serverfeeler opgetrueden. Mir entsch\u00ebllegen eis dofir :/" },
  { u8"500-page-title", u8"Interne Feeler um Server" },
  { u8"book-category.other", u8"Anerer" },
  { u8"book-category.stack_exchange", u8"Stack Exchange" },
  { u8"book-category.wikibooks", u8"Wikibooks" },
  { u8"book-category.wikinews", u8"Wikinews" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversity" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wiktionnaire" },
  { u8"book-filtering-all-categories", u8"All Kategorien" },
  { u8"book-filtering-all-languages", u8"All Sproochen" },
  { u8"caution-warning", u8"Opgepasst!" },
  { u8"count-of-matching-books", u8"{{COUNT}} Buch/Bicher" },
  { u8"direct-download-link-text", u8"Direkt" },
  { u8"download", u8"Eroflueden" },
  { u8"download-links-title", u8"Buch eroflueden" },
  { u8"empty-search-results-page-header", u8"Keng Resultater fonnt fir <b>\u201e{{{SEARCH_PATTERN}}}\u201c</b>" },
  { u8"external-link-detected", u8"Externe Link entdeckt" },
  { u8"fulltext-search-unavailable", u8"Volltext-Sich net verf\u00fcgbar" },
  { u8"home-button-text", u8"Op d'Haapts\u00e4it vun '{{{BOOK_TITLE}}}' goen" },
  { u8"name", u8"L\u00ebtzebuergesch" },
  { u8"new-404-page-heading", u8"Ups. S\u00e4it net fonnt." },
  { u8"new-404-page-title", u8"S\u00e4it net fonnt" },
  { u8"no-such-book", u8"Buch net fonnt: {{BOOK_NAME}}" },
  { u8"random-article-failure", u8"Ups! Et konnt keen zouf\u00e4llegen Artikel ausgewielt ginn :(" },
  { u8"random-page-button-text", u8"Gitt op eng zouf\u00e4lleg gewielte S\u00e4it" },
  { u8"search", u8"Sichen" },
  { u8"search-result-book-info", u8"aus {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Resultater <b>{{START}}-{{END}}</b> vu(n) <b>{{COUNT}}</b> fir <b>\u201e{{{SEARCH_PATTERN}}}\u201c</b>" },
  { u8"search-results-page-title", u8"Sichen: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"No '{{{BOOK_TITLE}}}' sichen" },
  { u8"suggest-full-text-search", u8"enth\u00e4lt '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Maacht eng Volltext-Sich fir <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Ze vill Bicher ugefrot ({{NB_BOOKS}}), d'Limitt l\u00e4it bei {{LIMIT}}" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Onbekannte Feeler" },
  { u8"url-not-found", u8"D\u00e9i ugefroten URL \u201e{{url}}\u201c gouf op d\u00ebsem Server net fonnt." },
  { u8"welcome-page-overzealous-filter", u8"Kee Resultat. W\u00ebllt Dir <a href=\"{{URL}}\">de Filter zr\u00e9cksetzen</a>?" },
  { u8"word-count", u8"{{COUNT}} Wierder" }
};


const I18nString string_table_for_mk[] = {
  { u8"400-page-heading", u8"\u041d\u0435\u0432\u0430\u0436\u0435\u0447\u043a\u043e \u0431\u0430\u0440\u0430\u045a\u0435" },
  { u8"400-page-title", u8"\u041d\u0435\u0432\u0430\u0436\u0435\u0447\u043a\u043e \u0431\u0430\u0440\u0430\u045a\u0435" },
  { u8"404-advice.p1", u8"\u0421\u043e\u0434\u0440\u0436\u0438\u043d\u0430\u0442\u0430 \u0448\u0442\u043e \u0458\u0430 \u0431\u0430\u0440\u0430\u0442\u0435 \u043c\u043e\u0436\u0435 \u0441\u0435\u043f\u0430\u043a \u0434\u0430 \u0435 \u0434\u043e\u0441\u0442\u0430\u043f\u043d\u0430, \u043d\u043e \u043c\u043e\u0436\u0435 \u0434\u0430 \u0441\u0435 \u043d\u0430\u043e\u0453\u0430 \u043d\u0430 \u0434\u0440\u0443\u0433\u043e \u043c\u0435\u0441\u0442\u043e \u0432\u043e \u0440\u0430\u043c\u043a\u0438\u0442\u0435 \u043d\u0430 ZIM-\u043f\u043e\u0434\u0430\u0442\u043e\u0442\u0435\u043a\u0430\u0442\u0430." },
  { u8"404-advice.p2", u8"\u0412\u0435 \u043c\u043e\u043b\u0438\u043c\u0435:" },
  { u8"404-advice.p3", u8"\u041f\u0440\u043e\u0431\u0430\u0458\u0442\u0435 \u0434\u0430 \u0458\u0430 \u0443\u043f\u043e\u0442\u0440\u0435\u0431\u0438\u0442\u0435 \u0444\u0443\u043d\u043a\u0446\u0438\u0458\u0430\u0442\u0430 \u0437\u0430 \u043f\u0440\u0435\u0431\u0430\u0440\u0443\u0432\u0430\u045a\u0435 \u0437\u0430 \u0434\u0430 \u0458\u0430 \u043d\u0430\u0458\u0434\u0435\u0442\u0435 \u0441\u043e\u0434\u0440\u0436\u0438\u043d\u0430\u0442\u0430 \u0448\u0442\u043e \u0432\u0438 \u0442\u0440\u0435\u0431\u0430" },
  { u8"404-advice.p4", u8"\u0411\u0430\u0440\u0430\u0458\u0442\u0435 \u043a\u043b\u0443\u0447\u043d\u0438 \u0437\u0431\u043e\u0440\u043e\u0432\u0438 \u0438\u043b\u0438 \u043d\u0430\u0441\u043b\u043e\u0432\u0438 \u043f\u043e\u0432\u0440\u0437\u0430\u043d\u0438 \u0441\u043e \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u0438\u0442\u0435 \u0448\u0442\u043e \u0432\u0438 \u0442\u0440\u0435\u0431\u0430\u0430\u0442" },
  { u8"404-advice.p5", u8"\u041e\u0432\u043e\u0458 \u043f\u0440\u0438\u043e\u0434 \u0442\u0440\u0435\u0431\u0430 \u0434\u0430 \u0432\u0438 \u043f\u043e\u043c\u043e\u0433\u043d\u0435 \u0434\u0430 \u0458\u0430 \u043d\u0430\u0458\u0434\u0435\u0442\u0435 \u0441\u0430\u043a\u0430\u043d\u0430\u0442\u0430 \u0441\u043e\u0434\u0440\u0436\u0438\u043d\u0430, \u0434\u0443\u0440\u0438 \u0438 \u0430\u043a\u043e \u0438\u0437\u0432\u043e\u0440\u043d\u0430\u0442\u0430 \u0432\u0440\u0441\u043a\u0430 \u043d\u0435 \u0440\u0430\u0431\u043e\u0442\u0438 \u043f\u0440\u0430\u0432\u0438\u043b\u043d\u043e." },
  { u8"404-img-text", u8"\u041d\u0435 \u0435 \u043d\u0430\u0458\u0434\u0435\u043d\u043e!" },
  { u8"404-page-heading", u8"\u041d\u0435 \u0435 \u043d\u0430\u0458\u0434\u0435\u043d\u043e" },
  { u8"404-page-title", u8"\u0421\u043e\u0434\u0440\u0436\u0438\u043d\u0430\u0442\u0430 \u043d\u0435 \u0435 \u043d\u0430\u0458\u0434\u0435\u043d\u0430" },
  { u8"500-img-text", u8"\u0421\u0442\u0440\u0430\u043d\u0438\u0446\u0430\u0442\u0430 \u043d\u0435 \u0440\u0430\u0431\u043e\u0442\u0438." },
  { u8"500-page-heading", u8"\u0421\u0442\u0440\u0430\u043d\u0438\u0446\u0430\u0442\u0430 \u043d\u0435 \u0440\u0430\u0431\u043e\u0442\u0438." },
  { u8"500-page-text", u8"\u041f\u043e\u0431\u0430\u0440\u0430\u043d\u0430\u0442\u0430 \u043f\u0430\u0442\u0435\u043a\u0430 \u043d\u0435 \u043c\u043e\u0436\u0435 \u043f\u0440\u0430\u0432\u0438\u043b\u043d\u043e \u0434\u0430 \u0441\u0435 \u0434\u043e\u0441\u0442\u0430\u0432\u0438:" },
  { u8"500-page-title", u8"\u0412\u043d\u0430\u0442\u0440\u0435\u0448\u043d\u0430 \u0433\u0440\u0435\u0448\u043a\u0430 \u0432\u043e \u043e\u043f\u0441\u043b\u0443\u0436\u0443\u0432\u0430\u0447\u043e\u0442" },
  { u8"book-category.gutenberg", u8"\u0413\u0443\u0442\u0435\u043d\u0431\u0435\u0440\u0433" },
  { u8"book-category.iFixit", u8"iFixit" },
  { u8"book-category.mooc", u8"MOOC" },
  { u8"book-category.other", u8"\u0434\u0440\u0443\u0433\u043e" },
  { u8"book-category.phet", u8"Phet" },
  { u8"book-category.stack_exchange", u8"Stack Exchange" },
  { u8"book-category.ted", u8"Ted" },
  { u8"book-category.vikidia", u8"\u0412\u0438\u043a\u0438\u0434\u0438\u0458\u0430" },
  { u8"book-category.wikibooks", u8"\u0412\u0438\u043a\u0438\u043a\u043d\u0438\u0433\u0438" },
  { u8"book-category.wikihow", u8"wikiHow" },
  { u8"book-category.wikinews", u8"\u0412\u0438\u043a\u0438\u0432\u0435\u0441\u0442\u0438" },
  { u8"book-category.wikipedia", u8"\u0412\u0438\u043a\u0438\u043f\u0435\u0434\u0438\u0458\u0430" },
  { u8"book-category.wikiquote", u8"\u0412\u0438\u043a\u0438\u0446\u0438\u0442\u0430\u0442" },
  { u8"book-category.wikisource", u8"\u0412\u0438\u043a\u0438\u0438\u0437\u0432\u043e\u0440" },
  { u8"book-category.wikispecies", u8"\u0412\u0438\u043a\u0438\u0432\u0438\u0434\u043e\u0432\u0438" },
  { u8"book-category.wikiversity", u8"\u0412\u0438\u043a\u0438\u0443\u043d\u0438\u0432\u0435\u0440\u0437\u0438\u0442\u0435\u0442" },
  { u8"book-category.wikivoyage", u8"\u0412\u0438\u043a\u0438\u043f\u0430\u0442\u0443\u0432\u0430\u045a\u0435" },
  { u8"book-category.wiktionary", u8"\u0412\u0438\u043a\u0438\u0440\u0435\u0447\u043d\u0438\u043a" },
  { u8"book-filtering-all-categories", u8"\u0421\u0438\u0442\u0435 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438" },
  { u8"book-filtering-all-languages", u8"\u0421\u0438\u0442\u0435 \u0458\u0430\u0437\u0438\u0446\u0438" },
  { u8"caution-warning", u8"\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!" },
  { u8"confusion-of-tongues", u8"\u0412\u043e \u043f\u0440\u0435\u0431\u0430\u0440\u0443\u0432\u0430\u045a\u0435\u0442\u043e \u045c\u0435 \u0443\u0447\u0435\u0441\u0442\u0432\u0443\u0432\u0430\u0430\u0442 \u0434\u0432\u0435 \u0438\u043b\u0438 \u043f\u043e\u0432\u0435\u045c\u0435 \u043a\u043d\u0438\u0433\u0438 \u043d\u0430 \u0440\u0430\u0437\u043b\u0438\u0447\u043d\u0438 \u0458\u0430\u0437\u0438\u0446\u0438, \u0448\u0442\u043e \u043c\u043e\u0436\u0435 \u0434\u0430 \u0434\u043e\u0432\u0435\u0442\u0435 \u0434\u043e \u0437\u0431\u0443\u043d\u0443\u0432\u0430\u0447\u043a\u0438 \u0438\u0441\u0445\u043e\u0434." },
  { u8"count-of-matching-books", u8"{{COUNT}} \u043a\u043d\u0438\u0433\u0438" },
  { u8"direct-download-alt-text", u8"\u041d\u0435\u043f\u043e\u0441\u0440\u0435\u0434\u043d\u043e \u043f\u0440\u0435\u0437\u0435\u043c\u0430\u045a\u0435 \u043f\u0440\u0435\u043a\u0443 HTTP(S)" },
  { u8"direct-download-link-text", u8"\u041d\u0435\u043f\u043e\u0441\u0440\u0435\u0434\u043d\u043e" },
  { u8"download", u8"\u041f\u0440\u0435\u0437\u0435\u043c\u0438" },
  { u8"download-links-heading", u8"\u0412\u0440\u0441\u043a\u0438 \u0437\u0430 \u043f\u0440\u0435\u0437\u0435\u043c\u0430\u045a\u0435 \u043d\u0430 <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"\u041f\u0440\u0435\u0437\u0435\u043c\u0438 \u043a\u043d\u0438\u0433\u0430" },
  { u8"empty-search-results-page-header", u8"\u041d\u0435 \u043d\u0430\u0458\u0434\u043e\u0432 \u043d\u0438\u0448\u0442\u043e \u0437\u0430 <b>\u201e{{{SEARCH_PATTERN}}}\u201c</b>" },
  { u8"external-link-advice.p1", u8"\u0412\u0440\u0441\u043a\u0430\u0442\u0430 \u0448\u0442\u043e \u043f\u0440\u043e\u0431\u0443\u0432\u0430\u0442\u0435 \u0434\u0430 \u0458\u0430 \u043e\u0442\u0432\u043e\u0440\u0438\u0442\u0435 \u043d\u0435 \u0435 \u0434\u0435\u043b \u043e\u0434 \u0432\u0430\u0448\u0438\u043e\u0442 \u0432\u043e\u043d\u043c\u0440\u0435\u0436\u0435\u043d \u043f\u0430\u043a\u0435\u0442 \u0438 \u0431\u0430\u0440\u0430 \u0441\u0435\u043c\u0440\u0435\u0436\u043d\u0430 \u0432\u0440\u0441\u043a\u0430." },
  { u8"external-link-advice.p2", u8"\u0410\u043a\u043e \u043c\u043e\u0436\u0435\u0442\u0435 \u0434\u0430 \u0441\u0435 \u043f\u043e\u0432\u0440\u0437\u0435\u0442\u0435 \u0441\u043e \u0441\u0435\u043c\u0440\u0435\u0436\u043d\u0435\u0442\u043e, \u043f\u0440\u043e\u0431\u0430\u0458\u0442\u0435 \u0434\u0430 \u0458\u0430 \u043e\u0442\u0432\u043e\u0440\u0438\u0442\u0435 \u0432\u0440\u0441\u043a\u0430\u0442\u0430." },
  { u8"external-link-advice.p3", u8"\u0412\u043e \u0441\u043f\u0440\u043e\u0442\u0438\u0432\u043d\u043e \u043c\u043e\u0436\u0435\u0442\u0435 \u043f\u043e\u0432\u0442\u043e\u0440\u043d\u043e \u0434\u0430 \u043f\u0440\u043e\u0431\u0430\u0442\u0435 \u0434\u0430 \u0458\u0430 \u043e\u0442\u0432\u043e\u0440\u0438\u0442\u0435 \u0432\u043e\u043d\u043c\u0440\u0435\u0436\u043d\u0430\u0442\u0430 \u0441\u043e\u0434\u0440\u0436\u0438\u043d\u0430 \u043d\u0430 \u0432\u0430\u0448\u0438\u043e\u0442 ZIM \u0441\u0442\u0438\u0441\u043a\u0430\u0458\u045c\u0438 \u043d\u0430 \u043a\u043e\u043f\u0447\u0435\u0442\u043e \u0437\u0430 \u0432\u0440\u0430\u045c\u0430\u045a\u0435 \u043d\u0430\u0437\u0430\u0434 \u043d\u0430 \u0432\u0430\u0448\u0438\u043e\u0442 \u043f\u0440\u0435\u043b\u0438\u0441\u0442\u0443\u0432\u0430\u0447." },
  { u8"external-link-detected", u8"\u041d\u0430\u0458\u0434\u0435\u043d\u0430 \u0435 \u043d\u0430\u0434\u0432\u043e\u0440\u0435\u0448\u043d\u0430 \u0432\u0440\u0441\u043a\u0430" },
  { u8"external-link-intro", u8"\u041d\u0430 \u043f\u0430\u0442 \u0441\u0442\u0435 \u0434\u0430 \u0433\u043e \u043d\u0430\u043f\u0443\u0448\u0442\u0438\u0442\u0435 ZIM-\u0447\u0438\u0442\u0430\u0447\u043e\u0442 \u043d\u0430 \u041a\u0438\u0432\u0438\u043a\u0441 \u0437\u0430 \u0434\u0430 \u043f\u043e\u0458\u0434\u0435\u0442\u0435 \u043d\u0430" },
  { u8"filter-by-tag", u8"\u0424\u0438\u043b\u0442\u0440\u0438\u0440\u0430\u0458 \u043f\u043e \u043e\u0437\u043d\u0430\u043a\u0430\u0442\u0430 \u201e{{{TAG}}}\u201c" },
  { u8"fulltext-search-unavailable", u8"\u0426\u0435\u043b\u043e\u0442\u0435\u043a\u0441\u0442\u043d\u043e\u0442\u043e \u043f\u0440\u0435\u0431\u0430\u0440\u0443\u0432\u0430\u045a\u0435 \u0435 \u043d\u0435\u0434\u043e\u0441\u0442\u0430\u043f\u043d\u043e" },
  { u8"hash-download-alt-text", u8"\u041f\u0440\u0438\u043a\u0430\u0436\u0438 \u043a\u043e\u043d\u0442\u0440\u043e\u043b\u0435\u043d \u0437\u0431\u0438\u0440 SHA-256 \u043d\u0430 \u043f\u043e\u0434\u0430\u0442\u043e\u0442\u0435\u043a\u0430\u0442\u0430" },
  { u8"hash-download-link-text", u8"\u041a\u043e\u043d\u0442\u0440\u043e\u043b\u0435\u043d \u0437\u0431\u0438\u0440 Sha256" },
  { u8"home-button-text", u8"\u041e\u0434\u0438 \u043d\u0430 \u0433\u043b\u0430\u0432\u043d\u0430\u0442\u0430 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430 \u043d\u0430 \u201e{{{BOOK_TITLE}}}\u201c" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u043d\u0435 \u043f\u0440\u0435\u0442\u0441\u0442\u0430\u0432\u0443\u0432\u0430 \u0432\u0430\u0436\u0435\u0447\u043a\u043e \u0431\u0430\u0440\u0430\u045a\u0435 \u0437\u0430 \u0441\u0438\u0440\u043e\u0432\u0430 \u0441\u043e\u0434\u0440\u0436\u0438\u043d\u0430." },
  { u8"invalid-request", u8"\u041f\u043e\u0431\u0430\u0440\u0430\u043d\u0430\u0442\u0430 URL \u201e{{{url}}}\u201c \u043d\u0435 \u043f\u0440\u0435\u0442\u0441\u0442\u0430\u0432\u0443\u0432\u0430 \u0432\u0430\u0436\u0435\u0447\u043a\u043e \u0431\u0430\u0440\u0430\u045a\u0435." },
  { u8"library-button-text", u8"\u041e\u0434\u0438 \u043d\u0430 \u0432\u043e\u0432\u0435\u0434\u043d\u0430\u0442\u0430 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430" },
  { u8"library-opds-feed-all-entries", u8"\u0411\u0438\u0431\u043b\u0438\u043e\u0442\u0435\u0447\u0435\u043d \u0442\u0435\u043a\u043e\u0432\u043d\u0438\u043a \u043d\u0430 OPDS \u2014 \u0421\u0438\u0442\u0435 \u0441\u0442\u0430\u0432\u043a\u0438" },
  { u8"library-opds-feed-parameterised", u8"\u0411\u0438\u0431\u043b\u0438\u043e\u0442\u0435\u0447\u0435\u043d \u0442\u0435\u043a\u043e\u0432\u043d\u0438\u043a \u043d\u0430 OPDS \u2014 \u0441\u0442\u0430\u0432\u043a\u0438 \u0448\u0442\u043e \u043e\u0434\u0433\u043e\u0432\u0430\u0440\u0430\u0430\u0442 \u043d\u0430 {{#LANG}}\n\u0408\u0430\u0437\u0438\u043a: {{LANG}} {{/LANG}}{{#CATEGORY}}\n\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0458\u0430: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\n\u041e\u0437\u043d\u0430\u043a\u0430: {{TAG}} {{/TAG}}{{#Q}}\n\u0411\u0430\u0440\u0430\u045a\u0435: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"\u041f\u0440\u0435\u0437\u0435\u043c\u0438 \u043f\u0440\u0435\u043a\u0443 Magnet-\u0432\u0440\u0441\u043a\u0430" },
  { u8"magnet-link-text", u8"\u041c\u0430\u0433\u043d\u0435\u0442\u043d\u0430 \u0432\u0440\u0441\u043a\u0430" },
  { u8"name", u8"\u043c\u0430\u043a\u0435\u0434\u043e\u043d\u0441\u043a\u0438" },
  { u8"new-404-page-heading", u8"\u0410\u0445! \u0421\u0442\u0440\u0430\u043d\u0438\u0446\u0430\u0442\u0430 \u043d\u0435 \u0435 \u043f\u0440\u043e\u043d\u0430\u0458\u0434\u0435\u043d\u0430." },
  { u8"new-404-page-title", u8"\u0421\u0442\u0440\u0430\u043d\u0438\u0446\u0430\u0442\u0430 \u043d\u0435 \u0435 \u043f\u0440\u043e\u043d\u0430\u0458\u0434\u0435\u043d\u0430" },
  { u8"no-book-found", u8"\u041d\u0438\u0435\u0434\u043d\u0430 \u043a\u043d\u0438\u0433\u0430 \u043d\u0435 \u043e\u0434\u0433\u043e\u0432\u0430\u0440\u0430 \u043d\u0430 \u0438\u0437\u0431\u0440\u0430\u043d\u043e\u0442\u043e" },
  { u8"no-query", u8"\u041d\u0435 \u0435 \u0443\u043a\u0430\u0436\u0430\u043d\u043e \u0431\u0430\u0440\u0430\u045a\u0435." },
  { u8"no-search-results", u8"\u041f\u043e\u0433\u043e\u043d\u043e\u0442 \u0437\u0430 \u0446\u0435\u043b\u043e\u0442\u0435\u043a\u0441\u0442\u043d\u043e \u043f\u0440\u0435\u0431\u0430\u0440\u0443\u0432\u0430\u045a\u0435 \u043d\u0435 \u0435 \u0434\u043e\u0441\u0442\u0430\u043f\u0435\u043d \u0437\u0430 \u043e\u0432\u0430\u0430 \u0441\u043e\u0434\u0440\u0436\u0438\u043d\u0430." },
  { u8"no-such-book", u8"\u041d\u0435\u043c\u0430 \u043a\u043d\u0438\u0433\u0430 \u043d\u0430\u0440\u0447\u0435\u043d\u0430 {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u041d\u0435\u043c\u0430 \u0443\u043a\u0430\u0436\u0430\u043d\u043e \u0432\u0440\u0435\u0434\u043d\u043e\u0441\u0442 \u0437\u0430 \u0430\u0440\u0433\u0443\u043c\u0435\u043d\u0442\u043e\u0442 {{ARGUMENT}}" },
  { u8"path-was-not-found", u8"\u041d\u0435 \u0458\u0430 \u043d\u0430\u0458\u0434\u043e\u0432 \u043f\u043e\u0431\u0430\u0440\u0430\u043d\u0430\u0442\u0430 \u043f\u0430\u0442\u0435\u043a\u0430:" },
  { u8"powered-by-kiwix-html", u8"\u041e\u0432\u043e\u0437\u043c\u043e\u0436\u0435\u043d\u043e \u043e\u0434&nbsp;<a href=\"https://kiwix.org\">\u041a\u0438\u0432\u0438\u043a\u0441</a>" },
  { u8"preview-book", u8"\u041f\u0440\u0435\u0433\u043b\u0435\u0434" },
  { u8"random-article-failure", u8"\u0423\u043f\u0441! \u041d\u0435 \u0443\u0441\u043f\u0435\u0430\u0432 \u0434\u0430 \u0438\u0437\u0431\u0435\u0440\u0430\u043c \u0441\u043b\u0443\u0447\u0430\u0458\u043d\u0430 \u0441\u0442\u0430\u0442\u0438\u0458\u0430 :(" },
  { u8"random-page-button-text", u8"\u041e\u0434\u0438 \u043d\u0430 \u0441\u043b\u0443\u0447\u0430\u0458\u043d\u043e \u0438\u0437\u0431\u0440\u0430\u043d\u0430 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0430" },
  { u8"raw-entry-not-found", u8"\u041d\u0435 \u043c\u043e\u0436\u0430\u043c \u0434\u0430 \u0458\u0430 \u043d\u0430\u0458\u0434\u0430\u043c {{DATATYPE}}-\u0441\u0442\u0430\u0432\u043a\u0430\u0442\u0430 {{ENTRY}}" },
  { u8"search", u8"\u041f\u0440\u0435\u0431\u0430\u0440\u0430\u0458" },
  { u8"search-result-book-info", u8"\u043e\u0434 {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"\u0418\u0441\u0445\u043e\u0434 <b>{{START}}-{{END}}</b> \u043e\u0434 <b>{{COUNT}}</b> \u0437\u0430 <b>\u201e{{{SEARCH_PATTERN}}}\u201c</b>" },
  { u8"search-results-page-title", u8"\u041f\u0440\u0435\u0431\u0430\u0440\u0443\u0432\u0430\u045a\u0435: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"\u041f\u0440\u0435\u0431\u0430\u0440\u0430\u0458 \u043f\u043e \u201e{{{BOOK_TITLE}}}\u201c" },
  { u8"stop-filtering-by-tag", u8"\u0417\u0430\u043f\u0440\u0438 \u0444\u0438\u043b\u0442\u0440\u0438\u0440\u0430\u045a\u0435 \u043f\u043e \u043e\u0437\u043d\u0430\u043a\u0430\u0442\u0430 \u201e{{{TAG}}}\u201c" },
  { u8"suggest-full-text-search", u8"\u0441\u043e\u0434\u0440\u0436\u0438 \u201e{{{SEARCH_TERMS}}}\u201c..." },
  { u8"suggest-search", u8"\u041f\u043e\u0431\u0430\u0440\u0430\u0458\u0442\u0435 \u0433\u043e <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a> \u043f\u043e \u0446\u0435\u043b\u0438\u043e\u0442 \u0442\u0435\u043a\u0441\u0442" },
  { u8"text-loading-content", u8"\u0408\u0430 \u0432\u0447\u0438\u0442\u0443\u0432\u0430\u043c \u0441\u043e\u0434\u0440\u0436\u0438\u043d\u0430\u0442\u0430" },
  { u8"too-many-books", u8"\u041f\u043e\u0431\u0430\u0440\u0430\u0432\u0442\u0435 \u043f\u0440\u0435\u043c\u043d\u043e\u0433\u0443 \u043a\u043d\u0438\u0433\u0438 ({{NB_BOOKS}}). \u041e\u0433\u0440\u0430\u043d\u0438\u0447\u0435\u043d\u0438 \u0441\u0442\u0435 \u043d\u0430 {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"\u041f\u0440\u0435\u0437\u0435\u043c\u0438 \u043f\u0440\u0435\u043a\u0443 BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"\u041d\u0435\u043f\u043e\u0437\u043d\u0430\u0442\u0430 \u0433\u0440\u0435\u0448\u043a\u0430" },
  { u8"url-not-found", u8"\u041d\u0435 \u0458\u0430 \u043f\u0440\u043e\u043d\u0430\u0458\u0434\u043e\u0432 \u043f\u043e\u0431\u0430\u0440\u0430\u043d\u0430\u0442\u0430 \u0430\u0434\u0440\u0435\u0441\u0430 \u201e{{url}}\u201c \u043d\u0430 \u043e\u043f\u0441\u043b\u0443\u0436\u0443\u0432\u0430\u0447\u043e\u0442." },
  { u8"welcome-page-overzealous-filter", u8"\u041d\u0435\u043c\u0430 \u0438\u0441\u0445\u043e\u0434. \u0414\u0430\u043b\u0438 \u0431\u0438 \u0441\u0430\u043a\u0430\u043b\u0435 \u0434\u0430 \u0433\u043e <a href=\"{{URL}}\">\u043f\u043e\u043d\u0438\u0448\u0442\u0438\u0442\u0435 \u0444\u0438\u043b\u0442\u0435\u0440\u043e\u0442</a>?" },
  { u8"welcome-to-kiwix-server", u8"\u0414\u043e\u0431\u0440\u0435 \u0434\u043e\u0458\u0434\u043e\u0432\u0442\u0435 \u043d\u0430 \u041e\u043f\u0441\u043b\u0443\u0436\u0443\u0432\u0430\u0447\u043e\u0442 \u043d\u0430 \u041a\u0438\u0432\u0438\u043a\u0441" },
  { u8"word-count", u8"{{COUNT}} \u0437\u0431\u043e\u0440\u043e\u0432\u0438" }
};


const I18nString string_table_for_ms[] = {
  { u8"404-page-heading", u8"Tidak Dijumpai" },
  { u8"500-page-heading", u8"Ralat Pelayan Dalaman" },
  { u8"500-page-title", u8"Ralat Pelayan Dalaman" },
  { u8"book-filtering-all-categories", u8"Semua kategori" },
  { u8"book-filtering-all-languages", u8"Semua bahasa" },
  { u8"direct-download-alt-text", u8"muat turun langsung" },
  { u8"direct-download-link-text", u8"Langsung" },
  { u8"download", u8"Muat turun" },
  { u8"download-links-title", u8"Muat turun buku" },
  { u8"library-button-text", u8"Pergi ke laman selamat datang" },
  { u8"name", u8"Bahasa Melayu" },
  { u8"search", u8"Cari" },
  { u8"searchbox-tooltip", u8"Cari '{{BOOK_TITLE}}'" }
};


const I18nString string_table_for_nb[] = {
  { u8"400-page-heading", u8"Ugyldig foresp\u00f8rsel" },
  { u8"400-page-title", u8"Ugyldig foresp\u00f8rsel" },
  { u8"404-page-heading", u8"Ikke funnet" },
  { u8"404-page-title", u8"Finner ikke innhold" },
  { u8"500-page-heading", u8"Intern serverfeil" },
  { u8"500-page-text", u8"Det oppstod en intern serverfeil. Vi beklager det :/" },
  { u8"500-page-title", u8"Intern serverfeil" },
  { u8"book-category.other", u8"Annet" },
  { u8"book-category.wikibooks", u8"Wikibooks" },
  { u8"book-category.wikinews", u8"Wikinews" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversity" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wiktionary" },
  { u8"book-filtering-all-categories", u8"Alle kategorier" },
  { u8"book-filtering-all-languages", u8"Alle spr\u00e5k" },
  { u8"confusion-of-tongues", u8"To eller flere b\u00f8ker p\u00e5 forskjellige spr\u00e5k vil inng\u00e5 i s\u00f8ket, noe som kan gi forvirrende resultater." },
  { u8"count-of-matching-books", u8"{{COUNT}} bok/b\u00f8ker" },
  { u8"direct-download-alt-text", u8"Last ned direkte via HTTP(S)" },
  { u8"direct-download-link-text", u8"Direkte" },
  { u8"download", u8"Last ned" },
  { u8"download-links-heading", u8"Nedlastingslenker for <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Last ned bok" },
  { u8"empty-search-results-page-header", u8"Ingen resultater ble funnet for <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"filter-by-tag", u8"Filtrer etter taggen \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"Fullteksts\u00f8k utilgjengelig" },
  { u8"hash-download-alt-text", u8"Vis filens SHA-256 kontrollsum" },
  { u8"hash-download-link-text", u8"SHA-256 kontrollsum" },
  { u8"home-button-text", u8"G\u00e5 til hovedsiden for '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} er ikke en gyldig foresp\u00f8rsel etter uformatert innhold." },
  { u8"invalid-request", u8"Den forespurte URL-en \"{{{url}}}\" er ikke en gyldig foresp\u00f8rsel." },
  { u8"library-button-text", u8"G\u00e5 til velkomstsiden" },
  { u8"library-opds-feed-all-entries", u8"Biblioteks OPDS-feed - Alle oppf\u00f8ringer" },
  { u8"library-opds-feed-parameterised", u8"Biblioteks OPDS-feed - oppf\u00f8ringer som samsvarer med {{#LANG}}\nSpr\u00e5k: {{LANG}} {{/LANG}}{{#CATEGORY}}\nKategori: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTagg: {{TAG}} {{/TAG}}{{#Q}}\nSp\u00f8rring: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Last ned via Magnetlenke" },
  { u8"magnet-link-text", u8"Magnetlenke" },
  { u8"name", u8"Engelsk" },
  { u8"no-book-found", u8"Ingen b\u00f8ker med treff p\u00e5 utvalgkriteriene" },
  { u8"no-query", u8"Ingen s\u00f8keord oppgitt." },
  { u8"no-search-results", u8"S\u00f8kemotoren for fullteksts\u00f8k er ikke tilgjengelig for dette innholdet." },
  { u8"no-such-book", u8"Finner ingen slik bok: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Ingen verdi angitt for argumentet {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Drevet av <a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Forh\u00e5ndsvisning" },
  { u8"random-article-failure", u8"Oops! Klarte ikke \u00e5 hente en tilfeldig artikkel :(" },
  { u8"random-page-button-text", u8"G\u00e5 til en tilfeldig valgt side" },
  { u8"raw-entry-not-found", u8"Finner ikke {{DATATYPE}}-oppf\u00f8ringen {{ENTRY}}" },
  { u8"search", u8"S\u00f8k" },
  { u8"search-result-book-info", u8"fra {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Resultater <b>{{START}}-{{END}}</b> av <b>{{COUNT}}</b> for <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"S\u00f8k: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"S\u00f8k etter '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Slutt \u00e5 filtrere etter taggen \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"inneholder '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Gj\u00f8r et fullteksts\u00f8k etter <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Laster innhold" },
  { u8"too-many-books", u8"Det er forespurt for mange b\u00f8ker {{NB_BOOKS}} der grensen er {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Last ned via BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Ukjent feil" },
  { u8"url-not-found", u8"Den forespurte webadressen \u00ab{{url}}\u00bb ble ikke funnet p\u00e5 denne serveren." },
  { u8"welcome-page-overzealous-filter", u8"Ingen resultater. Vil du <a href=\"{{URL}}\">tilbakestille filteret</a>?" },
  { u8"welcome-to-kiwix-server", u8"Velkommen til Kiwix Server" },
  { u8"word-count", u8"{{COUNT}} ord" }
};


const I18nString string_table_for_nl[] = {
  { u8"400-page-heading", u8"Ongeldig verzoek" },
  { u8"400-page-title", u8"Ongeldig verzoek" },
  { u8"404-advice.p1", u8"De inhoud die u zoekt is mogelijk toch beschikbaar, maar kan zich ergens anders in het ZIM-bestand bevinden." },
  { u8"404-advice.p2", u8"U kunt:" },
  { u8"404-advice.p3", u8"De zoekfunctie proberen om de gewenste inhoud te vinden" },
  { u8"404-advice.p4", u8"Trefwoorden of titels opzoeken die verband houden met de informatie die u zoekt" },
  { u8"404-advice.p5", u8"Met deze aanpak kunt u hopelijk de gewenste inhoud vinden, ook als de oorspronkelijke koppeling niet goed werkt." },
  { u8"404-img-text", u8"Niet gevonden!" },
  { u8"404-page-heading", u8"Niet gevonden" },
  { u8"404-page-title", u8"Inhoud niet gevonden" },
  { u8"500-img-text", u8"Pagina werkt niet" },
  { u8"500-page-heading", u8"Oeps. De pagina werkt niet." },
  { u8"500-page-text", u8"Het aangevraagde pad kan niet goed beschikbaar worden gesteld:" },
  { u8"500-page-title", u8"Interne serverfout" },
  { u8"book-category.other", u8"Overige" },
  { u8"book-category.wikibooks", u8"Wikibooks" },
  { u8"book-category.wikinews", u8"Wikinieuws" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversity" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"WikiWoordenboek" },
  { u8"book-filtering-all-categories", u8"Alle categorie\u00ebn" },
  { u8"book-filtering-all-languages", u8"Alle talen" },
  { u8"caution-warning", u8"Voorzichtig!" },
  { u8"confusion-of-tongues", u8"Er zouden twee of meer boeken in verschillende talen deelnemen aan de zoekopdracht, wat tot verwarrende resultaten kan leiden." },
  { u8"count-of-matching-books", u8"{{COUNT}} boek(en)" },
  { u8"direct-download-alt-text", u8"Direct downloaden via HTTP(S)" },
  { u8"direct-download-link-text", u8"Direct" },
  { u8"download", u8"Downloaden" },
  { u8"download-links-heading", u8"Downloadkoppelingen voor <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Boek downloaden" },
  { u8"empty-search-results-page-header", u8"Er zijn geen resultaten gevonden voor <b>\u201c{{{SEARCH_PATTERN}}}\u201d</b>" },
  { u8"external-link-advice.p1", u8"De koppeling die u probeert te openen, maakt geen deel uit van uw offline-pakket en vereist een internetverbinding." },
  { u8"external-link-advice.p2", u8"Als u online kunt gaan, kunt u proberen de koppeling te openen." },
  { u8"external-link-advice.p3", u8"Anders kunt u met de terugknop van uw browser terugkeren naar de offline-inhoud van uw ZIM." },
  { u8"external-link-detected", u8"Externe koppeling gedetecteerd" },
  { u8"external-link-intro", u8"U staat op het punt de ZIM-lezer van Kiwix te verlaten om online te gaan naar" },
  { u8"filter-by-tag", u8"Filteren op label \u201c{{{TAG}}}\u201d" },
  { u8"fulltext-search-unavailable", u8"Zoeken in volledige tekst is niet beschikbaar" },
  { u8"hash-download-alt-text", u8"De SHA-256-controlesom van het bestand weergeven" },
  { u8"hash-download-link-text", u8"SHA-256-controlesom" },
  { u8"home-button-text", u8"Naar de hoofdpagina van \u2018{{{BOOK_TITLE}}}\u2019" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} is geen geldig verzoek voor onbewerkte inhoud." },
  { u8"invalid-request", u8"De gevraagde URL \u201c{{{url}}}\u201d is onjuist." },
  { u8"library-button-text", u8"Naar de welkomstpagina" },
  { u8"library-opds-feed-all-entries", u8"OPDS-feed bibliotheek: alle vermeldingen" },
  { u8"library-opds-feed-parameterised", u8"OPDS-feed bibliotheek: vermeldingen die overeenkomen met {{#LANG}}\nTaal: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategorie: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nLabel: {{TAG}} {{/TAG}}{{#Q}}\nZoekopdracht: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Downloaden via Magnet-link" },
  { u8"magnet-link-text", u8"Magnet-koppeling" },
  { u8"name", u8"Nederlands" },
  { u8"new-404-page-heading", u8"Oeps. Pagina niet gevonden." },
  { u8"new-404-page-title", u8"Pagina niet gevonden" },
  { u8"no-book-found", u8"Er zijn geen boeken die overeenkomen met de zoekcriteria" },
  { u8"no-query", u8"Er is geen zoekterm opgegeven." },
  { u8"no-search-results", u8"De zoekmachine voor volledige tekst is niet beschikbaar voor deze inhoud." },
  { u8"no-such-book", u8"Boek bestaat niet: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Er is geen waarde opgegeven bij {{ARGUMENT}}" },
  { u8"path-was-not-found", u8"Het gevraagde pad is niet gevonden:" },
  { u8"powered-by-kiwix-html", u8"Mogelijk gemaakt door <a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Voorvertoning" },
  { u8"random-article-failure", u8"Oeps! Kan geen willekeurig artikel kiezen :(" },
  { u8"random-page-button-text", u8"Naar een willekeurig geselecteerde pagina gaan" },
  { u8"raw-entry-not-found", u8"Kan het {{DATATYPE}}-item {{ENTRY}} niet vinden" },
  { u8"search", u8"Zoeken" },
  { u8"search-result-book-info", u8"uit {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Resultaten <b>{{START}}-{{END}}</b> van <b>{{COUNT}}</b> voor <b>\u201c{{{SEARCH_PATTERN}}}\u201d</b>" },
  { u8"search-results-page-title", u8"Zoeken: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"\u2018{{{BOOK_TITLE}}}\u2019 doorzoeken" },
  { u8"stop-filtering-by-tag", u8"Niet meer filteren op label \u201c{{{TAG}}}\u201d" },
  { u8"suggest-full-text-search", u8"bevat \u2018{{{SEARCH_TERMS}}}\u2019\u2026" },
  { u8"suggest-search", u8"In volledige tekst zoeen naar <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Inhoud laden" },
  { u8"too-many-books", u8"Er zijn teveel boeken opgevraagd ({{NB_BOOKS}}). De limiet is {{LIMIT}}." },
  { u8"torrent-download-alt-text", u8"Downloaden via BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Onbekende fout" },
  { u8"url-not-found", u8"De opgevraagde URL \u201c{{url}}\u201d is niet gevonden op deze server." },
  { u8"welcome-page-overzealous-filter", u8"Geen resultaat. Wilt u <a href=\"{{URL}}\">het filter resetten</a>?" },
  { u8"welcome-to-kiwix-server", u8"Welkom bij de Kiwix-server" },
  { u8"word-count", u8"{{COUNT}} woorden" }
};


const I18nString string_table_for_nqo[] = {
  { u8"400-page-heading", u8"\u07e1\u07de\u07ca\u07ec\u07e3\u07cc\u07f2\u07ec\u07e0\u07cc\u07f2\u07eb \u07d3\u07cd\u07f2\u07ec\u07d3\u07ca\u07df\u07cc" },
  { u8"400-page-title", u8"\u07e1\u07de\u07ca\u07ec\u07e3\u07cc\u07f2\u07ec\u07e0\u07cc\u07f2\u07eb \u07d3\u07cd\u07f2\u07ec\u07d3\u07ca\u07df\u07cc" },
  { u8"404-page-heading", u8"\u07e1\u07ca\u07eb \u07db\u07d0\u07ec\u07d8\u07d0\u07f2\u07eb" },
  { u8"404-page-title", u8"\u07de\u07e3\u07d0\u07d8\u07d0 \u07e1\u07ca\u07eb \u07db\u07d0\u07ec\u07d8\u07d0\u07f2\u07eb" },
  { u8"500-page-heading", u8"\u07de\u07e3\u07d0\u07df\u07ca \u07e1\u07ca\u07ec\u07db\u07d0\u07ec\u07df\u07ca\u07f2 \u07dd\u07ce\u07ec\u07d5\u07ce\u07f2\u07ec\u07d5\u07cc" },
  { u8"500-page-title", u8"\u07de\u07e3\u07d0\u07df\u07ca \u07e1\u07ca\u07ec\u07db\u07d0\u07ec\u07df\u07ca\u07f2 \u07dd\u07ce\u07ec\u07d5\u07ce\u07f2\u07ec\u07d5\u07cc" },
  { u8"book-filtering-all-categories", u8"\u07e6\u07cc\u07df\u07e1\u07ca \u07df\u07ce\u07ec \u07d3\u07cd\u07ef" },
  { u8"book-filtering-all-languages", u8"\u07de\u07ca\u07f2 \u07e0\u07ce\u07ec \u07d3\u07cd\u07ef" },
  { u8"confusion-of-tongues", u8"\u07de\u07ca\u07ec\u07dd\u07ca\u07eb \u07dd\u07cc\u07ec\u07df\u07ca\u07ec \u07e5\u07df\u07ca\u07eb \u07e6\u07d9\u07cc\u07de\u07ca \u07de\u07ca\u07f2\u07eb \u07dc\u07d8\u07cd \u07df\u07ce\u07ec \u07d8\u07d0\u07eb\u07f8 \u07cf\u07ec \u07df\u07ce\u07eb \u07d8\u07cc\u07e3\u07ca\u07ec \u07d5\u07d8\u07cd\u07ec \u07e2\u07cc\u07e3\u07cc\u07f2\u07e0\u07cc\u07f2 \u07d8\u07d0\u07eb\u07f8 \u07e1\u07cd\u07f2 \u07e0\u07ce\u07ec \u07db\u07cc\u07eb \u07de\u07e3\u07d0\u07ec\u07dd\u07df\u07cc \u07df\u07ca\u07d8\u07cf\u07f2\u07ec \u07e0\u07ca\u07eb \u07de\u07d0\u07dd\u07df\u07cc \u07d8\u07d0\u07eb." },
  { u8"count-of-matching-books", u8"\u07de\u07ca\u07ec\u07dd\u07ca {{COUNT}}(\u07df\u07ce\u07eb)" },
  { u8"direct-download-alt-text", u8"\u07df\u07ca\u07ec\u07d6\u07cc\u07f0\u07d2\u07ec\u07de\u07ce\u07f2\u07ec\u07e0\u07cc\u07f2\u07eb \u07dd\u07ca\u07f2\u07de\u07e2\u07ca" },
  { u8"direct-download-link-text", u8"\u07d2\u07d5\u07cb\u07df\u07cb\u07f2\u07e1\u07ca\u07ec" },
  { u8"download", u8"\u07df\u07ca\u07ec\u07d6\u07cc\u07f0\u07d2\u07ec\u07de\u07ce\u07f2\u07ec\u07e0\u07cc\u07f2" },
  { u8"download-links-heading", u8"<b><i>{{BOOK_TITLE}}</i></b> \u07db\u07d8\u07cc\u07ec\u07dc\u07cb\u07f2 \u07e0\u07ca\u07d6\u07cc\u07f0 \u07cc \u07de\u07ce\u07f2\u07ec" },
  { u8"download-links-title", u8"\u07de\u07ca\u07ec\u07dd\u07ca \u07df\u07ca\u07d6\u07cc\u07f0 \u07cc \u07de\u07ce\u07f2\u07ec" },
  { u8"fulltext-search-unavailable", u8"\u07db\u07d3\u07cd\u07df\u07cc\u07eb \u07d8\u07dd\u07ca\u07e3\u07cd\u07f2 \u07e2\u07cc\u07e3\u07cc\u07f2\u07e0\u07cc\u07f2 \u07d5\u07cd\u07eb \u07e6\u07cb\u07f2\u07ec" },
  { u8"hash-download-alt-text", u8"\u07e4\u07ca\u07db\u07ed \u07df\u07ca\u07d6\u07cc\u07f0 \u07cc \u07de\u07ce\u07f2\u07ec" },
  { u8"home-button-text", u8"\u07d5\u07ca\u07ef {{BOOK_TITLE}} \u07d3\u07cf\u07ec\u07df\u07cf\u07f2\u07ec\u07d8\u07ca \u07de\u07d0\u07dc\u07cd \u07de\u07ca\u07f2\u07ec" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u07d5\u07cd\u07eb \u07e1\u07de\u07ca\u07ec\u07e3\u07cc\u07f2\u07ec\u07e3\u07cd\u07f2\u07eb \u07d3\u07cd\u07f2\u07ec\u07e3\u07cd\u07f2\u07eb \u07d8\u07cc\u07eb \u07de\u07e3\u07d0\u07d8\u07d0\u07eb \u07d8\u07dd\u07ca\u07e3\u07cd\u07f2 \u07de\u07ca\u07f2\u07e1\u07ca\u07ec." },
  { u8"library-button-text", u8"\u07d5\u07ca\u07ef \u07df\u07ca\u07ec\u07db\u07e3\u07cd\u07ec\u07df\u07cc\u07eb \u07de\u07d0\u07dc\u07cd \u07de\u07ca\u07f2\u07ec" },
  { u8"magnet-alt-text", u8"\u07e1\u07ca\u07e2\u07cd\u07d5 \u07df\u07ca\u07d6\u07cc\u07f0 \u07cc \u07de\u07ce\u07f2\u07ec" },
  { u8"magnet-link-text", u8"\u07e1\u07ca\u07e2\u07cd\u07d5 \u07db\u07d8\u07cc\u07ec\u07dc\u07cb\u07f2" },
  { u8"name", u8"\u07d2\u07de\u07cf" },
  { u8"no-book-found", u8"\u07de\u07dd\u07ca\u07ec \u07db\u07cc\u07eb \u07d3\u07cd\u07ec\u07e3\u07cd\u07f2\u07ec \u07d5\u07cd\u07eb \u07db\u07ce\u07e5\u07ca\u07f2\u07d8\u07df\u07cc \u07db\u07d9\u07ca\u07d5\u07cc \u07cf\u07ec \u07e1\u07ca\u07ec" },
  { u8"no-query", u8"\u07e1\u07de\u07ca\u07ec\u07e3\u07cc\u07f2\u07ec\u07e0\u07cc\u07f2\u07eb \u07db\u07cc\u07eb \u07e1\u07ca\u07eb \u07e1\u07ca\u07db\u07d0\u07eb." },
  { u8"no-search-results", u8"\u07db\u07d3\u07cd\u07df\u07cc\u07eb \u07d8\u07dd\u07ca\u07e3\u07cd\u07f2 \u07e2\u07cc\u07e3\u07cc\u07f2\u07e0\u07cc\u07f2\u07eb \u07e3\u07cc\u07d8\u07d0 \u07d5\u07cd\u07eb \u07e6\u07cb\u07f2\u07ec \u07de\u07e3\u07d0\u07d8\u07d0 \u07e3\u07cc\u07f2\u07ec \u07e2\u07cd\u07eb." },
  { u8"no-such-book", u8"\u07de\u07ca\u07ec\u07dd\u07ca\u07eb \u07db\u07ce\u07ee \u07cf\u07ec \u07d5\u07f4\u07e6\u07cb\u07f2\u07ec: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u07e1\u07d0\u07ec\u07df\u07d0\u07f2\u07ec \u07e1\u07ca\u07eb \u07e1\u07ca\u07db\u07d0\u07eb \u07d8\u07ca\u07d8\u07d0\u07e1\u07cc\u07e3\u07ca\u07de\u07ce\u07f2\u07e7\u07ca {{ARGUMENT}} \u07de\u07ca\u07f2\u07e1\u07ca\u07ec" },
  { u8"preview-book", u8"\u07ca\u07ec \u07d8\u07d0\u07dc\u07cd\u07eb \u07e1\u07ce\u07e3\u07ce\u07f2\u07ec" },
  { u8"random-article-failure", u8"\u07cf\u07ef\u07f9 \u07de\u07e2\u07ca\u07ec \u07d3\u07d8\u07ca\u07eb \u07de\u07cd\u07eb \u07d3\u07cd\u07f2\u07ec\u07db\u07cb\u07f2\u07ec\u07e1\u07ca\u07ec \u07de\u07ce\u07e1\u07d8\u07ca \u07db\u07d0\u07ec\u07d8\u07d0\u07f2\u07ec \u07e0\u07ca\u07eb:(" },
  { u8"random-page-button-text", u8"\u07d5\u07ca\u07ef \u07d3\u07cd\u07f2\u07ec\u07db\u07cb\u07f2\u07ec\u07e1\u07ca\u07ec \u07de\u07d0\u07dc\u07cd\u07eb \u07db\u07ce\u07e5\u07ca\u07f2\u07d8\u07cc\u07e3\u07cd\u07f2 \u07e0\u07ce\u07ec \u07de\u07ca\u07f2\u07ec" },
  { u8"raw-entry-not-found", u8"\u07df\u07ca\u07ec\u07d8\u07cf\u07f2\u07ec\u07e3\u07cd\u07f2 {{ENTRY}} {{DATATYPE}} \u07d5\u07cd\u07eb \u07e3\u07ca\u07ec \u07e1\u07ca\u07db\u07d0\u07ec\u07d8\u07d0\u07f2\u07eb \u07e0\u07ca\u07eb" },
  { u8"search", u8"\u07e2\u07cc\u07e3\u07cc\u07f2\u07e0\u07cc\u07f2" },
  { u8"searchbox-tooltip", u8"\u07d5\u07cc\u07d9\u07cc\u07f2\u07e0\u07cc\u07f2 {{BOOK_TITLE}}" },
  { u8"suggest-full-text-search", u8"\u07de\u07e3\u07d0\u07de\u07cd\u07e3\u07cd\u07f2\u07eb \u07e6\u07cb\u07eb '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"\u07db\u07d3\u07cd\u07df\u07cc\u07eb \u07d8\u07dd\u07ca\u07e3\u07cd\u07f2 \u07e2\u07cc\u07e3\u07cc\u07f2\u07e0\u07cc\u07f2 \u07de\u07cd\u07eb <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"\u07de\u07dd\u07ca\u07ec \u07db\u07cc\u07e6\u07ca\u07e1\u07ca\u07f2\u07eb \u07e1\u07ca\u07e2\u07cc\u07ec\u07e3\u07cc\u07f2\u07ec\u07de\u07ca\u07ec\u07e3\u07cd\u07f2\u07eb \u07de\u07cf\u07d6\u07ce\u07f0 {{NB_BOOKS}} \u07e1\u07cd\u07f2 \u07de\u07d0\u07d8\u07ca\u07f2 \u07e6\u07cb\u07eb {{LIMIT}} \u07d8\u07cc\u07eb" },
  { u8"torrent-download-alt-text", u8"\u07d5\u07cf\u07d9\u07cd\u07f2\u07d5 \u07df\u07ca\u07d6\u07cc\u07f0 \u07cc \u07de\u07ce\u07f2\u07ec" },
  { u8"torrent-download-link-text", u8"\u07d5\u07cf\u07d9\u07cd\u07f2\u07d5 \u07de\u07d0\u07d5\u07d0\u07ee" },
  { u8"url-not-found", u8"\u07cd\u07f2\u07ec\u07e4\u07cd\u07f2\u07eb ''URL ''{{url}} \u07e1\u07ca\u07e2\u07cc\u07ec\u07e3\u07cc\u07f2\u07ec\u07de\u07ca\u07ec\u07e3\u07cd\u07f2 \u07e1\u07ca\u07eb \u07db\u07d0\u07ec\u07d8\u07d0\u07f2\u07eb \u07e1\u07ca\u07ec\u07df\u07d0\u07ec\u07df\u07ca\u07f2 \u07e3\u07cc\u07f2\u07ec \u07e0\u07ca\u07eb." },
  { u8"welcome-page-overzealous-filter", u8"\u07de\u07d0\u07dd\u07df\u07cc\u07eb \u07d5\u07f4\u07e6\u07cb\u07f2\u07ec. \u07ca\u07ec \u07dd\u07d0\u07eb \u07cc \u07e6\u07f4\u07ca\u07ec \u07dd\u07cd\u07ec \u07de\u07ca\u07ec <a href=\"{{URL}}\">\u07db\u07cd\u07f2\u07db\u07cd\u07f2\u07df\u07ca\u07f2 \u07d8\u07d0\u07db\u07cc\u07f0 \u07d5\u07ce\u07f2\u07ef</a>\u061f" },
  { u8"welcome-to-kiwix-server", u8"\u07cc \u07e3\u07cc\u07eb \u07db\u07e3\u07cd\u07eb \u07de\u07e5\u07cc\u07de\u07db \u07e1\u07ca\u07db\u07d0\u07df\u07ca\u07f2 \u07de\u07e3\u07d0\u07eb" }
};


const I18nString string_table_for_or[] = {
  { u8"400-page-heading", u8"\u0b05\u0b2c\u0b48\u0b27 \u0b05\u0b28\u0b41\u0b30\u0b4b\u0b27" },
  { u8"400-page-title", u8"\u0b05\u0b2c\u0b48\u0b27 \u0b05\u0b28\u0b41\u0b30\u0b4b\u0b27" },
  { u8"404-page-heading", u8"\u0b2e\u0b3f\u0b33\u0b3f\u0b32\u0b3e\u0b28\u0b3e\u0b39\u0b3f\u0b01" },
  { u8"404-page-title", u8"\u0b2c\u0b3f\u0b37\u0b2f\u0b3c\u0b2c\u0b38\u0b4d\u0b24\u0b41 \u0b2e\u0b3f\u0b33\u0b41\u0b28\u0b3e\u0b39\u0b3f\u0b01" },
  { u8"500-page-heading", u8"\u0b06\u0b28\u0b4d\u0b24\u0b30\u0b3f\u0b15 \u0b38\u0b30\u0b4d\u0b2d\u0b30 \u0b24\u0b43\u0b1f\u0b3f" },
  { u8"500-page-title", u8"\u0b06\u0b28\u0b4d\u0b24\u0b30\u0b3f\u0b15 \u0b38\u0b30\u0b4d\u0b2d\u0b30 \u0b24\u0b43\u0b1f\u0b3f" },
  { u8"book-filtering-all-categories", u8"\u0b38\u0b2e\u0b38\u0b4d\u0b24 \u0b2c\u0b30\u0b4d\u0b17 |" },
  { u8"book-filtering-all-languages", u8"\u0b38\u0b2e\u0b38\u0b4d\u0b24 \u0b2d\u0b3e\u0b37\u0b3e" },
  { u8"confusion-of-tongues", u8"\u0b2c\u0b3f\u0b2d\u0b3f\u0b28\u0b4d\u0b28 \u0b2d\u0b3e\u0b37\u0b3e\u0b30\u0b47 \u0b26\u0b41\u0b07 \u0b15\u0b3f\u0b2e\u0b4d\u0b2c\u0b3e \u0b05\u0b27\u0b3f\u0b15 \u0b2a\u0b41\u0b38\u0b4d\u0b24\u0b15 \u0b38\u0b30\u0b4d\u0b1a\u0b4d\u0b1a\u0b30\u0b47 \u0b05\u0b02\u0b36\u0b17\u0b4d\u0b30\u0b39\u0b23 \u0b15\u0b30\u0b3f\u0b2c\u0b47 \u0b2f\u0b3e\u0b39\u0b3e \u0b2c\u0b3f\u0b2d\u0b4d\u0b30\u0b3e\u0b28\u0b4d\u0b24\u0b3f\u0b15\u0b30 \u0b2b\u0b33\u0b3e\u0b2b\u0b33 \u0b06\u0b23\u0b3f\u0b2a\u0b3e\u0b30\u0b47 |" },
  { u8"count-of-matching-books", u8"{{COUNT}} \u0b2a\u0b41\u0b38\u0b4d\u0b24\u0b15 (\u0b17\u0b41\u0b21\u0b3f\u0b15)" },
  { u8"direct-download-alt-text", u8"\u0b38\u0b3f\u0b27\u0b3e\u0b38\u0b33\u0b16 \u0b21\u0b3e\u0b09\u0b28\u0b32\u0b4b\u0b21\u0b4d |" },
  { u8"direct-download-link-text", u8"\u0b38\u0b3f\u0b27\u0b3e\u0b38\u0b33\u0b16 |" },
  { u8"download", u8"\u0b21\u0b3e\u0b09\u0b28\u0b32\u0b4b\u0b21\u0b3c" },
  { u8"download-links-heading", u8"<b><i>${{BOOK_TITLE}} for</i></b> \u0b2a\u0b3e\u0b07\u0b01 \u0b32\u0b3f\u0b19\u0b4d\u0b15\u0b4d \u0b21\u0b3e\u0b09\u0b28\u0b32\u0b4b\u0b21\u0b4d \u0b15\u0b30\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"download-links-title", u8"\u0b2c\u0b39\u0b3f \u0b21\u0b3e\u0b09\u0b28\u0b32\u0b4b\u0b21\u0b4d \u0b15\u0b30\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"filter-by-tag", u8"\u0b1f\u0b4d\u0b5f\u0b3e\u0b17\u0b4d \u0b26\u0b4d\u0b71\u0b3e\u0b30\u0b3e \u0b2b\u0b3f\u0b32\u0b4d\u0b1f\u0b30\u0b4d \"{{TAG}}\"" },
  { u8"fulltext-search-unavailable", u8"\u0b2a\u0b42\u0b30\u0b4d\u0b23\u0b4d\u0b23 \u0b2a\u0b3e\u0b20 \u0b38\u0b28\u0b4d\u0b27\u0b3e\u0b28 \u0b09\u0b2a\u0b32\u0b2c\u0b4d\u0b27 \u0b28\u0b3e\u0b39\u0b3f\u0b01 |" },
  { u8"hash-download-alt-text", u8"\u0b39\u0b4d\u0b5f\u0b3e\u0b38\u0b4d \u0b21\u0b3e\u0b09\u0b28\u0b32\u0b4b\u0b21\u0b4d \u0b15\u0b30\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"hash-download-link-text", u8"Sha256 \u0b39\u0b4d\u0b5f\u0b3e\u0b38\u0b4d |" },
  { u8"home-button-text", u8"'{{BOOK_TITLE}}' \u0b30 \u0b2e\u0b41\u0b16\u0b4d\u0b5f \u0b2a\u0b43\u0b37\u0b4d\u0b20\u0b3e\u0b15\u0b41 \u0b2f\u0b3e\u0b06\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u0b15\u0b1e\u0b4d\u0b1a\u0b3e \u0b2c\u0b3f\u0b37\u0b5f\u0b2c\u0b38\u0b4d\u0b24\u0b41 \u0b2a\u0b3e\u0b07\u0b01 \u0b0f\u0b15 \u0b2c valid \u0b27 \u0b05\u0b28\u0b41\u0b30\u0b4b\u0b27 \u0b28\u0b41\u0b39\u0b47\u0b01 |" },
  { u8"library-button-text", u8"\u0b38\u0b4d\u0b71\u0b3e\u0b17\u0b24 \u0b2a\u0b43\u0b37\u0b4d\u0b20\u0b3e\u0b15\u0b41 \u0b2f\u0b3e\u0b06\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"library-opds-feed-all-entries", u8"\u0b32\u0b3e\u0b07\u0b2c\u0b4d\u0b30\u0b47\u0b30\u0b40 OPDS \u0b2b\u0b3f\u0b21\u0b4d - \u0b38\u0b2e\u0b38\u0b4d\u0b24 \u0b0f\u0b23\u0b4d\u0b1f\u0b4d\u0b30\u0b3f\u0b17\u0b41\u0b21\u0b3f\u0b15 |" },
  { u8"library-opds-feed-parameterised", u8"\u0b32\u0b3e\u0b07\u0b2c\u0b4d\u0b30\u0b47\u0b30\u0b40 OPDS \u0b2b\u0b3f\u0b21\u0b4d - \u0b0f\u0b23\u0b4d\u0b1f\u0b4d\u0b30\u0b3f\u0b17\u0b41\u0b21\u0b3f\u0b15 {{#LANG}}! N! \u0b2d\u0b3e\u0b37\u0b3e! ${{LANG}} ! {#TAG}} Category: ${{CATEGORY}} \u0b1f\u0b4d\u0b5f\u0b3e\u0b17\u0b4d: ${{TAG}} {{/ TAG}} {{# Q}}!  \u0b2a\u0b4d\u0b30\u0b36\u0b4d\u0b28: {{Q}} {{/ Q}}" },
  { u8"magnet-alt-text", u8"\u0b1a\u0b41\u0b2e\u0b4d\u0b2c\u0b15 \u0b21\u0b3e\u0b09\u0b28\u0b32\u0b4b\u0b21\u0b4d \u0b15\u0b30\u0b28\u0b4d\u0b24\u0b41" },
  { u8"magnet-link-text", u8"\u0b1a\u0b41\u0b2e\u0b4d\u0b2c\u0b15\u0b40\u0b5f \u0b32\u0b3f\u0b19\u0b4d\u0b15\u0b4d" },
  { u8"name", u8"\u0b13\u0b21\u0b3c\u0b3f\u0b06" },
  { u8"no-book-found", u8"\u0b15\u0b4c\u0b23\u0b38\u0b3f \u0b2a\u0b41\u0b38\u0b4d\u0b24\u0b15 \u0b1a\u0b2f\u0b3c\u0b28 \u0b2e\u0b3e\u0b28\u0b26\u0b23\u0b4d\u0b21 \u0b38\u0b39 \u0b2e\u0b47\u0b33 \u0b16\u0b3e\u0b09\u0b28\u0b3e\u0b39\u0b3f\u0b01 \u0964" },
  { u8"no-query", u8"\u0b15\u0b4c\u0b23\u0b38\u0b3f \u0b2a\u0b4d\u0b30\u0b36\u0b4d\u0b28 \u0b2a\u0b4d\u0b30\u0b26\u0b3e\u0b28 \u0b15\u0b30\u0b3e\u0b2f\u0b3e\u0b07\u0b28\u0b3e\u0b39\u0b3f\u0b01 \u0964" },
  { u8"no-search-results", u8"\u0b0f\u0b39\u0b3f \u0b2c\u0b3f\u0b37\u0b5f\u0b2c\u0b38\u0b4d\u0b24\u0b41 \u0b2a\u0b3e\u0b07\u0b01 \u0b2b\u0b41\u0b32\u0b4d \u0b1f\u0b47\u0b15\u0b4d\u0b38\u0b1f\u0b4d \u0b38\u0b30\u0b4d\u0b1a\u0b4d\u0b1a \u0b07\u0b1e\u0b4d\u0b1c\u0b3f\u0b28\u0b4d \u0b09\u0b2a\u0b32\u0b2c\u0b4d\u0b27 \u0b28\u0b3e\u0b39\u0b3f\u0b01 |" },
  { u8"no-such-book", u8"\u0b0f\u0b2a\u0b30\u0b3f \u0b15\u0b4c\u0b23\u0b38\u0b3f \u0b2a\u0b41\u0b38\u0b4d\u0b24\u0b15 \u0b28\u0b3e\u0b39\u0b3f\u0b01\u0b03 ${{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u0b2f\u0b41\u0b15\u0b4d\u0b24\u0b3f \u0b2a\u0b3e\u0b07\u0b01 \u0b15\u0b4c\u0b23\u0b38\u0b3f \u0b2e\u0b42\u0b32\u0b4d\u0b2f\u0b3c \u0b2a\u0b4d\u0b30\u0b26\u0b3e\u0b28 \u0b15\u0b30\u0b3e\u0b2f\u0b3e\u0b07\u0b28\u0b3e\u0b39\u0b3f\u0b01 ${{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"<a href=\"https://kiwix.org\">\u0b15\u0b3f\u0b71\u0b3f\u0b15\u0b4d\u0b38</a> \u0b26\u0b4d\u0b71\u0b3e\u0b30\u0b3e \u0b1a\u0b3e\u0b33\u0b3f\u0b24 |" },
  { u8"preview-book", u8"\u0b2a\u0b42\u0b30\u0b4d\u0b2c\u0b30\u0b42\u0b2a" },
  { u8"random-article-failure", u8"\u0b13\u0b39\u0b4b! \u0b0f\u0b15 \u0b05\u0b28\u0b3f\u0b5f\u0b2e\u0b3f\u0b24 \u0b2a\u0b4d\u0b30\u0b2c\u0b28\u0b4d\u0b27 \u0b2c\u0b3e\u0b1b\u0b3f\u0b2c\u0b3e\u0b30\u0b47 \u0b2c\u0b3f\u0b2b\u0b33 :(" },
  { u8"random-page-button-text", u8"\u0b0f\u0b15 \u0b05\u0b28\u0b3f\u0b5f\u0b2e\u0b3f\u0b24 \u0b2d\u0b3e\u0b2c\u0b30\u0b47 \u0b2e\u0b28\u0b4b\u0b28\u0b40\u0b24 \u0b2a\u0b43\u0b37\u0b4d\u0b20\u0b3e\u0b15\u0b41 \u0b2f\u0b3e\u0b06\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"raw-entry-not-found", u8"${{DATATYPE}}  ${{ENTRY}} \u0b15\u0b41 \u0b16\u0b4b\u0b1c\u0b3f \u0b2a\u0b3e\u0b30\u0b41\u0b28\u0b3e\u0b39\u0b3f\u0b01|" },
  { u8"search", u8"\u0b16\u0b4b\u0b1c\u0b28\u0b4d\u0b24\u0b41" },
  { u8"searchbox-tooltip", u8"'{{BOOK_TITLE}}' \u0b38\u0b28\u0b4d\u0b27\u0b3e\u0b28 \u0b15\u0b30\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"stop-filtering-by-tag", u8"\"${{TAG}}\" \u0b1f\u0b4d\u0b5f\u0b3e\u0b17\u0b4d \u0b26\u0b4d\u0b71\u0b3e\u0b30\u0b3e \u0b2b\u0b3f\u0b32\u0b4d\u0b1f\u0b30 \u0b15\u0b30\u0b3f\u0b2c\u0b3e \u0b2c\u0b28\u0b4d\u0b26 \u0b15\u0b30\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"suggest-full-text-search", u8"${{{SEARCH_TERMS}}} \u0b27\u0b3e\u0b30\u0b23 \u0b15\u0b30\u0b3f\u0b1b\u0b3f ..." },
  { u8"suggest-search", u8"<a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a> \u0b2a\u0b3e\u0b07\u0b01 \u0b2a\u0b42\u0b30\u0b3e \u0b2a\u0b3e\u0b20 \u0b16\u0b4b\u0b1c\u0b28\u0b4d\u0b24\u0b41 |" },
  { u8"too-many-books", u8"\u0b05\u0b24\u0b4d\u0b5f\u0b27\u0b3f\u0b15 \u0b2c\u0b39\u0b3f \u0b05\u0b28\u0b41\u0b30\u0b4b\u0b27 (${{NB_BOOKS}}) \u0b2f\u0b47\u0b09\u0b01\u0b20\u0b3e\u0b30\u0b47 \u0b38\u0b40\u0b2e\u0b3e ${{LIMIT}} |" },
  { u8"torrent-download-alt-text", u8"torrent \u0b21\u0b3e\u0b09\u0b28\u0b32\u0b4b\u0b21\u0b4d \u0b15\u0b30\u0b28\u0b4d\u0b24\u0b41" },
  { u8"torrent-download-link-text", u8"\u0b1f\u0b4b\u0b30\u0b47\u0b23\u0b4d\u0b1f \u0b2b\u0b3e\u0b07\u0b32\u0b4d |" },
  { u8"url-not-found", u8"\u0b05\u0b28\u0b41\u0b30\u0b4b\u0b27 \u0b15\u0b30\u0b3e\u0b2f\u0b3e\u0b07\u0b25\u0b3f\u0b2c\u0b3e URL \"{{url}}\" \u0b0f\u0b39\u0b3f \u0b38\u0b30\u0b4d\u0b2d\u0b30\u0b30\u0b47 \u0b2e\u0b3f\u0b33\u0b3f\u0b32\u0b3e \u0b28\u0b3e\u0b39\u0b3f\u0b01 |" },
  { u8"welcome-page-overzealous-filter", u8"\u0b15\u0b4c\u0b23\u0b38\u0b3f \u0b2b\u0b33\u0b3e\u0b2b\u0b33 \u0b28\u0b3e\u0b39\u0b3f\u0b01 | \u0b06\u0b2a\u0b23 <a href=\"{{URL}}\">\u0b2b\u0b3f\u0b32\u0b4d\u0b1f\u0b30 \u0b2a\u0b41\u0b28 res \u0b38\u0b47\u0b1f\u0b4d</a> \u0b15\u0b30\u0b3f\u0b2c\u0b3e\u0b15\u0b41 \u0b1a\u0b3e\u0b39\u0b41\u0b01\u0b1b\u0b28\u0b4d\u0b24\u0b3f \u0b15\u0b3f?" },
  { u8"welcome-to-kiwix-server", u8"Kiwix \u0b38\u0b30\u0b4d\u0b2d\u0b30\u0b15\u0b41 \u0b38\u0b4d\u0b71\u0b3e\u0b17\u0b24 |" }
};


const I18nString string_table_for_pl[] = {
  { u8"400-page-heading", u8"Nieprawid\u0142owe \u017c\u0105danie" },
  { u8"400-page-title", u8"Nieprawid\u0142owe \u017c\u0105danie" },
  { u8"404-page-heading", u8"Nie znaleziono" },
  { u8"404-page-title", u8"Zawarto\u015b\u0107 nie zosta\u0142a znaleziona" },
  { u8"500-page-heading", u8"Wewn\u0119trzny b\u0142\u0105d serwera" },
  { u8"500-page-title", u8"Wewn\u0119trzny b\u0142\u0105d serwera" },
  { u8"book-category.other", u8"Inne" },
  { u8"book-filtering-all-categories", u8"Wszystkie Kategorie" },
  { u8"book-filtering-all-languages", u8"Wszystkie j\u0119zyki" },
  { u8"direct-download-alt-text", u8"bezpo\u015brednie pobieranie" },
  { u8"direct-download-link-text", u8"Bezpo\u015brednio" },
  { u8"download", u8"Pobierz" },
  { u8"download-links-title", u8"Pobierz ksi\u0105\u017ck\u0119" },
  { u8"fulltext-search-unavailable", u8"Wyszukiwanie pe\u0142notekstowe jest niedost\u0119pne" },
  { u8"home-button-text", u8"Przejd\u017a do g\u0142\u00f3wnej strony '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} nie jest prawid\u0142owym \u017c\u0105daniem zawarto\u015bci nieprzetworzonej." },
  { u8"library-button-text", u8"Przejd\u017a do strony powitalnej" },
  { u8"name", u8"Polski" },
  { u8"no-search-results", u8"Wyszukiwarka pe\u0142notekstowa nie jest dost\u0119pna dla tej zawarto\u015bci." },
  { u8"no-such-book", u8"Brak takiej ksi\u0105\u017cki: {{BOOK_NAME}}" },
  { u8"preview-book", u8"Podgl\u0105d" },
  { u8"random-article-failure", u8"Ups! Nie uda\u0142o si\u0119 wybra\u0107 losowego artyku\u0142u :(" },
  { u8"random-page-button-text", u8"Przejd\u017a do losowo wybranej strony" },
  { u8"raw-entry-not-found", u8"Nie mo\u017cna znale\u017a\u0107 {{DATATYPE}} wpisu {{ENTRY}}" },
  { u8"search", u8"Szukaj" },
  { u8"searchbox-tooltip", u8"Szukaj '{{BOOK_TITLE}}'" },
  { u8"suggest-full-text-search", u8"zawieraj\u0105cy '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Wykonaj wyszukiwanie pe\u0142notekstowe dla <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"torrent-download-link-text", u8"Plik torrent" },
  { u8"url-not-found", u8"\u017b\u0105dany adres URL \u201e{{url}}\u201d nie zosta\u0142 znaleziony na tym serwerze." },
  { u8"welcome-to-kiwix-server", u8"Witamy na serwerze Kiwix" }
};


const I18nString string_table_for_pt_br[] = {
  { u8"400-page-heading", u8"Requisi\u00e7\u00e3o inv\u00e1lida" },
  { u8"400-page-title", u8"Requisi\u00e7\u00e3o inv\u00e1lida" },
  { u8"404-page-heading", u8"N\u00e3o encontrado" },
  { u8"404-page-title", u8"Conte\u00fado n\u00e3o encontrado" },
  { u8"500-page-heading", u8"Erro interno do servidor" },
  { u8"500-page-text", u8"Aconteceu um erro interno do servidor. N\u00f3s pedimos desculpas sobre isso :/" },
  { u8"500-page-title", u8"Erro interno do servidor" },
  { u8"book-category.other", u8"Outro" },
  { u8"book-category.wikibooks", u8"Wikilivros" },
  { u8"book-category.wikinews", u8"Wikinot\u00edcias" },
  { u8"book-category.wikipedia", u8"Wikip\u00e9dia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikisp\u00e9cies" },
  { u8"book-category.wikiversity", u8"Wikiversidade" },
  { u8"book-category.wiktionary", u8"Wikcion\u00e1rio" },
  { u8"book-filtering-all-categories", u8"Todas as categorias" },
  { u8"book-filtering-all-languages", u8"Todos os idiomas" },
  { u8"caution-warning", u8"Cuidado!" },
  { u8"confusion-of-tongues", u8"Dois ou mais livros em diferentes idiomas podem participar da pesquisa, isso pode proporcionar resultados confusos." },
  { u8"count-of-matching-books", u8"{{COUNT}} livro(s)" },
  { u8"direct-download-alt-text", u8"Baixar diretamente por HTTP(S)" },
  { u8"direct-download-link-text", u8"Direto" },
  { u8"download", u8"Baixar" },
  { u8"download-links-heading", u8"Links para baixar <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Download do livro" },
  { u8"empty-search-results-page-header", u8"Nenhum resultado encontrado para <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"filter-by-tag", u8"Filtrar por etiqueta \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"Busca por texto completo est\u00e1 indispon\u00edvel" },
  { u8"hash-download-alt-text", u8"Exibir arquivo de verifica\u00e7\u00e3o SHA-256" },
  { u8"hash-download-link-text", u8"Verifica\u00e7\u00e3o SHA-256" },
  { u8"home-button-text", u8"Ir para p\u00e1gina principal de '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} n\u00e3o \u00e9 uma solicita\u00e7\u00e3o v\u00e1lida para conte\u00fado bruto." },
  { u8"invalid-request", u8"O URL solicitado \"{{{url}}}\" n\u00e3o \u00e9 uma solicita\u00e7\u00e3o v\u00e1lida." },
  { u8"library-button-text", u8"Ir para p\u00e1gina inicial" },
  { u8"library-opds-feed-all-entries", u8"Feed OPDS da biblioteca - Todas as entradas" },
  { u8"library-opds-feed-parameterised", u8"Biblioteca OPDS Feed - entradas que correspondem a {{#LANG}}\nIdioma: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategoria: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\nConsulta: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Baixar por link Magnet" },
  { u8"magnet-link-text", u8"Link Magnet" },
  { u8"name", u8"Portugu\u00eas" },
  { u8"no-book-found", u8"Nenhum livro corresponde os crit\u00e9rios de sele\u00e7\u00e3o" },
  { u8"no-query", u8"Nenhuma consulta fornecida." },
  { u8"no-search-results", u8"O motor de busca de texto completo n\u00e3o est\u00e1 dispon\u00edvel para este conte\u00fado." },
  { u8"no-such-book", u8"N\u00e3o existe o livro: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Nenhum valor para o argumento {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Desenvolvido por <a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Pr\u00e9-visualizar" },
  { u8"random-article-failure", u8"Ops! Falha ao escolher um artigo aleat\u00f3rio :(" },
  { u8"random-page-button-text", u8"Ir para uma p\u00e1gina aleat\u00f3ria" },
  { u8"search", u8"Pesquisar" },
  { u8"search-result-book-info", u8"de {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Resultados <b>{{START}}-{{END}}</b> de <b>{{COUNT}}</b> para <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Buscar: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Buscar '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Parar de filtrar por etiqueta \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"Contendo '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Fazer uma pesquisa de texto completo para <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Muitos livros solicitados {{NB_BOOKS}} mas o limite \u00e9 {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Baixar via BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Erro desconhecido" },
  { u8"url-not-found", u8"O URL \"{{url}}\" n\u00e3o foi encontrado neste servidor." },
  { u8"welcome-page-overzealous-filter", u8"Nenhum resultado. Gostaria de <a href=\"{{URL}}\">redefinir o filtro</a> ?" },
  { u8"welcome-to-kiwix-server", u8"Bem vindo ao servidor Kiwix" },
  { u8"word-count", u8"{{COUNT}} palavras" }
};


const I18nString string_table_for_pt[] = {
  { u8"400-page-heading", u8"Solicita\u00e7\u00e3o inv\u00e1lida" },
  { u8"400-page-title", u8"Solicita\u00e7\u00e3o inv\u00e1lida" },
  { u8"404-page-heading", u8"N\u00e3o encontrado" },
  { u8"404-page-title", u8"Conte\u00fado n\u00e3o encontrado" },
  { u8"500-page-heading", u8"Erro interno do servidor" },
  { u8"500-page-text", u8"Ocorreu um erro interno do servidor. Lamentamos por isso :/" },
  { u8"500-page-title", u8"Erro interno do servidor" },
  { u8"book-category.other", u8"Outro" },
  { u8"book-category.wikibooks", u8"Wikilivros" },
  { u8"book-category.wikinews", u8"Wikinot\u00edcias" },
  { u8"book-category.wikipedia", u8"Wikip\u00e9dia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversidade" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wikcion\u00e1rio" },
  { u8"book-filtering-all-categories", u8"Todas as categorias" },
  { u8"book-filtering-all-languages", u8"Todos os idiomas" },
  { u8"confusion-of-tongues", u8"Dois ou mais livros em idiomas diferentes participariam da pesquisa, o que poderia levar a resultados confusos." },
  { u8"count-of-matching-books", u8"{{COUNT}} livro(s)" },
  { u8"direct-download-alt-text", u8"Descarregar diretamente atrav\u00e9s de HTTP (S)" },
  { u8"direct-download-link-text", u8"Direto" },
  { u8"download", u8"Transferir" },
  { u8"download-links-heading", u8"Links para download de <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Descarregar livros" },
  { u8"empty-search-results-page-header", u8"Nenhum resultado foi encontrado para <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"filter-by-tag", u8"Filtrar por tag \"{{TAG}}\"" },
  { u8"fulltext-search-unavailable", u8"Pesquisa de texto completo indispon\u00edvel" },
  { u8"hash-download-alt-text", u8"Exibir arquivo de verifica\u00e7\u00e3o SHA-256" },
  { u8"hash-download-link-text", u8"Verifica\u00e7\u00e3o SHA-256" },
  { u8"home-button-text", u8"V\u00e1 para a p\u00e1gina principal de '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} n\u00e3o \u00e9 uma solicita\u00e7\u00e3o v\u00e1lida para conte\u00fado bruto." },
  { u8"invalid-request", u8"A URL solicitada \"{{{url}}}\" n\u00e3o \u00e9 uma solicita\u00e7\u00e3o v\u00e1lida." },
  { u8"library-button-text", u8"Ir para p\u00e1gina inicial" },
  { u8"library-opds-feed-all-entries", u8"Feed OPDS da biblioteca - Todas as entradas" },
  { u8"library-opds-feed-parameterised", u8"Feed OPDS da biblioteca - entradas que correspondem a {{#LANG}}\nIdioma: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategoria: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\nConsulta: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Descarregar atrav\u00e9s do link Magnet" },
  { u8"magnet-link-text", u8"Link magn\u00e9tico" },
  { u8"name", u8"portugu\u00eas" },
  { u8"no-book-found", u8"Nenhum livro corresponde aos crit\u00e9rios de sele\u00e7\u00e3o" },
  { u8"no-query", u8"Nenhuma consulta fornecida." },
  { u8"no-search-results", u8"O motor de busca de texto completo n\u00e3o est\u00e1 dispon\u00edvel para este conte\u00fado." },
  { u8"no-such-book", u8"N\u00e3o existe o livro: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Nenhum valor fornecido para o argumento {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Desenvolvido por <a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Pr\u00e9-visualiza\u00e7\u00e3o" },
  { u8"random-article-failure", u8"Ups! Erro ao eleger um artigo aleat\u00f3rio :(" },
  { u8"random-page-button-text", u8"V\u00e1 para uma p\u00e1gina selecionada aleatoriamente" },
  { u8"raw-entry-not-found", u8"N\u00e3o \u00e9 poss\u00edvel encontrar a entrada {{DATATYPE}} {{ENTRY}}" },
  { u8"search", u8"Pesquisar" },
  { u8"search-result-book-info", u8"de {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Resultados <b>{{START}}-{{END}}</b> de <b>{{COUNT}}</b> para <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"Pesquisar: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Procurar '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Pare de filtrar pela tag \"{{TAG}}\"" },
  { u8"suggest-full-text-search", u8"contendo '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Fa\u00e7a uma pesquisa de texto completo para <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Demasiadas solicita\u00e7\u00f5es de livros ({{NB_BOOKS}}) onde o limite \u00e9 {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Descarregar atrav\u00e9s de BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Erro desconhecido" },
  { u8"url-not-found", u8"A URL solicitada \"{{url}}\" n\u00e3o foi encontrada neste servidor." },
  { u8"welcome-page-overzealous-filter", u8"Nenhum resultado. Gostaria de <a href=\"{{URL}}\">redefinir o filtro</a> ?" },
  { u8"welcome-to-kiwix-server", u8"Bem-vindo ao Kiwix Server" },
  { u8"word-count", u8"{{COUNT}} palavras" }
};


const I18nString string_table_for_ro[] = {
  { u8"400-page-heading", u8"Cerere invalid\u0103" },
  { u8"400-page-title", u8"Cerere invalid\u0103" },
  { u8"404-page-heading", u8"Nu a fost g\u0103sit" },
  { u8"404-page-title", u8"Con\u021binut nu a fost g\u0103sit" },
  { u8"500-page-heading", u8"Eroare intern\u0103 de server" },
  { u8"500-page-text", u8"A ap\u0103rut o eroare intern\u0103 de server. Ne pare rau pentru asta :/" },
  { u8"500-page-title", u8"Eroare intern\u0103 de server" },
  { u8"book-category.other", u8"Altul" },
  { u8"book-category.wikibooks", u8"Wikimanuale" },
  { u8"book-category.wikinews", u8"Wiki\u0219tiri" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikicitat" },
  { u8"book-category.wikisource", u8"Wikisurs\u0103" },
  { u8"book-category.wikispecies", u8"Wikispecii" },
  { u8"book-category.wikiversity", u8"Wikiversitate" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wik\u021bionar" },
  { u8"book-filtering-all-categories", u8"Toate categoriile" },
  { u8"book-filtering-all-languages", u8"Toate limbile" },
  { u8"confusion-of-tongues", u8"Dou\u0103 sau mai multe c\u0103r\u021bi \u00een limbi diferite ar participa la c\u0103utare, ceea ce poate duce la rezultate confuze." },
  { u8"count-of-matching-books", u8"{{COUNT}} c\u0103r\u021bi" },
  { u8"direct-download-alt-text", u8"Desc\u0103rca\u021bi direct prin HTTP(S)" },
  { u8"direct-download-link-text", u8"Direct" },
  { u8"download", u8"Desc\u0103rcare" },
  { u8"download-links-heading", u8"Desc\u0103rca\u021bi linkuri pentru <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Desc\u0103rc\u0103 cartea" },
  { u8"empty-search-results-page-header", u8"Nu au fost g\u0103site rezultate pentru <b>\u201e{{{SEARCH_PATTERN}}}\u201d</b>" },
  { u8"external-link-intro", u8"E\u0219ti pe cale s\u0103 p\u0103r\u0103se\u0219ti cititorul ZIM al Kiwix pentru a te conecta la..." },
  { u8"filter-by-tag", u8"Filtra\u021bi dup\u0103 eticheta \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"C\u0103utarea text integral indisponibil\u0103" },
  { u8"hash-download-alt-text", u8"Afi\u0219eaz\u0103 suma de verificare a fi\u0219ierului SHA-256" },
  { u8"hash-download-link-text", u8"Sum\u0103 de control SHA-256" },
  { u8"home-button-text", u8"Accesa\u021bi pagina principal\u0103 a \u201e{{BOOK_TITLE}}\u201d" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} nu este o solicitare valid\u0103 pentru con\u021binut brut." },
  { u8"invalid-request", u8"Adresa URL solicitat\u0103 \"{{{url}}}\" nu este o solicitare valid\u0103." },
  { u8"library-button-text", u8"Mergi la pagina de pornire" },
  { u8"library-opds-feed-all-entries", u8"Bibliotec\u0103 OPDS Feed - Toate intr\u0103rile" },
  { u8"library-opds-feed-parameterised", u8"Bibliotec\u0103 OPDS Feed - intr\u0103ri care se potrivesc cu {{#LANG}}\nLimba: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategorie: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nEtichet\u0103: {{TAG}} {{/TAG}}{{#Q}}\nInterogare: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Desc\u0103rca\u021bi prin linkul Magnet" },
  { u8"magnet-link-text", u8"Leg\u0103tur\u0103 magnetic\u0103" },
  { u8"name", u8"Englez\u0103" },
  { u8"no-book-found", u8"Nicio carte nu corespunde criteriilor de selec\u021bie" },
  { u8"no-query", u8"Nu a fost furnizat\u0103 nicio interogare." },
  { u8"no-search-results", u8"Motorul de c\u0103utare textintegral nu este disponibil pentru acest con\u021binut." },
  { u8"no-such-book", u8"Nu exist\u0103 o astfel de carte: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Nu este furnizat\u0103 nicio valoare pentru argumentul {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Sus\u021binut de&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Previzualizare" },
  { u8"random-article-failure", u8"Hopa! Nu s-a putut alege un articol aleatoriu :(" },
  { u8"random-page-button-text", u8"Accesa\u021bi o pagin\u0103 selectat\u0103 aleatoriu" },
  { u8"raw-entry-not-found", u8"Nu se poate g\u0103si {{DATATYPE}} intrarea {{ENTRY}}" },
  { u8"search", u8"Caut\u0103" },
  { u8"search-result-book-info", u8"din {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Rezultatele <b>{{START}}-{{END}}</b> din <b>{{COUNT}}</b> pentru <b>\u201e{{{SEARCH_PATTERN}}}\u201d</b>" },
  { u8"search-results-page-title", u8"C\u0103utare: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"C\u0103uta\u021bi \u201e{{BOOK_TITLE}}\u201d" },
  { u8"stop-filtering-by-tag", u8"Opri\u021bi filtrarea dup\u0103 eticheta \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"care con\u021bine '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Efectua\u021bi o c\u0103utare text complet pentru <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Prea multe c\u0103r\u021bi solicitate ({{NB_BOOKS}}) unde limita este {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Desc\u0103rca\u021bi prin BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Eroare necunoscut\u0103" },
  { u8"url-not-found", u8"Adresa URL solicitat\u0103 \"{{url}}\" nu a fost g\u0103sit\u0103 pe acest server." },
  { u8"welcome-page-overzealous-filter", u8"Nici un rezultat. Dori\u021bi s\u0103 <a href=\"{{URL}}\">reseta\u021bi filtrul</a>?" },
  { u8"welcome-to-kiwix-server", u8"Bun venit la Kiwix Server" },
  { u8"word-count", u8"{{COUNT}} cuvinte" }
};


const I18nString string_table_for_ru[] = {
  { u8"400-page-heading", u8"\u041d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439 \u0437\u0430\u043f\u0440\u043e\u0441" },
  { u8"400-page-title", u8"\u041d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439 \u0437\u0430\u043f\u0440\u043e\u0441" },
  { u8"404-page-heading", u8"\u041d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e" },
  { u8"404-page-title", u8"\u0421\u043e\u0434\u0435\u0440\u0436\u0430\u043d\u0438\u0435 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e" },
  { u8"500-page-heading", u8"\u0412\u043d\u0443\u0442\u0440\u0435\u043d\u043d\u044f\u044f \u043e\u0448\u0438\u0431\u043a\u0430 \u0441\u0435\u0440\u0432\u0435\u0440\u0430" },
  { u8"500-page-text", u8"\u041f\u0440\u043e\u0438\u0437\u043e\u0448\u043b\u0430 \u0432\u043d\u0443\u0442\u0440\u0435\u043d\u043d\u044f\u044f \u043e\u0448\u0438\u0431\u043a\u0430 \u0441\u0435\u0440\u0432\u0435\u0440\u0430. \u041c\u044b \u0441\u043e\u0436\u0430\u043b\u0435\u0435\u043c \u043e\u0431 \u044d\u0442\u043e\u043c :/" },
  { u8"500-page-title", u8"\u0412\u043d\u0443\u0442\u0440\u0435\u043d\u043d\u044f\u044f \u043e\u0448\u0438\u0431\u043a\u0430 \u0441\u0435\u0440\u0432\u0435\u0440\u0430" },
  { u8"book-category.other", u8"\u0414\u0440\u0443\u0433\u043e\u0435" },
  { u8"book-category.wikibooks", u8"\u0412\u0438\u043a\u0438\u0443\u0447\u0435\u0431\u043d\u0438\u043a" },
  { u8"book-category.wikinews", u8"\u0412\u0438\u043a\u0438\u043d\u043e\u0432\u043e\u0441\u0442\u0438" },
  { u8"book-category.wikipedia", u8"\u0412\u0438\u043a\u0438\u043f\u0435\u0434\u0438\u044f" },
  { u8"book-category.wikiquote", u8"\u0412\u0438\u043a\u0438\u0446\u0438\u0442\u0430\u0442\u043d\u0438\u043a" },
  { u8"book-category.wikisource", u8"\u0412\u0438\u043a\u0438\u0442\u0435\u043a\u0430" },
  { u8"book-category.wikispecies", u8"\u0412\u0438\u043a\u0438\u0432\u0438\u0434\u044b" },
  { u8"book-category.wikiversity", u8"\u0412\u0438\u043a\u0438\u0432\u0435\u0440\u0441\u0438\u0442\u0435\u0442" },
  { u8"book-category.wikivoyage", u8"\u0412\u0438\u043a\u0438\u0433\u0438\u0434" },
  { u8"book-category.wiktionary", u8"\u0412\u0438\u043a\u0438\u0441\u043b\u043e\u0432\u0430\u0440\u044c" },
  { u8"book-filtering-all-categories", u8"\u0412\u0441\u0435 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438" },
  { u8"book-filtering-all-languages", u8"\u0412\u0441\u0435 \u044f\u0437\u044b\u043a\u0438" },
  { u8"confusion-of-tongues", u8"\u0412 \u043f\u043e\u0438\u0441\u043a\u0435 \u0431\u0443\u0434\u0443\u0442 \u0443\u0447\u0430\u0441\u0442\u0432\u043e\u0432\u0430\u0442\u044c \u0434\u0432\u0435 \u0438\u043b\u0438 \u0431\u043e\u043b\u0435\u0435 \u043a\u043d\u0438\u0433 \u043d\u0430 \u0440\u0430\u0437\u043d\u044b\u0445 \u044f\u0437\u044b\u043a\u0430\u0445, \u0447\u0442\u043e \u043c\u043e\u0436\u0435\u0442 \u043f\u0440\u0438\u0432\u0435\u0441\u0442\u0438 \u043a \u0437\u0430\u043f\u0443\u0442\u0430\u043d\u043d\u044b\u043c \u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442\u0430\u043c." },
  { u8"count-of-matching-books", u8"{{COUNT}} \u043a\u043d\u0438\u0433(\u0438)" },
  { u8"direct-download-alt-text", u8"\u0417\u0430\u0433\u0440\u0443\u0437\u043a\u0430 \u043d\u0430\u043f\u0440\u044f\u043c\u0443\u044e \u0447\u0435\u0440\u0435\u0437 HTTP(S)" },
  { u8"direct-download-link-text", u8"\u041f\u0440\u044f\u043c\u043e\u0439" },
  { u8"download", u8"\u0421\u043a\u0430\u0447\u0430\u0442\u044c" },
  { u8"download-links-heading", u8"\u0421\u0441\u044b\u043b\u043a\u0438 \u0434\u043b\u044f \u0441\u043a\u0430\u0447\u0438\u0432\u0430\u043d\u0438\u044f <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"\u0421\u043a\u0430\u0447\u0430\u0442\u044c \u043a\u043d\u0438\u0433\u0443" },
  { u8"empty-search-results-page-header", u8"\u041f\u043e \u0437\u0430\u043f\u0440\u043e\u0441\u0443 <b>\"{{{SEARCH_PATTERN}}}\"</b> \u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442\u043e\u0432 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e." },
  { u8"filter-by-tag", u8"\u0424\u0438\u043b\u044c\u0442\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u043e \u0442\u0435\u0433\u0443 \u00ab{{{TAG}}}\u00bb" },
  { u8"fulltext-search-unavailable", u8"\u041f\u043e\u043b\u043d\u043e\u0442\u0435\u043a\u0441\u0442\u043e\u0432\u044b\u0439 \u043f\u043e\u0438\u0441\u043a \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u0435\u043d" },
  { u8"hash-download-alt-text", u8"\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u043a\u043e\u043d\u0442\u0440\u043e\u043b\u044c\u043d\u0443\u044e \u0441\u0443\u043c\u043c\u0443 SHA-256 \u0443 \u0444\u0430\u0439\u043b\u0430" },
  { u8"hash-download-link-text", u8"\u041a\u043e\u043d\u0442\u0440\u043e\u043b\u044c\u043d\u0430\u044f \u0441\u0443\u043c\u043c\u0430 SHA-256" },
  { u8"home-button-text", u8"\u041f\u0435\u0440\u0435\u0439\u0442\u0438 \u043d\u0430 \u0433\u043b\u0430\u0432\u043d\u0443\u044e \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0443 '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u043d\u0435 \u044f\u0432\u043b\u044f\u0435\u0442\u0441\u044f \u0434\u043e\u043f\u0443\u0441\u0442\u0438\u043c\u044b\u043c \u0437\u0430\u043f\u0440\u043e\u0441\u043e\u043c \u043d\u0435\u043e\u0431\u0440\u0430\u0431\u043e\u0442\u0430\u043d\u043d\u043e\u0433\u043e \u043a\u043e\u043d\u0442\u0435\u043d\u0442\u0430." },
  { u8"invalid-request", u8"\u0417\u0430\u043f\u0440\u043e\u0448\u0435\u043d\u043d\u044b\u0439 URL-\u0430\u0434\u0440\u0435\u0441 \u00ab{{{url}}}\u00bb \u043d\u0435 \u044f\u0432\u043b\u044f\u0435\u0442\u0441\u044f \u0434\u043e\u043f\u0443\u0441\u0442\u0438\u043c\u044b\u043c \u0437\u0430\u043f\u0440\u043e\u0441\u043e\u043c." },
  { u8"library-button-text", u8"\u041f\u0435\u0440\u0435\u0439\u0442\u0438 \u043d\u0430 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0443-\u043f\u0440\u0438\u0432\u0435\u0442\u0441\u0442\u0432\u0438\u0435" },
  { u8"library-opds-feed-all-entries", u8"\u041a\u0430\u043d\u0430\u043b \u0431\u0438\u0431\u043b\u0438\u043e\u0442\u0435\u043a\u0438 OPDS\u00a0\u2013 \u0432\u0441\u0435 \u0437\u0430\u043f\u0438\u0441\u0438" },
  { u8"library-opds-feed-parameterised", u8"\u041a\u0430\u043d\u0430\u043b OPDS \u0431\u0438\u0431\u043b\u0438\u043e\u0442\u0435\u043a\u0438\u00a0\u2013 \u0437\u0430\u043f\u0438\u0441\u0438, \u0441\u043e\u043e\u0442\u0432\u0435\u0442\u0441\u0442\u0432\u0443\u044e\u0449\u0438\u0435 {{#LANG}}\nLanguage: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategory: {{CATEGORY}} {{/CATEGORY}} {{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\n\u0417\u0430\u043f\u0440\u043e\u0441: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"\u0421\u043a\u0430\u0447\u0430\u0442\u044c \u043f\u043e Magnet-\u0441\u0441\u044b\u043b\u043a\u0435" },
  { u8"magnet-link-text", u8"\u041c\u0430\u0433\u043d\u0438\u0442\u043d\u0430\u044f \u0441\u0441\u044b\u043b\u043a\u0430" },
  { u8"name", u8"\u0440\u0443\u0441\u0441\u043a\u0438\u0439" },
  { u8"no-book-found", u8"\u041d\u0438 \u043e\u0434\u043d\u0430 \u043a\u043d\u0438\u0433\u0430 \u043d\u0435 \u0441\u043e\u043e\u0442\u0432\u0435\u0442\u0441\u0442\u0432\u0443\u0435\u0442 \u043a\u0440\u0438\u0442\u0435\u0440\u0438\u044f\u043c \u043e\u0442\u0431\u043e\u0440\u0430" },
  { u8"no-query", u8"\u041d\u0435 \u043f\u0440\u0435\u0434\u043e\u0441\u0442\u0430\u0432\u043b\u0435\u043d \u0437\u0430\u043f\u0440\u043e\u0441." },
  { u8"no-search-results", u8"\u041f\u043e\u043b\u043d\u043e\u0442\u0435\u043a\u0441\u0442\u043e\u0432\u0430\u044f \u043f\u043e\u0438\u0441\u043a\u043e\u0432\u0430\u044f \u0441\u0438\u0441\u0442\u0435\u043c\u0430 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u043d\u0430 \u0434\u043b\u044f \u044d\u0442\u043e\u0433\u043e \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u043d\u0438\u044f." },
  { u8"no-such-book", u8"\u0422\u0430\u043a\u043e\u0439 \u043a\u043d\u0438\u0433\u0438 \u043d\u0435\u0442: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u041d\u0435 \u0443\u043a\u0430\u0437\u0430\u043d\u043e \u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435 \u0434\u043b\u044f \u0430\u0440\u0433\u0443\u043c\u0435\u043d\u0442\u0430 {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"\u041f\u0440\u0438 \u043f\u043e\u0434\u0434\u0435\u0440\u0436\u043a\u0435&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"\u041f\u0440\u0435\u0434\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440" },
  { u8"random-article-failure", u8"\u041e\u0439! \u041d\u0435 \u0443\u0434\u0430\u043b\u043e\u0441\u044c \u0432\u044b\u0431\u0440\u0430\u0442\u044c \u0441\u043b\u0443\u0447\u0430\u0439\u043d\u0443\u044e \u0441\u0442\u0430\u0442\u044c\u044e :(" },
  { u8"random-page-button-text", u8"\u041f\u0435\u0440\u0435\u0439\u0442\u0438 \u043d\u0430 \u0441\u043b\u0443\u0447\u0430\u0439\u043d\u043e \u0432\u044b\u0431\u0440\u0430\u043d\u043d\u0443\u044e \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0443" },
  { u8"raw-entry-not-found", u8"\u041d\u0435 \u0443\u0434\u0430\u0451\u0442\u0441\u044f \u043d\u0430\u0439\u0442\u0438 \u0437\u0430\u043f\u0438\u0441\u044c {{ENTRY}} \u0442\u0438\u043f\u0430 {{DATATYPE}}" },
  { u8"search", u8"\u041d\u0430\u0439\u0442\u0438" },
  { u8"search-result-book-info", u8"\u0438\u0437 {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"\u0420\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442\u044b <b>{{START}}-{{END}}</b> \u0438\u0437 <b>{{COUNT}}</b> \u0434\u043b\u044f <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"\u041f\u043e\u0438\u0441\u043a: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"\u0418\u0441\u043a\u0430\u0442\u044c '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"\u041f\u0440\u0435\u043a\u0440\u0430\u0442\u0438\u0442\u044c \u0444\u0438\u043b\u044c\u0442\u0440\u0430\u0446\u0438\u044e \u043f\u043e \u0442\u0435\u0433\u0443 \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"\u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0449\u0435\u0435 '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"\u0412\u044b\u043f\u043e\u043b\u043d\u0438\u0442\u0435 \u043f\u043e\u043b\u043d\u043e\u0442\u0435\u043a\u0441\u0442\u043e\u0432\u044b\u0439 \u043f\u043e\u0438\u0441\u043a \u0434\u043b\u044f <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"\u0417\u0430\u043f\u0440\u043e\u0448\u0435\u043d\u043e \u0441\u043b\u0438\u0448\u043a\u043e\u043c \u043c\u043d\u043e\u0433\u043e \u043a\u043d\u0438\u0433 ({{NB_BOOKS}}), \u043c\u0430\u043a\u0441\u0438\u043c\u0430\u043b\u044c\u043d\u043e\u0435 \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e\u00a0\u2014 {{LIMIT}}." },
  { u8"torrent-download-alt-text", u8"\u0421\u043a\u0430\u0447\u0430\u0442\u044c \u0447\u0435\u0440\u0435\u0437 BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"\u041d\u0435\u0438\u0437\u0432\u0435\u0441\u0442\u043d\u0430\u044f \u043e\u0448\u0438\u0431\u043a\u0430" },
  { u8"url-not-found", u8"\u0417\u0430\u043f\u0440\u043e\u0448\u0435\u043d\u043d\u044b\u0439 URL \"{{url}}\" \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d \u043d\u0430 \u044d\u0442\u043e\u043c \u0441\u0435\u0440\u0432\u0435\u0440\u0435." },
  { u8"welcome-page-overzealous-filter", u8"\u0411\u0435\u0437\u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442\u043d\u043e. \u0425\u043e\u0442\u0438\u0442\u0435 <a href=\"{{URL}}\">\u0441\u0431\u0440\u043e\u0441\u0438\u0442\u044c \u0444\u0438\u043b\u044c\u0442\u0440</a> ?" },
  { u8"welcome-to-kiwix-server", u8"\u0414\u043e\u0431\u0440\u043e \u043f\u043e\u0436\u0430\u043b\u043e\u0432\u0430\u0442\u044c \u043d\u0430 \u0441\u0435\u0440\u0432\u0435\u0440 Kiwix" },
  { u8"word-count", u8"{{COUNT}} \u0441\u043b\u043e\u0432" }
};


const I18nString string_table_for_sc[] = {
  { u8"400-page-heading", u8"Rechesta non v\u00e0lida" },
  { u8"400-page-title", u8"Rechesta non v\u00e0lida" },
  { u8"404-page-heading", u8"No agatadu" },
  { u8"404-page-title", u8"Cuntentu no agatadu" },
  { u8"500-page-heading", u8"Errore internu de su serbidore" },
  { u8"500-page-title", u8"Errore internu de su serbidore" },
  { u8"book-filtering-all-categories", u8"Totu sas categorias" },
  { u8"book-filtering-all-languages", u8"Totu sas limbas" },
  { u8"confusion-of-tongues", u8"Duos o prus libros in limbas diferentes diant pigare parte a sa chirca, cosa chi diat p\u00f2dere causare resurtados confusionosos." },
  { u8"count-of-matching-books", u8"{{COUNT}} libru/os" },
  { u8"direct-download-alt-text", u8"Isc\u00e0rriga in manera direta tr\u00e0mite HTTP(S)" },
  { u8"direct-download-link-text", u8"Diretu" },
  { u8"download", u8"Isc\u00e0rriga" },
  { u8"download-links-heading", u8"Lig\u00e0menes de iscarrigamentu pro <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Isc\u00e0rriga su libru" },
  { u8"filter-by-tag", u8"Filtra pro eticheta \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"Chirca de testu integrale no a disponimentu" },
  { u8"hash-download-alt-text", u8"Mustra sa summa de controllu SHA-256" },
  { u8"hash-download-link-text", u8"Summa de controllu SHA-256" },
  { u8"home-button-text", u8"Bae a sa p\u00e0gina printzipale de '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} no est una rechesta v\u00e0lida pro cuntenutu puru." },
  { u8"library-button-text", u8"Bae a sa p\u00e0gina de bene b\u00e8nnidu" },
  { u8"library-opds-feed-all-entries", u8"Flussu OPDS de sa biblioteca \u2013 Totu sos elementos" },
  { u8"library-opds-feed-parameterised", u8"Flussu OPDS de sa biblioteca - elementos chi currispondet cun {{#LANG}}\nLimba: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategoria: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nEticheta: {{TAG}} {{/TAG}}{{#Q}}\nChirca: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Isc\u00e0rriga impreende su lig\u00e0mene Magnet" },
  { u8"magnet-link-text", u8"Lig\u00e0mene Magnet" },
  { u8"name", u8"Sardu" },
  { u8"no-book-found", u8"Perunu libru currispondet a sos crit\u00e8rios de seletzione" },
  { u8"no-query", u8"Peruna chirca frunida." },
  { u8"no-search-results", u8"Su motore de chirca de testu integrale no est a disponimentu pro custu cuntenutu." },
  { u8"no-such-book", u8"Perunu libru cun custu n\u00f9mene: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Perunu valore frunidu pro s'argumentu {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Alimentadu dae&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Antiprima" },
  { u8"random-article-failure", u8"Oops! Sa seletzione de un'art\u00ecculu a casu est fallida :(" },
  { u8"random-page-button-text", u8"Bae a una p\u00e0gina seletzionada a manera casuale" },
  { u8"raw-entry-not-found", u8"Non faghet a atzapare s'elementu {{ENTRY}} de genia {{DATATYPE}}" },
  { u8"search", u8"Chirca" },
  { u8"searchbox-tooltip", u8"Chirca '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Non filtres prus pro eticheta \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"chi cuntenet '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Faghe una chirca de testu intreu pro <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Tropu libros pedidos, {{NB_BOOKS}} cando su l\u00ecmite est de {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Isc\u00e0rriga impreende BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"url-not-found", u8"S'URL pedidu \"{{url}}\" non s'est atzapadu in custu serbidore." },
  { u8"welcome-page-overzealous-filter", u8"Perunu resurtadu. Boles <a href=\"{{URL}}\">resetare su filtru</a>?" },
  { u8"welcome-to-kiwix-server", u8"Bene b\u00e8nnidu a su serbidore de Kiwix" }
};


const I18nString string_table_for_sk[] = {
  { u8"400-page-heading", u8"Neplatn\u00e1 po\u017eiadavka" },
  { u8"400-page-title", u8"Neplatn\u00e1 po\u017eiadavka" },
  { u8"404-page-heading", u8"Nen\u00e1jden\u00e9" },
  { u8"404-page-title", u8"Obsah nebol n\u00e1jden\u00fd" },
  { u8"500-page-heading", u8"Chyba intern\u00e9ho servera" },
  { u8"500-page-title", u8"Chyba intern\u00e9ho servera" },
  { u8"fulltext-search-unavailable", u8"Vyh\u013ead\u00e1vanie cel\u00e9ho textu nie je dostupn\u00e9" },
  { u8"home-button-text", u8"Prejs\u0165 na hlavn\u00fa str\u00e1nku knihy {{BOOK_TITLE}}" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} nie je platn\u00e1 po\u017eiadavka pre surov\u00fd obsah." },
  { u8"library-button-text", u8"Prejs\u0165 na uv\u00edtaciu str\u00e1nku" },
  { u8"name", u8"sloven\u010dina" },
  { u8"no-book-found", u8"Krit\u00e9ri\u00e1m v\u00fdberu nevyhovuje \u017eiadna kniha" },
  { u8"no-query", u8"Nebol poskytnut\u00fd \u017eiadny dopyt." },
  { u8"no-search-results", u8"Funkcia na vyh\u013ead\u00e1vanie cel\u00e9ho textu nie je pre tento obsah dostupn\u00e1." },
  { u8"no-such-book", u8"\u017diadna kniha ako: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Pre argument {{ARGUMENT}} nebola poskytnut\u00e1 \u017eiadna hodnota" },
  { u8"random-article-failure", u8"Nepodarilo sa vybra\u0165 n\u00e1hodn\u00fd \u010dl\u00e1nok :(" },
  { u8"random-page-button-text", u8"Prejs\u0165 na n\u00e1hodne vybran\u00fa str\u00e1nku" },
  { u8"raw-entry-not-found", u8"Nepodarilo sa n\u00e1js\u0165 {{DATATYPE}} polo\u017eka {{ENTRY}}" },
  { u8"searchbox-tooltip", u8"Vyh\u013eada\u0165 {{BOOK_TITLE}}" },
  { u8"suggest-full-text-search", u8"obsahuje '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Spustite h\u013eadanie cel\u00e9ho textu <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"Pr\u00edli\u0161 ve\u013ea po\u017eadovan\u00fdch kn\u00edh ({{NB_BOOKS}}), limit je {{LIMIT}}" },
  { u8"url-not-found", u8"Po\u017eadovan\u00e1 adresa URL \"{{url}}\" na tomto serveri nebola n\u00e1jden\u00e1." }
};


const I18nString string_table_for_skr_arab[] = {
  { u8"400-page-heading", u8"\u063a\u0644\u0637 \u0627\u0631\u062f\u0627\u0633" },
  { u8"400-page-title", u8"\u063a\u0644\u0637 \u0627\u0631\u062f\u0627\u0633" },
  { u8"404-img-text", u8"\u06a9\u0627\u0626\u0646\u06cc \u0644\u0628\u06be\u0627!" },
  { u8"404-page-heading", u8"\u06a9\u0627\u0626\u0646\u06cc \u0644\u0628\u06be\u0627" },
  { u8"404-page-title", u8"\u0645\u0648\u0627\u062f \u06a9\u0627\u0626\u0646\u06cc \u0644\u0628\u06be\u06cc\u0627" },
  { u8"500-page-heading", u8"\u0627\u0646\u062f\u0631\u0644\u0627 \u0633\u0631\u0648\u0631 \u0646\u0642\u0635" },
  { u8"500-page-title", u8"\u0627\u0646\u062f\u0631\u0644\u0627 \u0633\u0631\u0648\u0631 \u0646\u0642\u0635" },
  { u8"book-category.other", u8"\u067b\u06cc\u0627" },
  { u8"book-category.vikidia", u8"\u0648\u06a9\u06cc \u0688\u06cc\u0627" },
  { u8"book-category.wikibooks", u8"\u0648\u06a9\u06cc \u06a9\u062a\u0627\u0628\u0627\u06ba" },
  { u8"book-category.wikinews", u8"\u0648\u06a9\u06cc \u062e\u0628\u0631\u0627\u06ba" },
  { u8"book-category.wikipedia", u8"\u0648\u06a9\u06cc\u067e\u06cc\u0688\u06cc\u0627" },
  { u8"book-category.wikiquote", u8"\u0648\u06a9\u06cc \u067b\u0648\u0644" },
  { u8"book-category.wikisource", u8"\u0648\u06a9\u06cc \u0645\u0627\u062e\u0630" },
  { u8"book-category.wikispecies", u8"\u0648\u06a9\u06cc \u0633\u067e\u06cc\u0634\u06cc\u0632" },
  { u8"book-category.wikiversity", u8"\u0648\u06a9\u06cc \u0648\u0631\u0633\u0679\u06cc" },
  { u8"book-category.wikivoyage", u8"\u0648\u06a9\u06cc \u0633\u06cc\u0631\u0633\u067e\u0627\u0679\u0627" },
  { u8"book-category.wiktionary", u8"\u0648\u06a9\u0634\u0646\u0631\u06cc" },
  { u8"book-filtering-all-categories", u8"\u0633\u0627\u0631\u06cc\u0627\u06ba \u0648\u0646\u06a9\u06cc\u0627\u06ba" },
  { u8"book-filtering-all-languages", u8"\u0633\u0627\u0631\u06cc\u0627\u06ba \u0632\u0628\u0627\u0646\u0627\u06ba" },
  { u8"count-of-matching-books", u8"{{COUNT}} \u06a9\u062a\u0627\u0628(\u0627\u06ba)" },
  { u8"direct-download-alt-text", u8"\u0688\u0627\u0626\u0631\u06a9\u0679 \u0688\u0627\u0624\u0646 \u0644\u0648\u0688" },
  { u8"direct-download-link-text", u8"\u0688\u0627\u0626\u0631\u06a9\u0679" },
  { u8"download", u8"\u0688\u0627\u0624\u0646 \u0644\u0648\u0688" },
  { u8"download-links-title", u8"\u06a9\u062a\u0627\u0628 \u0688\u0627\u0624\u0646 \u0644\u0648\u0688 \u06a9\u0631\u0648" },
  { u8"hash-download-alt-text", u8"\u0688\u0627\u0624\u0646 \u0644\u0648\u0688 \u06c1\u06cc\u0634" },
  { u8"name", u8"\u0633\u0631\u0627\u0626\u06cc\u06a9\u06cc" },
  { u8"new-404-page-title", u8"\u0648\u0631\u0642\u06c1 \u06a9\u0627\u0626\u0646\u06cc \u0644\u0628\u06be\u06cc\u0627" },
  { u8"preview-book", u8"\u067e\u06cc\u0634\u06af\u06cc \u0759\u06a9\u06be\u0627\u0644\u0627" },
  { u8"search", u8"\u06b3\u0648\u0644\u0648" },
  { u8"torrent-download-alt-text", u8"\u0679\u0648\u0631\u06ba\u0679 \u0759\u0627\u0624\u0646 \u0644\u0648\u0688 \u06a9\u0631\u0648" },
  { u8"torrent-download-link-text", u8"\u0679\u0648\u0631\u0646\u0679 \u0641\u0627\u0626\u0644" }
};


const I18nString string_table_for_sl[] = {
  { u8"400-page-heading", u8"Neveljaven zahtevek" },
  { u8"400-page-title", u8"Neveljaven zahtevek" },
  { u8"404-advice.p1", u8"Vsebina, ki jo i\u0161\u010dete, je mogo\u010de \u0161e vedno na voljo, vendar se morda nahaja na drugem mestu v datoteki ZIM." },
  { u8"404-advice.p2", u8"Prosimo:" },
  { u8"404-advice.p3", u8"Poskusite uporabiti funkcijo iskanja, da najdete \u017eeleno vsebino" },
  { u8"404-advice.p4", u8"Poi\u0161\u010dite klju\u010dne besede ali naslove, povezane z informacijami, ki jih i\u0161\u010dete" },
  { u8"404-advice.p5", u8"Ta pristop bi vam moral pomagati najti \u017eeleno vsebino, tudi \u010de izvirna povezava ne deluje pravilno." },
  { u8"404-img-text", u8"Ni najdeno!" },
  { u8"404-page-heading", u8"Ni najdeno" },
  { u8"404-page-title", u8"Vsebine ni mogo\u010de najti" },
  { u8"500-img-text", u8"Stran ne deluje" },
  { u8"500-page-heading", u8"Ups. Stran ne deluje." },
  { u8"500-page-text", u8"Zahtevane poti ni mogo\u010de pravilno dostaviti:" },
  { u8"500-page-title", u8"Notranja napaka stre\u017enika" },
  { u8"book-category.other", u8"Drugo" },
  { u8"book-category.wikibooks", u8"Wikiknjige" },
  { u8"book-category.wikinews", u8"Wikinovice" },
  { u8"book-category.wikipedia", u8"Wikipedija" },
  { u8"book-category.wikiquote", u8"Wikinavedek" },
  { u8"book-category.wikisource", u8"Wikivir" },
  { u8"book-category.wikispecies", u8"Wikivrste" },
  { u8"book-category.wikiversity", u8"Wikiverza" },
  { u8"book-category.wikivoyage", u8"Wikipotovanje" },
  { u8"book-category.wiktionary", u8"Wikislovar" },
  { u8"book-filtering-all-categories", u8"Vse kategorije" },
  { u8"book-filtering-all-languages", u8"Vsi jeziki" },
  { u8"caution-warning", u8"Pozor!" },
  { u8"confusion-of-tongues", u8"V iskanju bi bili uporabljeni dve ali ve\u010d knjig v razli\u010dnih jezikih, kar lahko pripelje do nejasnih zadetkov." },
  { u8"count-of-matching-books", u8"{{COUNT}} knjiga(i/e)" },
  { u8"direct-download-alt-text", u8"Neposredni prenos prek HTTP(S)" },
  { u8"direct-download-link-text", u8"Neposredno" },
  { u8"download", u8"Prenesi" },
  { u8"download-links-heading", u8"Povezave za prenos za <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Prenesi knjigo" },
  { u8"empty-search-results-page-header", u8"Ni zadetkov za \u00bb<b>{{{SEARCH_PATTERN}}}</b>\u00ab" },
  { u8"external-link-advice.p1", u8"Povezava, do katere posku\u0161ate dostopati, ni del va\u0161ega paketa za delo brez povezave in zahteva internetno povezavo." },
  { u8"external-link-advice.p2", u8"\u010ce se lahko pove\u017eete z internetom, lahko poskusite odpreti povezavo." },
  { u8"external-link-advice.p3", u8"Na vsebino ZIM brez povezave se lahko vrnete tudi z gumbom za nazaj v brskalniku." },
  { u8"external-link-detected", u8"Zaznana zunanja povezava" },
  { u8"external-link-intro", u8"Zapustili boste bralnik ZIM v Kiwixu in se v internetu povezali z" },
  { u8"filter-by-tag", u8"Filtriraj po oznaki \u00bb{{{TAG}}}\u00ab" },
  { u8"fulltext-search-unavailable", u8"Iskanje po celotnem besedilu ni na voljo" },
  { u8"hash-download-alt-text", u8"Prikaz kontrolne vsote SHA-256 datoteke" },
  { u8"hash-download-link-text", u8"Kontrolna vsota SHA-256" },
  { u8"home-button-text", u8"Pojdi na glavno stran \u00bb{{{BOOK_TITLE}}}\u00ab" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} ni veljaven zahtevek za neobdelano vsebino." },
  { u8"invalid-request", u8"Zahtevani URL \u00bb{{{url}}}\u00ab ni veljaven zahtevek." },
  { u8"library-button-text", u8"Pojdi na pozdravno stran" },
  { u8"library-opds-feed-all-entries", u8"Knji\u017eni\u010dni vir OPDS \u2013 Vsi vnosi" },
  { u8"library-opds-feed-parameterised", u8"Knji\u017eni\u010dni vir OPDS \u2013 vnosi, ki se ujemajo z {{#LANG}}\nJezik: {{LANG}} {{/LANG}}{{#CATEGORY}}\nKategorija: {{CATEGORY}} {{/CATEGORY}} {{#TAG}}\nOznaka: {{TAG}} {{/TAG}}{{#Q}}\nPoizvedba: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Prenos prek magnetne povezave" },
  { u8"magnet-link-text", u8"Magnetna povezava" },
  { u8"name", u8"sloven\u0161\u010dina" },
  { u8"new-404-page-heading", u8"Ups. Stran ni bila najdena." },
  { u8"new-404-page-title", u8"Stran ni bila najdena" },
  { u8"no-book-found", u8"Izbranim merilom ne ustreza nobena knjiga" },
  { u8"no-query", u8"Poizvedba ni podana." },
  { u8"no-search-results", u8"Iskalnik po celotnem besedilu za to vsebino ni na voljo." },
  { u8"no-such-book", u8"Ni take knjige: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Argument {{ARGUMENT}} nima dolo\u010dene nobene vrednosti" },
  { u8"path-was-not-found", u8"Zahtevana pot ni bila najdena:" },
  { u8"powered-by-kiwix-html", u8"Omogo\u010da <a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Predogled" },
  { u8"random-article-failure", u8"Ups! Ni bilo mogo\u010de izbrati naklju\u010dnega \u010dlanka :(" },
  { u8"random-page-button-text", u8"Pojdi na naklju\u010dno izbrano stran" },
  { u8"raw-entry-not-found", u8"Ni mogo\u010de najti vnosa {{ENTRY}} tipa {{DATATYPE}}" },
  { u8"search", u8"I\u0161\u010di" },
  { u8"search-result-book-info", u8"iz {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Zadetki <b>{{START}}\u2013{{END}}</b> od <b>{{COUNT}}</b> za \u00bb<b>{{{SEARCH_PATTERN}}}</b>\u00ab" },
  { u8"search-results-page-title", u8"Iskanje: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Poi\u0161\u010dite \u00bb{{{BOOK_TITLE}}}\u00ab" },
  { u8"stop-filtering-by-tag", u8"Ustavi filtriranje po oznaki \u00bb{{{TAG}}}\u00ab" },
  { u8"suggest-full-text-search", u8"vsebuje \u00bb{{{SEARCH_TERMS}}}\u00ab ..." },
  { u8"suggest-search", u8"Prei\u0161\u010dite celotno besedilo za <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Nalaganje vsebine" },
  { u8"too-many-books", u8"Preve\u010d zahtevanih knjig ({{NB_BOOKS}}), omejitev je {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Prenos prek BitTorrenta" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Neznana napaka" },
  { u8"url-not-found", u8"Zahtevanega URL-ja \u00bb{{url}}\u00ab v tem stre\u017eniku ni bilo mogo\u010de najti." },
  { u8"welcome-page-overzealous-filter", u8"Ni zadetkov. \u017delite <a href=\"{{URL}}\">ponastaviti filter</a>?" },
  { u8"welcome-to-kiwix-server", u8"Pozdravljeni na stre\u017eniku Kiwix" },
  { u8"word-count", u8"{{COUNT}} besed" }
};


const I18nString string_table_for_sq[] = {
  { u8"400-page-heading", u8"K\u00ebrkes\u00eb e pavlefshme" },
  { u8"400-page-title", u8"K\u00ebrkes\u00eb e pavlefshme" },
  { u8"404-page-heading", u8"S\u2019u Gjet" },
  { u8"404-page-title", u8"S\u2019u gjet l\u00ebnd\u00eb" },
  { u8"500-page-heading", u8"Gabim i Brendsh\u00ebm Sh\u00ebrbyesi" },
  { u8"500-page-text", u8"Ndodhi nj\u00eb gabim i brendsh\u00ebm sh\u00ebrbyesi. Na ndjeni p\u00ebr k\u00ebt\u00eb :/" },
  { u8"500-page-title", u8"Gabim i Brendsh\u00ebm Sh\u00ebrbyesi" },
  { u8"book-category.other", u8"Tjet\u00ebr" },
  { u8"book-category.wikibooks", u8"Wikibooks" },
  { u8"book-category.wikinews", u8"Wikinews" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversity" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wiktionary" },
  { u8"book-filtering-all-categories", u8"Krejt kategorit\u00eb" },
  { u8"book-filtering-all-languages", u8"Krejt gjuh\u00ebt" },
  { u8"confusion-of-tongues", u8"K\u00ebrkimi do t\u00eb merrej me dy ose m\u00eb tep\u00ebr libra n\u00eb gjuh\u00eb t\u00eb ndryshme, \u00e7ka mund t\u00eb sjell\u00eb p\u00ebrfundime t\u00eb ngat\u00ebrruara." },
  { u8"count-of-matching-books", u8"{{COUNT}} lib\u00ebr(a)" },
  { u8"direct-download-alt-text", u8"Shkarkoje drejtp\u00ebrs\u00ebdrejti p\u00ebrmes HTTP(S)" },
  { u8"direct-download-link-text", u8"Drejtp\u00ebrs\u00ebdrejti" },
  { u8"download", u8"Shkarkoje" },
  { u8"download-links-heading", u8"Lidhje shkarkimi p\u00ebr <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Shkarkoje librin" },
  { u8"empty-search-results-page-header", u8"S\u2019u gjet\u00ebn p\u00ebrfundime p\u00ebr <b>\u201c{{{SEARCH_PATTERN}}}\u201d</b>" },
  { u8"filter-by-tag", u8"Filtroji sipas etikete \u201c{{{TAG}}}\u201d" },
  { u8"fulltext-search-unavailable", u8"K\u00ebrkim teksti t\u00eb plot\u00eb jo i mundsh\u00ebm" },
  { u8"hash-download-alt-text", u8"Shfaq \u201cchecksum\u201d SHA-256 kartele" },
  { u8"hash-download-link-text", u8"\u201cChecksum\u201d SHA-256" },
  { u8"home-button-text", u8"Kalo te faqja krye e '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} s\u2019\u00ebsht\u00eb varg i vlefsh\u00ebm k\u00ebrkimi p\u00ebr l\u00ebnd\u00eb t\u00eb pap\u00ebrpunuar." },
  { u8"invalid-request", u8"URL-ja e k\u00ebrkuar \u201c{{{url}}}\u201d s\u2019\u00ebsht\u00eb k\u00ebrkes\u00eb e vlefshme." },
  { u8"library-button-text", u8"Kalo te faqja e mir\u00ebseardhjes" },
  { u8"library-opds-feed-all-entries", u8"Prurje OPDS Biblioteke - Krejt z\u00ebrat" },
  { u8"library-opds-feed-parameterised", u8"Prurje OPDS Biblioteke - z\u00ebra q\u00eb kan\u00eb p\u00ebrputhje me {{#LANG}}\nGjuh\u00eb: {{LANG}} {{/LANG}}{{#CATEGORY}}\nKategori: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nEtiket\u00eb: {{TAG}} {{/TAG}}{{#Q}}\nVarg K\u00ebrkimi: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Shkarkoje p\u00ebrmes lidhjeje Magnet" },
  { u8"magnet-link-text", u8"Lidhje Magnet" },
  { u8"name", u8"Shqip" },
  { u8"no-book-found", u8"S\u2019ka lib\u00ebr me p\u00ebrputhje me kriteret e p\u00ebrzgjedhjes" },
  { u8"no-query", u8"S\u2019u dha varg k\u00ebrkimi." },
  { u8"no-search-results", u8"S\u2019\u00ebsht\u00eb i passh\u00ebm motori i k\u00ebrkimit t\u00eb tekstit t\u00eb plot\u00eb p\u00ebr k\u00ebt\u00eb l\u00ebnd\u00eb." },
  { u8"no-such-book", u8"S\u2019ka lib\u00ebr t\u00eb till\u00eb: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"S\u2019u dha vler\u00eb p\u00ebr argumentin {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Bazuar n\u00eb&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Paraparje" },
  { u8"random-article-failure", u8"Oh! S\u2019u arrit t\u00eb merrej nj\u00eb artikull kuturu :(" },
  { u8"random-page-button-text", u8"Kalo te nj\u00eb faqe e p\u00ebrzgjedhur kuturu" },
  { u8"raw-entry-not-found", u8"S\u2019gjendet dot z\u00ebri {{DATATYPE}} {{ENTRY}}" },
  { u8"search", u8"K\u00ebrko" },
  { u8"search-result-book-info", u8"nga {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"P\u00ebrfundime <b>{{START}}-{{END}}</b> nga <b>{{COUNT}}</b> gjithsej p\u00ebr <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"K\u00ebrkim: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"K\u00ebrko n\u00eb '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Resht s\u00eb filtruari sipas etikete \u201c{{{TAG}}}\u201d" },
  { u8"suggest-full-text-search", u8"q\u00eb p\u00ebrmban '{{{SEARCH_TERMS}}}'\u2026" },
  { u8"suggest-search", u8"B\u00ebni nj\u00eb k\u00ebrkim t\u00eb plot\u00eb teksti p\u00ebr <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"too-many-books", u8"U k\u00ebrkuan shum\u00eb libra ({{NB_BOOKS}}), teksa kufiri \u00ebsht\u00eb {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Shkarkoje p\u00ebrmes BitTorrent-it" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Gabim i panjohur" },
  { u8"url-not-found", u8"URL \u201c{{url}}\u201d e k\u00ebrkuar s\u2019u gjet n\u00eb k\u00ebt\u00eb sh\u00ebrbyes." },
  { u8"welcome-page-overzealous-filter", u8"S\u2019ka p\u00ebrfundime. Do t\u00eb donit t\u00eb <a href=\"{{URL}}\">riujdisni filtrimin</a>?" },
  { u8"welcome-to-kiwix-server", u8"Mir\u00eb se vini n\u00eb Sh\u00ebrbyesin Kiwix" },
  { u8"word-count", u8"{{COUNT}} fjal\u00eb" }
};


const I18nString string_table_for_sv[] = {
  { u8"400-page-heading", u8"Ogiltig beg\u00e4ran" },
  { u8"400-page-title", u8"Ogiltig beg\u00e4ran" },
  { u8"404-advice.p1", u8"Inneh\u00e5llet du letar efter kan fortfarande vara tillg\u00e4ngligt, men det kan finnas p\u00e5 en annan plats i ZIM-filen." },
  { u8"404-advice.p2", u8"V\u00e4nligen:" },
  { u8"404-advice.p3", u8"F\u00f6rs\u00f6k att anv\u00e4nda s\u00f6kfunktionen f\u00f6r att hitta det inneh\u00e5ll du vill ha" },
  { u8"404-advice.p4", u8"Leta efter nyckelord eller titlar relaterade till den information du s\u00f6ker" },
  { u8"404-advice.p5", u8"Den h\u00e4r metoden b\u00f6r hj\u00e4lpa dig att hitta \u00f6nskat inneh\u00e5ll, \u00e4ven om den ursprungliga l\u00e4nken inte fungerar korrekt." },
  { u8"404-img-text", u8"Hittades ej!" },
  { u8"404-page-heading", u8"Hittades inte" },
  { u8"404-page-title", u8"Inneh\u00e5llet hittades inte" },
  { u8"500-img-text", u8"Sidan fungerar ej" },
  { u8"500-page-heading", u8"Hoppsan. Sidan fungerar inte." },
  { u8"500-page-text", u8"Den beg\u00e4rda s\u00f6kv\u00e4gen kan inte levereras korrekt:" },
  { u8"500-page-title", u8"Internt serverfel" },
  { u8"book-category.other", u8"\u00d6vriga" },
  { u8"book-category.wikibooks", u8"Wikibooks" },
  { u8"book-category.wikinews", u8"Wikinews" },
  { u8"book-category.wikipedia", u8"Wikipedia" },
  { u8"book-category.wikiquote", u8"Wikiquote" },
  { u8"book-category.wikisource", u8"Wikisource" },
  { u8"book-category.wikispecies", u8"Wikispecies" },
  { u8"book-category.wikiversity", u8"Wikiversity" },
  { u8"book-category.wikivoyage", u8"Wikivoyage" },
  { u8"book-category.wiktionary", u8"Wiktionary" },
  { u8"book-filtering-all-categories", u8"Alla kategorier" },
  { u8"book-filtering-all-languages", u8"Alla spr\u00e5k" },
  { u8"caution-warning", u8"Varning!" },
  { u8"confusion-of-tongues", u8"Tv\u00e5 eller fler b\u00f6cker p\u00e5 olika spr\u00e5k skulle delta i s\u00f6kningen, vilket kan ge f\u00f6rvirrande resultat." },
  { u8"count-of-matching-books", u8"{{COUNT}} b\u00f6cker" },
  { u8"direct-download-alt-text", u8"Ladda ner direkt via HTTP(S)" },
  { u8"direct-download-link-text", u8"Direkt" },
  { u8"download", u8"Ladda ned" },
  { u8"download-links-heading", u8"Nedladdningsl\u00e4nkar f\u00f6r <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Ladda ned bok" },
  { u8"empty-search-results-page-header", u8"Inga resultat hittades f\u00f6r <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"external-link-advice.p1", u8"L\u00e4nken du f\u00f6rs\u00f6ker komma \u00e5t \u00e4r inte en del av ditt offlinepaket och kr\u00e4ver en internetanslutning." },
  { u8"external-link-advice.p2", u8"Om du kan g\u00e5 online kan du f\u00f6rs\u00f6ka \u00f6ppna l\u00e4nken." },
  { u8"external-link-advice.p3", u8"Du kan annars \u00e5terg\u00e5 till ditt ZIM-inneh\u00e5ll offline genom att anv\u00e4nda webbl\u00e4sarens bak\u00e5tknapp." },
  { u8"external-link-detected", u8"Extern l\u00e4nk uppt\u00e4ckt" },
  { u8"external-link-intro", u8"Du \u00e4r p\u00e5 v\u00e4g att l\u00e4mna Kiwix ZIM-l\u00e4sare f\u00f6r att g\u00e5 online till" },
  { u8"filter-by-tag", u8"Filtrera efter taggen \"{{{TAG}}}\"" },
  { u8"fulltext-search-unavailable", u8"Fulltexts\u00f6kning \u00e4r inte tillg\u00e4nglig" },
  { u8"hash-download-alt-text", u8"Visa SHA-256-filens kontrollsiffra" },
  { u8"hash-download-link-text", u8"SHA-256-kontrollsiffra" },
  { u8"home-button-text", u8"G\u00e5 till huvudsidan f\u00f6r '{{{BOOK_TITLE}}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u00e4r ingen giltig beg\u00e4ran f\u00f6r oformaterat inneh\u00e5ll." },
  { u8"invalid-request", u8"Den beg\u00e4rda webbadressen \"{{{url}}}\" \u00e4r inte en giltig beg\u00e4ran." },
  { u8"library-button-text", u8"G\u00e5 till hemsidan" },
  { u8"library-opds-feed-all-entries", u8"Library OPDS Feed - Alla poster" },
  { u8"library-opds-feed-parameterised", u8"Library OPDS Feed - poster som matchar {{#LANG}}\nSpr\u00e5k: {{LANG}} {{/LANG}}{{#CATEGORY}}\nKategori: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTagg: {{TAG}} {{/TAG}}{{#Q}}\nFr\u00e5ga: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"Ladda ner via Magnet-l\u00e4nk" },
  { u8"magnet-link-text", u8"Magnetl\u00e4nk" },
  { u8"name", u8"Svenska" },
  { u8"new-404-page-heading", u8"Hoppsan. Sidan hittades inte." },
  { u8"new-404-page-title", u8"Sidan kunde inte hittas" },
  { u8"no-book-found", u8"Ingen bok matchar urvalskriterierna" },
  { u8"no-query", u8"Ingen fr\u00e5ga tillhandah\u00e5lls." },
  { u8"no-search-results", u8"S\u00f6kmaskinen f\u00f6r fulltext \u00e4r inte tillg\u00e4nglig f\u00f6r detta inneh\u00e5ll." },
  { u8"no-such-book", u8"Ingen s\u00e5dan bok: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Inget v\u00e4rde angett f\u00f6r argumentet {{ARGUMENT}}" },
  { u8"path-was-not-found", u8"Den beg\u00e4rda s\u00f6kv\u00e4gen hittades ej:" },
  { u8"powered-by-kiwix-html", u8"Drivs av&nbsp;<a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"F\u00f6rhandsgranska" },
  { u8"random-article-failure", u8"Hoppsan! Kunde inte v\u00e4lja en slumpartikel :(" },
  { u8"random-page-button-text", u8"G\u00e5 till en slumpm\u00e4ssigt utvald sida" },
  { u8"raw-entry-not-found", u8"Kunde inte hitta {{DATATYPE}}-inl\u00e4gget {{ENTRY}}" },
  { u8"search", u8"S\u00f6k" },
  { u8"search-result-book-info", u8"fr\u00e5n {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Resultat <b>{{START}}-{{END}}</b> av <b>{{COUNT}}</b> f\u00f6r <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"S\u00f6k: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"S\u00f6k '{{{BOOK_TITLE}}}'" },
  { u8"stop-filtering-by-tag", u8"Sluta filtrera efter taggen \"{{{TAG}}}\"" },
  { u8"suggest-full-text-search", u8"inneh\u00e5ller '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"Utf\u00f6r en fulltexts\u00f6kning f\u00f6r <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Laddar inneh\u00e5ll" },
  { u8"too-many-books", u8"F\u00f6r m\u00e5nga b\u00f6cker beg\u00e4rda ({{NB_BOOKS}}) d\u00e4r gr\u00e4nsen \u00e4r {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"Ladda ner via BitTorrent" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Ok\u00e4nt fel" },
  { u8"url-not-found", u8"Den beg\u00e4rda webbadressen \"{{url}}\" hittades inte p\u00e5 denna server." },
  { u8"welcome-page-overzealous-filter", u8"Inga resultat. Vill du <a href=\"{{URL}}\">\u00e5terst\u00e4lla filtret</a>?" },
  { u8"welcome-to-kiwix-server", u8"V\u00e4lkommen till Kiwix Server" },
  { u8"word-count", u8"{{COUNT}} ord" }
};


const I18nString string_table_for_sw[] = {
  { u8"400-page-heading", u8"Ombi batili" },
  { u8"400-page-title", u8"Ombi batili" },
  { u8"404-page-heading", u8"Haijapatikana" },
  { u8"404-page-title", u8"Maudhui hayajapatikana" },
  { u8"500-page-heading", u8"Hitilafu ya Ndani ya Seva" },
  { u8"500-page-text", u8"Hitilafu ya ndani ya seva imetokea. Tunasikitika kwa hilo:/" },
  { u8"500-page-title", u8"Hitilafu ya Ndani ya Seva" },
  { u8"book-filtering-all-categories", u8"Jamii Zote" },
  { u8"book-filtering-all-languages", u8"Lugha zote" },
  { u8"confusion-of-tongues", u8"Vitabu viwili au zaidi katika lugha tofauti vitashiriki katika utafutaji, jambo ambalo linaweza kusababisha matokeo ya kutatanisha." },
  { u8"count-of-matching-books", u8"Vitabu {{COUNT}}" },
  { u8"direct-download-alt-text", u8"kupakua moja kwa moja" },
  { u8"direct-download-link-text", u8"Moja kwa moja" },
  { u8"download", u8"Pakua" },
  { u8"download-links-heading", u8"Pakua viungo vya <b><i>{{BOOK_TITLE}}</i></b>" },
  { u8"download-links-title", u8"Pakua vitabu" },
  { u8"empty-search-results-page-header", u8"Hakuna matokeo yaliyopatikana ya <b>\"{{{SEARCH_PATTERN}}}}\"</b>" },
  { u8"filter-by-tag", u8"Chuja kwa lebo \"{{TAG}}\"" },
  { u8"fulltext-search-unavailable", u8"Utafutaji wa maandishi kamili haupatikani" },
  { u8"hash-download-alt-text", u8"pakua heshi" },
  { u8"hash-download-link-text", u8"Sha256 heshi" },
  { u8"home-button-text", u8"Nenda kwenye ukurasa mkuu wa '{{BOOK_TITLE}}'" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} si ombi halali la maudhui ghafi." },
  { u8"invalid-request", u8"URL iliyoombwa \"{{{url}}}\" si ombi halali." },
  { u8"library-button-text", u8"Nenda katika wiki ya mwanzo" },
  { u8"library-opds-feed-all-entries", u8"Mlisho wa OPDS wa Maktaba - Maingizo yote" },
  { u8"library-opds-feed-parameterised", u8"Mlisho wa OPDS wa Maktaba - maingizo yanayolingana {{#LANG}}\nLugha: {{LANG}} {{/LANG}}{{#CATEGORY}}\nKitengo: {{CATEGORY}} {{/CATEGORY}} {{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\nSwali: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"sumaku ya kupakua" },
  { u8"magnet-link-text", u8"Kiungo cha sumaku" },
  { u8"name", u8"Kiswahili" },
  { u8"no-book-found", u8"Hakuna kitabu kinacholingana na vigezo vya uteuzi" },
  { u8"no-query", u8"Hakuna swali lililotolewa." },
  { u8"no-search-results", u8"Injini ya utafutaji ya maandishi kamili haipatikani kwa maudhui haya." },
  { u8"no-such-book", u8"Hakuna kitabu kama hiki: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"Hakuna thamani iliyotolewa kwa hoja {{ARGUMENT}}" },
  { u8"powered-by-kiwix-html", u8"Inaendeshwa na <a href=\"https://kiwix.org\">Kiwix</a>" },
  { u8"preview-book", u8"Hakiki" },
  { u8"random-article-failure", u8"Lo! Imeshindwa kuchagua makala nasibu :(" },
  { u8"random-page-button-text", u8"Nenda kwa ukurasa uliochaguliwa kwa nasibu" },
  { u8"raw-entry-not-found", u8"Haiwezi kupata ingizo la {{DATATYPE}} {{ENTRY}}" },
  { u8"search", u8"Tafuta" },
  { u8"search-result-book-info", u8"kutoka kwa {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"Matokeo <b>{{START}}-{{END}}</b> ya <b>{{COUNT}}</b> ya <b>\"{{{SEARCH_PATTERN}}}}\"</b>" },
  { u8"search-results-page-title", u8"Tafuta: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"Tafuta '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"Acha kuchuja kwa lebo \"{{TAG}}\"" },
  { u8"suggest-full-text-search", u8"ina '{{{SEARCH_TERMS}}}}'..." },
  { u8"suggest-search", u8"Tafuta maandishi kamili ya <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"Inapakia Maudhui" },
  { u8"too-many-books", u8"Vitabu vingi mno vimeombwa ({{NB_BOOKS}}) ambapo kikomo ni {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"pakua torrent" },
  { u8"torrent-download-link-text", u8"Faili ya Torrent" },
  { u8"unknown-error", u8"Hitilafu isiyojulikana" },
  { u8"url-not-found", u8"URL iliyoombwa \"{{url}}\" haikupatikana kwenye seva hii." },
  { u8"welcome-page-overzealous-filter", u8"Hakuna matokeo. Je, ungependa <a href=\"{{URL}}\">kuweka upya kichujio</a> ?" },
  { u8"welcome-to-kiwix-server", u8"Karibu kwenye Seva ya Kiwix" },
  { u8"word-count", u8"Maneno {{COUNT}}" }
};


const I18nString string_table_for_te[] = {
  { u8"400-page-heading", u8"\u0c1a\u0c46\u0c32\u0c4d\u0c32\u0c28\u0c3f \u0c05\u0c2d\u0c4d\u0c2f\u0c30\u0c4d\u0c25\u0c28" },
  { u8"400-page-title", u8"\u0c1a\u0c46\u0c32\u0c4d\u0c32\u0c28\u0c3f \u0c05\u0c2d\u0c4d\u0c2f\u0c30\u0c4d\u0c25\u0c28" },
  { u8"404-page-heading", u8"\u0c26\u0c4a\u0c30\u0c15\u0c32\u0c47\u0c26\u0c41" },
  { u8"404-page-title", u8"\u0c15\u0c02\u0c1f\u0c46\u0c02\u0c1f\u0c4d \u0c15\u0c28\u0c41\u0c17\u0c4a\u0c28\u0c2c\u0c21\u0c32\u0c47\u0c26\u0c41" },
  { u8"500-page-heading", u8"\u0c05\u0c02\u0c24\u0c30\u0c4d\u0c17\u0c24 \u0c38\u0c30\u0c4d\u0c35\u0c30\u0c4d \u0c32\u0c4b\u0c2a\u0c02" },
  { u8"500-page-title", u8"\u0c05\u0c02\u0c24\u0c30\u0c4d\u0c17\u0c24 \u0c38\u0c30\u0c4d\u0c35\u0c30\u0c4d \u0c32\u0c4b\u0c2a\u0c02" },
  { u8"book-filtering-all-categories", u8"\u0c35\u0c30\u0c4d\u0c17\u0c3e\u0c32\u0c28\u0c4d\u0c28\u0c40" },
  { u8"book-filtering-all-languages", u8"\u0c05\u0c28\u0c4d\u0c28\u0c3f \u0c2d\u0c3e\u0c37\u0c32\u0c41" },
  { u8"confusion-of-tongues", u8"\u0c35\u0c3f\u0c35\u0c3f\u0c27 \u0c2d\u0c3e\u0c37\u0c32\u0c4d\u0c32\u0c4b\u0c28\u0c3f \u0c30\u0c46\u0c02\u0c21\u0c41 \u0c32\u0c47\u0c26\u0c3e \u0c05\u0c02\u0c24\u0c15\u0c02\u0c1f\u0c47 \u0c0e\u0c15\u0c4d\u0c15\u0c41\u0c35 \u0c2a\u0c41\u0c38\u0c4d\u0c24\u0c15\u0c3e\u0c32\u0c41 \u0c36\u0c4b\u0c27\u0c28\u0c32\u0c4b \u0c2a\u0c3e\u0c32\u0c4d\u0c17\u0c4a\u0c02\u0c1f\u0c3e\u0c2f\u0c3f, \u0c07\u0c26\u0c3f \u0c17\u0c02\u0c26\u0c30\u0c17\u0c4b\u0c33 \u0c2b\u0c32\u0c3f\u0c24\u0c3e\u0c32\u0c15\u0c41 \u0c26\u0c3e\u0c30\u0c3f\u0c24\u0c40\u0c2f\u0c35\u0c1a\u0c4d\u0c1a\u0c41." },
  { u8"count-of-matching-books", u8"{{COUNT}} \u0c2a\u0c41\u0c38\u0c4d\u0c24\u0c15\u0c02(\u0c32\u0c41)" },
  { u8"direct-download-alt-text", u8"\u0c28\u0c47\u0c30\u0c41\u0c17\u0c3e \u0c21\u0c4c\u0c28\u0c4d\u0c32\u0c4b\u0c21\u0c4d" },
  { u8"direct-download-link-text", u8"\u0c21\u0c48\u0c30\u0c46\u0c15\u0c4d\u0c1f\u0c4d" },
  { u8"download", u8"\u0c21\u0c4c\u0c28\u0c4d\u200c\u0c32\u0c4b\u0c21\u0c4d" },
  { u8"download-links-heading", u8"<b><i>{{BOOK_TITLE}}</i></b> \u0c15\u0c4b\u0c38\u0c02 \u0c32\u0c3f\u0c02\u0c15\u0c4d\u200c\u0c32\u0c28\u0c41 \u0c21\u0c4c\u0c28\u0c4d\u200c\u0c32\u0c4b\u0c21\u0c4d \u0c1a\u0c47\u0c2f\u0c02\u0c21\u0c3f" },
  { u8"download-links-title", u8"\u0c2a\u0c41\u0c38\u0c4d\u0c24\u0c15\u0c3e\u0c28\u0c4d\u0c28\u0c3f \u0c21\u0c4c\u0c28\u0c4d\u200c\u0c32\u0c4b\u0c21\u0c4d \u0c1a\u0c47\u0c2f\u0c02\u0c21\u0c3f" },
  { u8"filter-by-tag", u8"\"{{TAG}}\" \u0c1f\u0c4d\u0c2f\u0c3e\u0c17\u0c4d \u0c26\u0c4d\u0c35\u0c3e\u0c30\u0c3e \u0c2b\u0c3f\u0c32\u0c4d\u0c1f\u0c30\u0c4d \u0c1a\u0c47\u0c2f\u0c02\u0c21\u0c3f" },
  { u8"fulltext-search-unavailable", u8"\u0c2a\u0c42\u0c30\u0c4d\u0c24\u0c3f \u0c35\u0c1a\u0c28 \u0c36\u0c4b\u0c27\u0c28 \u0c05\u0c02\u0c26\u0c41\u0c2c\u0c3e\u0c1f\u0c41\u0c32\u0c4b \u0c32\u0c47\u0c26\u0c41" },
  { u8"hash-download-alt-text", u8"\u0c39\u0c3e\u0c37\u0c4d\u200c\u0c28\u0c3f \u0c21\u0c4c\u0c28\u0c4d\u200c\u0c32\u0c4b\u0c21\u0c4d \u0c1a\u0c47\u0c2f\u0c02\u0c21\u0c3f" },
  { u8"hash-download-link-text", u8"\u0c37\u0c3e256 \u0c39\u0c3e\u0c37\u0c4d" },
  { u8"home-button-text", u8"'{{BOOK_TITLE}}' \u0c2f\u0c4a\u0c15\u0c4d\u0c15 \u0c2a\u0c4d\u0c30\u0c27\u0c3e\u0c28 \u0c2a\u0c47\u0c1c\u0c40\u0c15\u0c3f \u0c35\u0c46\u0c33\u0c4d\u0c32\u0c02\u0c21\u0c3f" },
  { u8"invalid-raw-data-type", u8"\u0c2e\u0c41\u0c21\u0c3f \u0c15\u0c02\u0c1f\u0c46\u0c02\u0c1f\u0c4d \u0c15\u0c4b\u0c38\u0c02 {{DATATYPE}} \u0c1a\u0c46\u0c32\u0c4d\u0c32\u0c41\u0c2c\u0c3e\u0c1f\u0c41 \u0c05\u0c2f\u0c4d\u0c2f\u0c47 \u0c05\u0c2d\u0c4d\u0c2f\u0c30\u0c4d\u0c25\u0c28 \u0c15\u0c3e\u0c26\u0c41." },
  { u8"library-button-text", u8"\u0c38\u0c4d\u0c35\u0c3e\u0c17\u0c24 \u0c2a\u0c47\u0c1c\u0c40\u0c15\u0c3f \u0c35\u0c46\u0c33\u0c4d\u0c32\u0c02\u0c21\u0c3f" },
  { u8"library-opds-feed-all-entries", u8"\u0c32\u0c48\u0c2c\u0c4d\u0c30\u0c30\u0c40 OPDS \u0c2b\u0c40\u0c21\u0c4d - \u0c05\u0c28\u0c4d\u0c28\u0c3f \u0c0e\u0c02\u0c1f\u0c4d\u0c30\u0c40\u0c32\u0c41" },
  { u8"library-opds-feed-parameterised", u8"\u0c32\u0c48\u0c2c\u0c4d\u0c30\u0c30\u0c40 OPDS \u0c2b\u0c40\u0c21\u0c4d - \u0c0e\u0c02\u0c1f\u0c4d\u0c30\u0c40\u0c32\u0c41 \u0c38\u0c30\u0c3f\u0c2a\u0c4b\u0c32\u0c47 {{#LANG}}\n\u0c2d\u0c3e\u0c37: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategory: {{CATEGORY}} {{/CATEGORY}} {{#TAG}}\n\u0c1f\u0c4d\u0c2f\u0c3e\u0c17\u0c4d: {{TAG}} {{/TAG}}{{#Q}}\n\u0c2a\u0c4d\u0c30\u0c36\u0c4d\u0c28: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"\u0c05\u0c2f\u0c38\u0c4d\u0c15\u0c3e\u0c02\u0c24\u0c3e\u0c28\u0c4d\u0c28\u0c3f \u0c21\u0c4c\u0c28\u0c4d\u200c\u0c32\u0c4b\u0c21\u0c4d \u0c1a\u0c47\u0c2f\u0c02\u0c21\u0c3f" },
  { u8"magnet-link-text", u8"\u0c2e\u0c3e\u0c17\u0c4d\u0c28\u0c46\u0c1f\u0c4d \u0c32\u0c3f\u0c02\u0c15\u0c4d" },
  { u8"name", u8"\u0c07\u0c02\u0c17\u0c4d\u0c32\u0c40\u0c37\u0c41" },
  { u8"no-book-found", u8"\u0c0e\u0c02\u0c2a\u0c3f\u0c15 \u0c2a\u0c4d\u0c30\u0c2e\u0c3e\u0c23\u0c3e\u0c32\u0c15\u0c41 \u0c0f \u0c2a\u0c41\u0c38\u0c4d\u0c24\u0c15\u0c02 \u0c38\u0c30\u0c3f\u0c2a\u0c4b\u0c32\u0c32\u0c47\u0c26\u0c41" },
  { u8"no-query", u8"\u0c2a\u0c4d\u0c30\u0c36\u0c4d\u0c28 \u0c0f\u0c26\u0c40 \u0c05\u0c02\u0c26\u0c3f\u0c02\u0c1a\u0c2c\u0c21\u0c32\u0c47\u0c26\u0c41." },
  { u8"no-search-results", u8"\u0c08 \u0c15\u0c02\u0c1f\u0c46\u0c02\u0c1f\u0c4d \u0c15\u0c4b\u0c38\u0c02 \u0c2b\u0c41\u0c32\u0c4d\u200c\u0c1f\u0c46\u0c15\u0c4d\u0c38\u0c4d\u0c1f\u0c4d \u0c36\u0c4b\u0c27\u0c28 \u0c07\u0c02\u0c1c\u0c3f\u0c28\u0c4d \u0c05\u0c02\u0c26\u0c41\u0c2c\u0c3e\u0c1f\u0c41\u0c32\u0c4b \u0c32\u0c47\u0c26\u0c41." },
  { u8"no-such-book", u8"\u0c05\u0c32\u0c3e\u0c02\u0c1f\u0c3f \u0c2a\u0c41\u0c38\u0c4d\u0c24\u0c15\u0c02 \u0c32\u0c47\u0c26\u0c41: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u0c06\u0c30\u0c4d\u0c17\u0c4d\u0c2f\u0c41\u0c2e\u0c46\u0c02\u0c1f\u0c4d {{ARGUMENT}}\u0c15\u0c3f \u0c35\u0c3f\u0c32\u0c41\u0c35 \u0c05\u0c02\u0c26\u0c3f\u0c02\u0c1a\u0c2c\u0c21\u0c32\u0c47\u0c26\u0c41" },
  { u8"powered-by-kiwix-html", u8"<a href=\"https://kiwix.org\">Kiwix</a> \u0c26\u0c4d\u0c35\u0c3e\u0c30\u0c3e \u0c06\u0c27\u0c3e\u0c30\u0c3f\u0c24\u0c02" },
  { u8"preview-book", u8"\u0c2a\u0c4d\u0c30\u0c3f\u0c35\u0c4d\u0c2f\u0c42" },
  { u8"random-article-failure", u8"\u0c05\u0c2f\u0c4d\u0c2f\u0c4b! \u0c2f\u0c3e\u0c26\u0c43\u0c1a\u0c4d\u0c1b\u0c3f\u0c15 \u0c15\u0c25\u0c28\u0c3e\u0c28\u0c4d\u0c28\u0c3f \u0c0e\u0c02\u0c1a\u0c41\u0c15\u0c4b\u0c35\u0c21\u0c02\u0c32\u0c4b \u0c35\u0c3f\u0c2b\u0c32\u0c2e\u0c48\u0c02\u0c26\u0c3f :(" },
  { u8"random-page-button-text", u8"\u0c2f\u0c3e\u0c26\u0c43\u0c1a\u0c4d\u0c1b\u0c3f\u0c15\u0c02\u0c17\u0c3e \u0c0e\u0c02\u0c1a\u0c41\u0c15\u0c41\u0c28\u0c4d\u0c28 \u0c2a\u0c47\u0c1c\u0c40\u0c15\u0c3f \u0c35\u0c46\u0c33\u0c4d\u0c32\u0c02\u0c21\u0c3f" },
  { u8"raw-entry-not-found", u8"{{DATATYPE}} \u0c0e\u0c02\u0c1f\u0c4d\u0c30\u0c40 {{ENTRY}} \u0c15\u0c28\u0c41\u0c17\u0c4a\u0c28\u0c2c\u0c21\u0c32\u0c47\u0c26\u0c41" },
  { u8"search", u8"\u0c35\u0c46\u0c24\u0c41\u0c15\u0c41" },
  { u8"searchbox-tooltip", u8"'{{BOOK_TITLE}}'\u0c28\u0c3f \u0c36\u0c4b\u0c27\u0c3f\u0c02\u0c1a\u0c02\u0c21\u0c3f" },
  { u8"stop-filtering-by-tag", u8"\"{{TAG}}\" \u0c1f\u0c4d\u0c2f\u0c3e\u0c17\u0c4d \u0c26\u0c4d\u0c35\u0c3e\u0c30\u0c3e \u0c2b\u0c3f\u0c32\u0c4d\u0c1f\u0c30\u0c4d \u0c1a\u0c47\u0c2f\u0c21\u0c3e\u0c28\u0c4d\u0c28\u0c3f \u0c06\u0c2a\u0c3f\u0c35\u0c47\u0c2f\u0c3f" },
  { u8"suggest-full-text-search", u8"'{{{SEARCH_TERMS}}}'\u0c28\u0c3f \u0c15\u0c32\u0c3f\u0c17\u0c3f \u0c09\u0c02\u0c26\u0c3f..." },
  { u8"suggest-search", u8"<a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a> \u0c15\u0c4b\u0c38\u0c02 \u0c2a\u0c42\u0c30\u0c4d\u0c24\u0c3f \u0c35\u0c1a\u0c28 \u0c36\u0c4b\u0c27\u0c28 \u0c1a\u0c47\u0c2f\u0c02\u0c21\u0c3f" },
  { u8"too-many-books", u8"\u0c2a\u0c30\u0c3f\u0c2e\u0c3f\u0c24\u0c3f {{LIMIT}} \u0c09\u0c28\u0c4d\u0c28 \u0c1a\u0c3e\u0c32\u0c3e \u0c2a\u0c41\u0c38\u0c4d\u0c24\u0c15\u0c3e\u0c32\u0c41 \u0c05\u0c2d\u0c4d\u0c2f\u0c30\u0c4d\u0c25\u0c3f\u0c02\u0c1a\u0c2c\u0c21\u0c4d\u0c21\u0c3e\u0c2f\u0c3f ({{NB_BOOKS}})" },
  { u8"torrent-download-alt-text", u8"\u0c1f\u0c4a\u0c30\u0c46\u0c02\u0c1f\u0c4d\u200c\u0c28\u0c3f \u0c21\u0c4c\u0c28\u0c4d\u200c\u0c32\u0c4b\u0c21\u0c4d \u0c1a\u0c47\u0c2f\u0c02\u0c21\u0c3f" },
  { u8"torrent-download-link-text", u8"\u0c1f\u0c4b\u0c30\u0c46\u0c02\u0c1f\u0c4d \u0c2b\u0c48\u0c32\u0c4d" },
  { u8"url-not-found", u8"\u0c05\u0c2d\u0c4d\u0c2f\u0c30\u0c4d\u0c25\u0c3f\u0c02\u0c1a\u0c3f\u0c28 URL \"{{url}}\" \u0c08 \u0c38\u0c30\u0c4d\u0c35\u0c30\u0c4d\u200c\u0c32\u0c4b \u0c15\u0c28\u0c41\u0c17\u0c4a\u0c28\u0c2c\u0c21\u0c32\u0c47\u0c26\u0c41." },
  { u8"welcome-page-overzealous-filter", u8"\u0c2b\u0c32\u0c3f\u0c24\u0c02 \u0c32\u0c47\u0c26\u0c41. <a href=\"{{URL}}\">\u0c35\u0c21\u0c2a\u0c4b\u0c24\u0c28\u0c41 \u0c30\u0c40\u0c38\u0c46\u0c1f\u0c4d</a> \u0c1a\u0c47\u0c38\u0c4d\u0c24\u0c3e\u0c30\u0c3e?" },
  { u8"welcome-to-kiwix-server", u8"Kiwix \u0c38\u0c30\u0c4d\u0c35\u0c30\u0c4d\u200c\u0c15\u0c3f \u0c38\u0c4d\u0c35\u0c3e\u0c17\u0c24\u0c02" }
};


const I18nString string_table_for_test[] = {
  { u8"400-page-heading", u8"[I18N TESTING] -400 karma for an invalid request" },
  { u8"400-page-title", u8"[I18N TESTING] Invalid request ($400 fine must be paid)" },
  { u8"404-advice.p1", u8"Sh*t happens. [I18N TESTING] Take it easy!" },
  { u8"404-advice.p2", u8"[I18N TESTING] Try one of the following:" },
  { u8"404-advice.p3", u8"[I18N TESTING] Check the spelling of the URL path" },
  { u8"404-advice.p4", u8"[I18N TESTING] Press the dice button" },
  { u8"404-advice.p5", u8"Good luck! [I18N TESTING]" },
  { u8"404-img-text", u8"[I18N] Not found! [TESTING]" },
  { u8"404-page-heading", u8"[I18N TESTING] Content not found, but at least the server is alive" },
  { u8"404-page-title", u8"[I18N TESTING] Not Found - Try Again" },
  { u8"500-img-text", u8"Page [I18N] isn't [TESTING] working" },
  { u8"500-page-heading", u8"Oops. [I18N] Page isn't [TESTING] working." },
  { u8"500-page-text", u8"The requested path [I18N TESTING] cannot be properly delivered:" },
  { u8"500-page-title", u8"[I18N] Internal Server Error [TESTING]" },
  { u8"book-category.gutenberg", u8"[I18N] Gutenberg [TESTING]" },
  { u8"book-category.iFixit", u8"[I18N] iFixit [TESTING]" },
  { u8"book-category.mooc", u8"[I18N] MOOC [TESTING]" },
  { u8"book-category.other", u8"[I18N] Other [TESTING]" },
  { u8"book-category.phet", u8"[I18N] Phet [TESTING]" },
  { u8"book-category.stack_exchange", u8"[I18N] Stack Exchange [TESTING]" },
  { u8"book-category.ted", u8"[I18N] Ted [TESTING]" },
  { u8"book-category.vikidia", u8"[I18N] Vikidia [TESTING]" },
  { u8"book-category.wikibooks", u8"[I18N] Wikibooks [TESTING]" },
  { u8"book-category.wikihow", u8"[I18N] wikiHow [TESTING]" },
  { u8"book-category.wikinews", u8"[I18N] Wikinews [TESTING]" },
  { u8"book-category.wikipedia", u8"[I18N] Wikipedia [TESTING]" },
  { u8"book-category.wikiquote", u8"[I18N] Wikiquote [TESTING]" },
  { u8"book-category.wikisource", u8"[I18N] Wikisource [TESTING]" },
  { u8"book-category.wikispecies", u8"[I18N] Wikispecies [TESTING]" },
  { u8"book-category.wikiversity", u8"[I18N] Wikiversity [TESTING]" },
  { u8"book-category.wikivoyage", u8"[I18N] Wikivoyage [TESTING]" },
  { u8"book-category.wiktionary", u8"[I18N] Wiktionary [TESTING]" },
  { u8"book-filtering-all-categories", u8"All [I18N TESTING] categories" },
  { u8"book-filtering-all-languages", u8"All [I18N TESTING] languages" },
  { u8"caution-warning", u8"[I18N] C5n! [TESTING]" },
  { u8"count-of-matching-books", u8"[I18N TESTING] Number of matching books: {{COUNT}}" },
  { u8"direct-download-alt-text", u8"[I18N TESTING] download directly" },
  { u8"direct-download-link-text", u8"[I18N TESTING] HTTP(S)" },
  { u8"download", u8"[I18N Download TESTING]" },
  { u8"download-links-heading", u8"[I18N] Download links for <b><i>{{BOOK_TITLE}}</i></b> [TESTING]" },
  { u8"download-links-title", u8"[I18N TESTING]Download book" },
  { u8"empty-search-results-page-header", u8"[I18N TESTING] No results were found for <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"external-link-advice.p1", u8"[I18N TESTING] The link you're trying to access points past the end of the ZIM file." },
  { u8"external-link-advice.p2", u8"[I18N TESTING] If you are an optimist, you can attempt to open the link." },
  { u8"external-link-advice.p3", u8"[I18N TESTING] But we strongly recommend you to be reasonable and press your browser's back button." },
  { u8"external-link-detected", u8"External [I18] Link [TESTING] Detected" },
  { u8"external-link-intro", u8"[I18N TESTING] The following link may lead you to a place from which you won't ever be able to return" },
  { u8"filter-by-tag", u8"Filter [I18N] by [TESTING] tag \"{{TAG}}\"" },
  { u8"hash-download-alt-text", u8"download [I18N TESTING] hash" },
  { u8"hash-download-link-text", u8"Sha256 [I18N TESTING] hash" },
  { u8"home-button-text", u8"[I18N TESTING] Jump to the main page of '{{BOOK_TITLE}}'" },
  { u8"invalid-request", u8"[I18N TESTING] Invalid URL: \"{{{url}}}\"" },
  { u8"library-button-text", u8"[I18N TESTING] Navigate to the welcome page" },
  { u8"library-opds-feed-all-entries", u8"[I18N] Library [TESTING] OPDS Feed - All entries [I18N TESTING]" },
  { u8"library-opds-feed-parameterised", u8"[I18N] Library OPDS Feed - [TESTING] entries matching {{#LANG}}\nLanguage: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategory: {{CATEGORY}} {{/CATEGORY}}{{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\nQuery: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"download [I18N TESTING] magnet" },
  { u8"magnet-link-text", u8"Magnet [I18N TESTING] link" },
  { u8"name", u8"Fake language for i18n testing" },
  { u8"new-404-page-heading", u8"[I18N TESTING] Oops. Larry Page could not be reached. He may be on paternity leave." },
  { u8"new-404-page-title", u8"Page [I18N] not [TESTING] found" },
  { u8"no-query", u8"[I18N TESTING] Kiwix can read your thoughts but it is against GDPR. Please provide your query explicitly." },
  { u8"no-such-book", u8"[I18N TESTING] No such book: {{BOOK_NAME}}. Sorry." },
  { u8"path-was-not-found", u8"[I18N TESTING] The requested path was not found (in fact, nothing was found instead, either):" },
  { u8"powered-by-kiwix-html", u8"[I18N TESTING] Powered by&nbsp;<a href=\"https://kiwix.org\">Kiwix</a> (nominal power: 1.23 kW)" },
  { u8"preview-book", u8"[I18N] Preview [TESTING]" },
  { u8"random-page-button-text", u8"[I18N TESTING] I am tired of determinism" },
  { u8"search", u8"[I18N Search TESTING]" },
  { u8"search-result-book-info", u8"from [I18N TESTING] {{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"[I18N TESTING] Results <b>{{START}}-{{END}}</b> of <b>{{COUNT}}</b> for <b>\"{{{SEARCH_PATTERN}}}\"</b>" },
  { u8"search-results-page-title", u8"[I18N TESTING] Search: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"[I18N TESTING] Let's search in '{{BOOK_TITLE}}'" },
  { u8"stop-filtering-by-tag", u8"[I18N] Stop filtering [TESTING] by tag \"{{TAG}}\"" },
  { u8"suggest-full-text-search", u8"[I18N TESTING] cOnTaInInG '{{{SEARCH_TERMS}}}'..." },
  { u8"suggest-search", u8"[I18N TESTING] Make a full text search for <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>" },
  { u8"text-loading-content", u8"[I18N TESTING] Loading content" },
  { u8"torrent-download-alt-text", u8"download [I18N TESTING] torrent" },
  { u8"torrent-download-link-text", u8"Torrent [I18N TESTING] file" },
  { u8"url-not-found", u8"[I18N TESTING] URL not found: {{url}}" },
  { u8"welcome-page-overzealous-filter", u8"[I18N TESTING] Nothing found. <a href=\"{{URL}}\">Reset filter</a>" },
  { u8"welcome-to-kiwix-server", u8"[I18N] Welcome to Kiwix Server [TESTING]" },
  { u8"word-count", u8"{{COUNT}} [I18N TESTING] words" }
};


const I18nString string_table_for_tr[] = {
  { u8"400-page-heading", u8"Ge\u00e7ersiz istek" },
  { u8"400-page-title", u8"Ge\u00e7ersiz istek" },
  { u8"404-page-heading", u8"Bulunamad\u0131" },
  { u8"404-page-title", u8"i\u00e7erik bulunamad\u0131" },
  { u8"500-page-heading", u8"\u00dczg\u00fcn\u00fcz. Sayfa \u00e7al\u0131\u015fm\u0131yor." },
  { u8"500-page-text", u8"\u0130stenen yol d\u00fczg\u00fcn bir \u015fekilde teslim edilemiyor:" },
  { u8"500-page-title", u8"\u0130\u00e7 Sunucu Hatas\u0131" },
  { u8"book-filtering-all-categories", u8"T\u00fcm kategoriler" },
  { u8"book-filtering-all-languages", u8"T\u00fcm diller" },
  { u8"confusion-of-tongues", u8"Aramaya farkl\u0131 dillerde iki veya daha fazla kitap kat\u0131lacak ve bu da kafa kar\u0131\u015ft\u0131r\u0131c\u0131 sonu\u00e7lara yol a\u00e7abilecektir." },
  { u8"count-of-matching-books", u8"{{COUNT}} kitap" },
  { u8"direct-download-alt-text", u8"Do\u011frudan HTTP(S) \u00fczerinden indir" },
  { u8"direct-download-link-text", u8"Do\u011frudan" },
  { u8"download", u8"\u0130ndir" },
  { u8"download-links-heading", u8"<b><i>{{BOOK_TITLE}}</i></b> i\u00e7in indirme ba\u011flant\u0131lar\u0131" },
  { u8"download-links-title", u8"Kitaplar\u0131 indir" },
  { u8"empty-search-results-page-header", u8"<b>\"{{{SEARCH_PATTERN}}}\"</b> i\u00e7in sonu\u00e7 bulunamad\u0131" },
  { u8"filter-by-tag", u8"\"{{{TAG}}}\" etiketine g\u00f6re filtrele" },
  { u8"fulltext-search-unavailable", u8"Tam metin aramas\u0131 kullan\u0131lam\u0131yor" },
  { u8"hash-download-alt-text", u8"SHA-256 dosya toplam kontrol\u00fcn\u00fc g\u00f6r\u00fcnt\u00fcle" },
  { u8"hash-download-link-text", u8"SHA-256 sa\u011flama toplam\u0131" },
  { u8"home-button-text", u8"'{{{BOOK_TITLE}}}' ana sayfas\u0131na git" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}}, ham i\u00e7erik i\u00e7in ge\u00e7erli bir istek de\u011fil." },
  { u8"invalid-request", u8"\u0130stenen \"{{{url}}}\" URL'si ge\u00e7erli bir istek de\u011fil." },
  { u8"library-button-text", u8"Kar\u015f\u0131lama sayfas\u0131na git" },
  { u8"library-opds-feed-all-entries", u8"K\u00fct\u00fcphane OPDS Ak\u0131\u015f\u0131 - T\u00fcm giri\u015fler" },
  { u8"library-opds-feed-parameterised", u8"K\u00fct\u00fcphane OPDS \u00d6zet Ak\u0131\u015f\u0131 - {{#LANG}}\nLanguage: {{LANG}} {{/LANG}}{{#CATEGORY}}\nCategory: {{CATEGORY}} {{/CATEGORY}} ile e\u015fle\u015fen giri\u015fler {{#TAG}}\nTag: {{TAG}} {{/TAG}}{{#Q}}\nQuery: {{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"M\u0131knat\u0131s ba\u011flant\u0131s\u0131yla indir" },
  { u8"magnet-link-text", u8"M\u0131knat\u0131s ba\u011flant\u0131s\u0131" },
  { u8"name", u8"T\u00fcrk\u00e7e" },
  { u8"no-book-found", u8"Se\u00e7im kriterleriyle e\u015fle\u015fen kitap yok" },
  { u8"no-query", u8"Sorgu sa\u011flanmad\u0131." },
  { u8"no-search-results", u8"Tam metin arama motoru bu i\u00e7erik i\u00e7in kullan\u0131lamaz." },
  { u8"no-such-book", u8"B\u00f6yle bir kitap yok: {{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"{{ARGUMENT}} ba\u011f\u0131ms\u0131z de\u011fi\u015fkeni i\u00e7in de\u011fer sa\u011flanmad\u0131" },
  { u8"powered-by-kiwix-html", u8"<a href=\"https://kiwix.org\">Kiwix</a> taraf\u0131ndan desteklenmektedir" },
  { u8"preview-book", u8"\u00d6nizleme" },
  { u8"random-article-failure", u8"Hata! Rastgele bir madde se\u00e7ilemedi :(" },
  { u8"random-page-button-text", u8"Rastgele se\u00e7ilen bir sayfaya git" },
  { u8"raw-entry-not-found", u8"{{DATATYPE}} {{ENTRY}} giri\u015fi bulunamad\u0131" },
  { u8"search", u8"Ara" },
  { u8"search-result-book-info", u8"{{BOOK_TITLE}} adl\u0131 kitaptan" },
  { u8"search-results-page-header", u8"<b>\"{{{SEARCH_PATTERN}}}\"</b> i\u00e7in <b>{{COUNT}}</b> sonu\u00e7tan <b>{{START}}-{{END}}</b> aras\u0131 sonu\u00e7lar" },
  { u8"search-results-page-title", u8"Arama: {{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"'{{{BOOK_TITLE}}}' ara" },
  { u8"stop-filtering-by-tag", u8"\"{{{TAG}}}\" etiketine g\u00f6re filtrelemeyi durdur" },
  { u8"suggest-full-text-search", u8"'{{{SEARCH_TERMS}}}' i\u00e7eriyor..." },
  { u8"suggest-search", u8"<a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a> i\u00e7in tam metin aramas\u0131 yap\u0131n" },
  { u8"too-many-books", u8"S\u0131n\u0131r {{LIMIT}} oldu\u011funda \u00e7ok fazla ({{NB_BOOKS}}) kitap istendi" },
  { u8"torrent-download-alt-text", u8"BitTorrent \u00fczerinden indir" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"Bilinmeyen hata" },
  { u8"url-not-found", u8"\u0130stenen \"{{url}}\" URL'si bu sunucuda bulunamad\u0131." },
  { u8"welcome-page-overzealous-filter", u8"Sonu\u00e7 yok. <a href=\"{{URL}}\">Filtreyi s\u0131f\u0131rlamak</a> ister misiniz?" },
  { u8"welcome-to-kiwix-server", u8"Kiwix Sunucusuna Ho\u015f Geldiniz" },
  { u8"word-count", u8"{{COUNT}} kelime" }
};


const I18nString string_table_for_zh_hans[] = {
  { u8"400-page-heading", u8"\u65e0\u6548\u8bf7\u6c42" },
  { u8"400-page-title", u8"\u65e0\u6548\u8bf7\u6c42" },
  { u8"404-advice.p1", u8"\u60a8\u6b63\u5728\u5bfb\u627e\u7684\u5185\u5bb9\u53ef\u80fd\u4ecd\u7136\u53ef\u7528\uff0c\u4f46\u5b83\u53ef\u80fd\u4f4d\u4e8e ZIM \u6587\u4ef6\u4e2d\u7684\u4e0d\u540c\u4f4d\u7f6e\u3002" },
  { u8"404-advice.p2", u8"\u8bf7\uff1a" },
  { u8"404-advice.p3", u8"\u5c1d\u8bd5\u4f7f\u7528\u641c\u7d22\u529f\u80fd\u6765\u67e5\u627e\u60a8\u60f3\u8981\u7684\u5185\u5bb9" },
  { u8"404-advice.p4", u8"\u67e5\u627e\u4e0e\u4f60\u6b63\u5728\u5bfb\u627e\u7684\u4fe1\u606f\u76f8\u5173\u7684\u5173\u952e\u5b57\u6216\u6807\u9898" },
  { u8"404-advice.p5", u8"\u5373\u4f7f\u539f\u59cb\u94fe\u63a5\u65e0\u6cd5\u6b63\u5e38\u5de5\u4f5c\uff0c\u8fd9\u79cd\u65b9\u6cd5\u4e5f\u5e94\u8be5\u53ef\u4ee5\u5e2e\u52a9\u60a8\u627e\u5230\u6240\u9700\u7684\u5185\u5bb9\u3002" },
  { u8"404-img-text", u8"\u672a\u627e\u5230\uff01" },
  { u8"404-page-heading", u8"\u672a\u627e\u5230" },
  { u8"404-page-title", u8"\u672a\u627e\u5230\u5185\u5bb9" },
  { u8"500-img-text", u8"\u9875\u9762\u65e0\u6cd5\u6b63\u5e38\u5de5\u4f5c" },
  { u8"500-page-heading", u8"\u54ce\u5440\u3002\u9875\u9762\u65e0\u6cd5\u6b63\u5e38\u5de5\u4f5c\u3002" },
  { u8"500-page-text", u8"\u8bf7\u6c42\u7684\u8def\u5f84\u65e0\u6cd5\u6b63\u786e\u4f20\u9012\uff1a" },
  { u8"500-page-title", u8"\u5185\u90e8\u670d\u52a1\u5668\u9519\u8bef" },
  { u8"book-category.other", u8"\u5176\u4ed6" },
  { u8"book-category.wikibooks", u8"\u7ef4\u57fa\u6559\u79d1\u4e66" },
  { u8"book-category.wikinews", u8"\u7ef4\u57fa\u65b0\u95fb" },
  { u8"book-category.wikipedia", u8"\u7ef4\u57fa\u767e\u79d1" },
  { u8"book-category.wikiquote", u8"\u7ef4\u57fa\u8bed\u5f55" },
  { u8"book-category.wikisource", u8"\u7ef4\u57fa\u6587\u5e93" },
  { u8"book-category.wikispecies", u8"\u7ef4\u57fa\u7269\u79cd" },
  { u8"book-category.wikiversity", u8"\u7ef4\u57fa\u5b66\u9662" },
  { u8"book-category.wikivoyage", u8"\u7ef4\u57fa\u5bfc\u6e38" },
  { u8"book-category.wiktionary", u8"\u7ef4\u57fa\u8bcd\u5178" },
  { u8"book-filtering-all-categories", u8"\u6240\u6709\u5206\u7c7b" },
  { u8"book-filtering-all-languages", u8"\u6240\u6709\u8bed\u8a00" },
  { u8"caution-warning", u8"\u8b66\u544a\uff01" },
  { u8"confusion-of-tongues", u8"\u4e24\u672c\u6216\u591a\u672c\u4e0d\u540c\u8bed\u8a00\u7684\u56fe\u4e66\u5c06\u540c\u65f6\u88ab\u641c\u7d22\uff0c\u8fd9\u53ef\u80fd\u4f1a\u5bfc\u81f4\u641c\u7d22\u7ed3\u679c\u6df7\u4e71\u3002" },
  { u8"count-of-matching-books", u8"{{COUNT}} \u672c\u4e66" },
  { u8"direct-download-alt-text", u8"\u901a\u8fc7 HTTP(S) \u76f4\u63a5\u4e0b\u8f09" },
  { u8"direct-download-link-text", u8"\u76f4\u63a5" },
  { u8"download", u8"\u4e0b\u8f7d" },
  { u8"download-links-heading", u8"\u4e0b\u8f7d<b><i>{{BOOK_TITLE}}</i></b>\u7684\u94fe\u63a5" },
  { u8"download-links-title", u8"\u4e0b\u8f7d\u4e66\u7c4d" },
  { u8"empty-search-results-page-header", u8"\u672a\u627e\u5230<b>\u201c{{{SEARCH_PATTERN}}}\u201d</b>\u7684\u7ed3\u679c" },
  { u8"external-link-advice.p1", u8"\u4f60\u8bd5\u56fe\u8bbf\u95ee\u7684\u94fe\u63a5\u4e0d\u5728\u4f60\u7684\u79bb\u7ebf\u5305\u4e2d\uff0c\u9700\u8981\u8054\u7f51\u624d\u80fd\u8bbf\u95ee\u3002" },
  { u8"external-link-advice.p2", u8"\u5982\u679c\u60a8\u53ef\u4ee5\u4e0a\u7f51\uff0c\u60a8\u53ef\u4ee5\u5c1d\u8bd5\u6253\u5f00\u8be5\u94fe\u63a5\u3002" },
  { u8"external-link-advice.p3", u8"\u60a8\u4e5f\u53ef\u4ee5\u4f7f\u7528\u6d4f\u89c8\u5668\u7684\u540e\u9000\u6309\u94ae\u8fd4\u56de ZIM \u7684\u79bb\u7ebf\u5185\u5bb9\u3002" },
  { u8"external-link-detected", u8"\u68c0\u6d4b\u5230\u5916\u90e8\u94fe\u63a5" },
  { u8"external-link-intro", u8"\u4f60\u5373\u5c06\u79bb\u5f00Kiwix\u7684ZIM\u9605\u8bfb\u5668\u5e76\u6253\u5f00\u7f51\u9875" },
  { u8"filter-by-tag", u8"\u6309\u6807\u7b7e\u201c{{{TAG}}}\u201d\u8fc7\u6ee4" },
  { u8"fulltext-search-unavailable", u8"\u5168\u6587\u641c\u7d22\u4e0d\u53ef\u7528" },
  { u8"hash-download-alt-text", u8"\u663e\u793a SHA-256 \u6587\u4ef6\u6821\u9a8c\u548c" },
  { u8"hash-download-link-text", u8"SHA-256 \u6821\u9a8c\u548c" },
  { u8"home-button-text", u8"\u8f6c\u5230\u201c{{{BOOK_TITLE}}}\u201d\u7684\u4e3b\u9875" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}} \u5bf9\u539f\u8bf7\u6c42\u65e0\u6548\u3002" },
  { u8"invalid-request", u8"\u8bf7\u6c42\u7684URL\u65e0\u6548\uff1a{{{url}}}" },
  { u8"library-button-text", u8"\u8f6c\u5230\u6b22\u8fce\u9875\u9762" },
  { u8"library-opds-feed-all-entries", u8"\u56fe\u4e66\u9986 OPDS Feed - \u6240\u6709\u6761\u76ee" },
  { u8"library-opds-feed-parameterised", u8"\u56fe\u4e66\u9986 OPDS Feed - \u5339\u914d\u7684\u9879\u76ee {{#LANG}}\n\u8bed\u8a00\uff1a{{LANG}} {{/LANG}}{{#CATEGORY}}\n\u5206\u7c7b\uff1a{{CATEGORY}} {{/CATEGORY}}{{#TAG}}\n\u6807\u7b7e\uff1a{{TAG}} {{/TAG}}{{#Q}}\n\u67e5\u8be2\uff1a{{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"\u901a\u8fc7\u78c1\u529b\u94fe\u63a5\u4e0b\u8f7d" },
  { u8"magnet-link-text", u8"\u78c1\u529b\u94fe\u63a5" },
  { u8"name", u8"\u7b80\u4f53\u4e2d\u6587" },
  { u8"new-404-page-heading", u8"\u54ce\u5440\u3002\u9875\u9762\u672a\u627e\u5230\u3002" },
  { u8"new-404-page-title", u8"\u627e\u4e0d\u5230\u9875\u9762" },
  { u8"no-book-found", u8"\u6ca1\u6709\u7b26\u5408\u641c\u7d22\u8981\u6c42\u7684\u56fe\u4e66" },
  { u8"no-query", u8"\u672a\u63d0\u4f9b\u67e5\u8be2\u3002" },
  { u8"no-search-results", u8"\u5168\u6587\u641c\u7d22\u5f15\u64ce\u4e0d\u9002\u7528\u4e8e\u8be5\u5185\u5bb9\u3002" },
  { u8"no-such-book", u8"\u6ca1\u6709\u540d\u4e3a\u201c{{BOOK_NAME}}\u201d\u7684\u56fe\u4e66" },
  { u8"no-value-for-arg", u8"\u53c2\u6570{{ARGUMENT}}\u65e0\u503c" },
  { u8"path-was-not-found", u8"\u672a\u627e\u5230\u8bf7\u6c42\u7684\u8def\u5f84\uff1a" },
  { u8"powered-by-kiwix-html", u8"\u7531<a href=\"https://kiwix.org\">Kiwix</a>\u63d0\u4f9b\u6280\u672f\u652f\u6301" },
  { u8"preview-book", u8"\u9884\u89c8" },
  { u8"random-article-failure", u8"\u62b1\u6b49\uff01 \u968f\u673a\u6761\u76ee\u5931\u8d25\u4e86 (\u2060\u3012\u2060\ufe4f\u2060\u3012\u2060)" },
  { u8"random-page-button-text", u8"\u524d\u5f80\u968f\u673a\u9009\u62e9\u7684\u9875\u9762" },
  { u8"raw-entry-not-found", u8"\u627e\u4e0d\u5230 {{DATATYPE}} \u6761\u76ee {{ENTRY}}" },
  { u8"search", u8"\u641c\u7d22" },
  { u8"search-result-book-info", u8"\u6765\u81ea{{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"<b>\u201c{{{SEARCH_PATTERN}}}\u201d</b>\u7684<b>\u7b2c {{START}}-{{END}}</b>\u4e2a\u7ed3\u679c\uff08\u5171<b>{{COUNT}}</b>\u4e2a\uff09" },
  { u8"search-results-page-title", u8"\u641c\u7d22\uff1a{{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"\u641c\u7d22\u201c{{{BOOK_TITLE}}}\u201d" },
  { u8"stop-filtering-by-tag", u8"\u505c\u6b62\u6309\u6807\u7b7e\u201c{{{TAG}}}\u201d\u8fc7\u6ee4" },
  { u8"suggest-full-text-search", u8"\u6b63\u5728\u67e5\u627e\u300c{{{SEARCH_TERMS}}}\u300d\u2026" },
  { u8"suggest-search", u8"\u5bf9<a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a>\u8fdb\u884c\u5168\u6587\u641c\u7d22" },
  { u8"text-loading-content", u8"\u5185\u5bb9\u52a0\u8f7d\u4e2d" },
  { u8"too-many-books", u8"\u8bf7\u6c42\u7684\u56fe\u4e66\u8fc7\u591a ({{NB_BOOKS}})\uff0c\u4e0a\u9650\u4e3a {{LIMIT}}" },
  { u8"torrent-download-alt-text", u8"\u901a\u8fc7 BitTorrent \u4e0b\u8f7d" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"\u672a\u77e5\u9519\u8bef" },
  { u8"url-not-found", u8"\u5728\u6b64\u670d\u52a1\u5668\u4e0a\u627e\u4e0d\u5230\u8bf7\u6c42\u7684 URL\uff1a{{url}}" },
  { u8"welcome-page-overzealous-filter", u8"\u6ca1\u6709\u7ed3\u679c\u3002\u60a8\u60f3<a href=\"{{URL}}\">\u91cd\u7f6e\u8fc7\u6ee4\u5668</a>\u5417\uff1f" },
  { u8"welcome-to-kiwix-server", u8"\u6b22\u8fce\u6765\u5230 Kiwix \u670d\u52a1\u5668" },
  { u8"word-count", u8"{{COUNT}} \u4e2a\u5b57" }
};


const I18nString string_table_for_zh_hant[] = {
  { u8"400-page-heading", u8"\u7121\u6548\u8acb\u6c42" },
  { u8"400-page-title", u8"\u7121\u6548\u8acb\u6c42" },
  { u8"404-advice.p1", u8"\u60a8\u6b63\u5728\u5c0b\u627e\u7684\u5167\u5bb9\u53ef\u80fd\u4ecd\u7136\u53ef\u7528\uff0c\u53ea\u662f\u53ef\u80fd\u4f4d\u65bc ZIM \u6a94\u6848\u4e2d\u7684\u4e0d\u540c\u4f4d\u7f6e\u3002" },
  { u8"404-advice.p2", u8"\u8acb\uff1a" },
  { u8"404-advice.p3", u8"\u5617\u8a66\u4f7f\u7528\u641c\u5c0b\u529f\u80fd\u4f86\u5c0b\u627e\u60a8\u60f3\u8981\u7684\u5167\u5bb9" },
  { u8"404-advice.p4", u8"\u67e5\u770b\u8207\u60a8\u6b63\u5728\u5c0b\u627e\u8cc7\u8a0a\u76f8\u95dc\u7684\u95dc\u9375\u5b57\u6216\u6a19\u984c" },
  { u8"404-advice.p5", u8"\u5373\u4f7f\u539f\u59cb\u9023\u7d50\u7121\u6cd5\u6b63\u5e38\u904b\u4f5c\uff0c\u9019\u7a2e\u65b9\u6cd5\u61c9\u8a72\u53ef\u4ee5\u5e6b\u52a9\u60a8\u767c\u73fe\u5230\u6240\u9700\u7684\u5167\u5bb9\u3002" },
  { u8"404-img-text", u8"\u627e\u4e0d\u5230\uff01" },
  { u8"404-page-heading", u8"\u67e5\u7121\u9801\u9762" },
  { u8"404-page-title", u8"\u67e5\u7121\u5167\u5bb9" },
  { u8"500-img-text", u8"\u9801\u9762\u7121\u6cd5\u6b63\u5e38\u904b\u4f5c" },
  { u8"500-page-heading", u8"\u54ce\u5440\uff0c\u9801\u9762\u7121\u6cd5\u6b63\u5e38\u904b\u4f5c\u3002" },
  { u8"500-page-text", u8"\u8acb\u6c42\u7684\u8def\u5f91\u7121\u6cd5\u6b63\u78ba\u50b3\u905e\uff1a" },
  { u8"500-page-title", u8"\u5167\u90e8\u4f3a\u670d\u5668\u932f\u8aa4" },
  { u8"book-category.gutenberg", u8"\u53e4\u9a30\u5821\u8a08\u5283" },
  { u8"book-category.iFixit", u8"iFixit" },
  { u8"book-category.mooc", u8"MOOC" },
  { u8"book-category.other", u8"\u5176\u4ed6" },
  { u8"book-category.phet", u8"PhET" },
  { u8"book-category.stack_exchange", u8"Stack Exchange" },
  { u8"book-category.ted", u8"Ted" },
  { u8"book-category.vikidia", u8"Vikidia" },
  { u8"book-category.wikibooks", u8"\u7dad\u57fa\u6559\u79d1\u66f8" },
  { u8"book-category.wikihow", u8"wikiHow" },
  { u8"book-category.wikinews", u8"\u7dad\u57fa\u65b0\u805e" },
  { u8"book-category.wikipedia", u8"\u7dad\u57fa\u767e\u79d1" },
  { u8"book-category.wikiquote", u8"\u7dad\u57fa\u8a9e\u9304" },
  { u8"book-category.wikisource", u8"\u7dad\u57fa\u6587\u5eab" },
  { u8"book-category.wikispecies", u8"\u7dad\u57fa\u7269\u7a2e" },
  { u8"book-category.wikiversity", u8"\u7dad\u57fa\u5b78\u9662" },
  { u8"book-category.wikivoyage", u8"\u7dad\u57fa\u5c0e\u904a" },
  { u8"book-category.wiktionary", u8"\u7dad\u57fa\u8a5e\u5178" },
  { u8"book-filtering-all-categories", u8"\u6240\u6709\u5206\u985e" },
  { u8"book-filtering-all-languages", u8"\u6240\u6709\u8a9e\u8a00" },
  { u8"caution-warning", u8"\u6ce8\u610f\uff01" },
  { u8"confusion-of-tongues", u8"\u641c\u7d22\u88e1\u6709\u52a0\u5165\u5169\u672c\u6216\u66f4\u591a\u4e0d\u540c\u8a9e\u8a00\u7684\u66f8\u7c4d\uff0c\u9019\u53ef\u80fd\u6703\u5c0e\u81f4\u6df7\u6dc6\u7d50\u679c\u3002" },
  { u8"count-of-matching-books", u8"{{COUNT}} \u672c\u66f8\u7c4d" },
  { u8"direct-download-alt-text", u8"\u76f4\u63a5\u900f\u904e HTTP\uff08S\uff09\u4e0b\u8f09" },
  { u8"direct-download-link-text", u8"\u76f4\u63a5" },
  { u8"download", u8"\u4e0b\u8f09" },
  { u8"download-links-heading", u8"\u4e0b\u8f09<b><i>{{BOOK_TITLE}}</i></b>\u7684\u9023\u7d50" },
  { u8"download-links-title", u8"\u4e0b\u8f09\u66f8\u7c4d" },
  { u8"empty-search-results-page-header", u8"\u672a\u627e\u5230<b>\u300c{{{SEARCH_PATTERN}}}\u300d</b>\u7684\u7d50\u679c" },
  { u8"external-link-advice.p1", u8"\u60a8\u5617\u8a66\u5b58\u53d6\u7684\u9023\u7d50\u4e0d\u5728\u96e2\u7dda\u5957\u4ef6\u88e1\uff0c\u9700\u8981\u7db2\u8def\u9023\u7dda\u3002" },
  { u8"external-link-advice.p2", u8"\u5982\u679c\u60a8\u53ef\u4ee5\u9023\u4e0a\u7db2\u8def\uff0c\u60a8\u53ef\u4ee5\u5617\u8a66\u958b\u555f\u8a72\u9023\u7d50\u3002" },
  { u8"external-link-advice.p3", u8"\u60a8\u4e5f\u53ef\u4ee5\u4f7f\u7528\u700f\u89bd\u5668\u7684\u8fd4\u56de\u6309\u9215\u8df3\u56de\u5230 ZIM \u96e2\u7dda\u5167\u5bb9\u3002" },
  { u8"external-link-detected", u8"\u5075\u6e2c\u5230\u5916\u90e8\u9023\u7d50" },
  { u8"external-link-intro", u8"\u60a8\u5373\u5c07\u96e2\u958b Kiwix \u7684 ZIM \u95b1\u8b80\u5668\uff0c\u4e26\u4e0a\u7db2\u5230" },
  { u8"filter-by-tag", u8"\u4f9d\u6a19\u7c64\u300c{{{TAG}}}\u300d\u7be9\u9078" },
  { u8"fulltext-search-unavailable", u8"\u5168\u6587\u641c\u5c0b\u7121\u6548" },
  { u8"hash-download-alt-text", u8"\u986f\u793a SHA-256 \u6a94\u6848\u6838\u5c0d\u548c" },
  { u8"hash-download-link-text", u8"SHA-256 \u6838\u5c0d\u548c" },
  { u8"home-button-text", u8"\u524d\u5f80\u300c{{{BOOK_TITLE}}}\u300d\u7684\u9996\u9801" },
  { u8"invalid-raw-data-type", u8"{{DATATYPE}}\u4e0d\u662f\u539f\u59cb\u5167\u5bb9\u7684\u6709\u6548\u8acb\u6c42\u3002" },
  { u8"invalid-request", u8"\u8acb\u6c42\u7684 URL\u300c{{{url}}}\u300d\u4e0d\u662f\u6709\u6548\u7684\u8acb\u6c42\u3002" },
  { u8"library-button-text", u8"\u524d\u5f80\u6b61\u8fce\u9996\u9801" },
  { u8"library-opds-feed-all-entries", u8"\u6587\u5eab OPDS \u6458\u8981 - \u6240\u6709\u9805\u76ee" },
  { u8"library-opds-feed-parameterised", u8"\u6587\u5eab OPDS \u6458\u8981 - \u9805\u76ee\u7b26\u5408 {{#LANG}}\n\u8a9e\u8a00\uff1a{{LANG}} {{/LANG}}{{#CATEGORY}}\n\u5206\u985e\uff1a{{CATEGORY}} {{/CATEGORY}}{{#TAG}}\n\u6a19\u7c64\uff1a{{TAG}} {{/TAG}}{{#Q}}\n\u67e5\u8a62\uff1a{{Q}} {{/Q}}" },
  { u8"magnet-alt-text", u8"\u900f\u904e\u78c1\u529b\u9023\u7d50\u4e0b\u8f09" },
  { u8"magnet-link-text", u8"Magnet \u9023\u7d50" },
  { u8"name", u8"\u7e41\u9ad4\u4e2d\u6587" },
  { u8"new-404-page-heading", u8"\u54ce\u5440\uff0c\u627e\u4e0d\u5230\u9801\u9762\u3002" },
  { u8"new-404-page-title", u8"\u627e\u4e0d\u5230\u9801\u9762" },
  { u8"no-book-found", u8"\u6c92\u6709\u66f8\u7c4d\u7b26\u5408\u9078\u64c7\u6a19\u6e96" },
  { u8"no-query", u8"\u672a\u63d0\u4f9b\u67e5\u8a62\u3002" },
  { u8"no-search-results", u8"\u5168\u6587\u641c\u5c0b\u5f15\u64ce\u4e0d\u9069\u7528\u6b64\u5167\u5bb9\u3002" },
  { u8"no-such-book", u8"\u6c92\u6709\u9019\u6a23\u7684\u66f8\u7c4d\uff1a{{BOOK_NAME}}" },
  { u8"no-value-for-arg", u8"\u6c92\u6709\u70ba\u5f15\u6578 {{ARGUMENT}} \u63d0\u4f9b\u5167\u5bb9" },
  { u8"path-was-not-found", u8"\u627e\u4e0d\u5230\u8acb\u6c42\u8def\u5f91\u3002" },
  { u8"powered-by-kiwix-html", u8"\u7531 <a href=\"https://kiwix.org\">Kiwix</a> \u63d0\u4f9b\u6280\u8853\u652f\u63f4" },
  { u8"preview-book", u8"\u9810\u89bd" },
  { u8"random-article-failure", u8"\u54ce\u5440\uff01\u96a8\u6a5f\u6311\u9078\u689d\u76ee\u5931\u6557 :(" },
  { u8"random-page-button-text", u8"\u524d\u5f80\u96a8\u6a5f\u9078\u53d6\u9801\u9762" },
  { u8"raw-entry-not-found", u8"\u627e\u4e0d\u5230{{DATATYPE}}\u9805\u76ee{{ENTRY}}" },
  { u8"search", u8"\u641c\u5c0b" },
  { u8"search-result-book-info", u8"\u4f86\u81ea{{BOOK_TITLE}}" },
  { u8"search-results-page-header", u8"<b>\u300c{{{SEARCH_PATTERN}}}\u300d</b>\u7684<b>\u7b2c{{START}}-{{END}}\u7b46</b>\u7d50\u679c\uff08\u5171<b>{{COUNT}}</b>\u7b46\uff09" },
  { u8"search-results-page-title", u8"\u641c\u5c0b\uff1a{{SEARCH_PATTERN}}" },
  { u8"searchbox-tooltip", u8"\u5728\u300c{{{BOOK_TITLE}}}\u300d\u641c\u5c0b" },
  { u8"stop-filtering-by-tag", u8"\u505c\u6b62\u4f9d\u6a19\u7c64\u300c{{{TAG}}}\u300d\u7be9\u9078" },
  { u8"suggest-full-text-search", u8"\u6b63\u5728\u5305\u542b\u300c{{{SEARCH_TERMS}}}\u300d\u2026" },
  { u8"suggest-search", u8"\u5efa\u7acb <a href=\"{{{SEARCH_URL}}}\">{{PATTERN}}</a> \u4f7f\u7528\u7684\u5168\u6587\u641c\u5c0b" },
  { u8"text-loading-content", u8"\u6b63\u5728\u8f09\u5165\u5167\u5bb9" },
  { u8"too-many-books", u8"\u8acb\u6c42\u592a\u591a\u500b\u66f8\u7c4d\uff08{{NB_BOOKS}}\uff09\uff0c\u4e0a\u9650\u662f {{LIMIT}} \u500b" },
  { u8"torrent-download-alt-text", u8"\u900f\u904e BitTorrent \u4e0b\u8f09" },
  { u8"torrent-download-link-text", u8"BitTorrent" },
  { u8"unknown-error", u8"\u4e0d\u660e\u932f\u8aa4" },
  { u8"url-not-found", u8"\u5728\u6b64\u4f3a\u670d\u5668\u4e0a\u627e\u4e0d\u5230\u8acb\u6c42\u7684 URL\u300c{{url}}\u300d\u3002" },
  { u8"welcome-page-overzealous-filter", u8"\u6c92\u6709\u7d50\u679c\u3002\u60a8\u60f3\u8981<a href=\"{{URL}}\">\u91cd\u65b0\u8a2d\u5b9a\u7be9\u9078</a>\u55ce\uff1f" },
  { u8"welcome-to-kiwix-server", u8"\u6b61\u8fce\u4f86\u5230 Kiwix \u4f3a\u670d\u5668" },
  { u8"word-count", u8"{{COUNT}}\u500b\u5b57" }
};


} // unnamed namespace

#define ARRAY_ELEMENT_COUNT(a) (sizeof(a)/sizeof(a[0]))

extern const I18nStringTable stringTables[] = {
  
    {
        u8"ar",
        ARRAY_ELEMENT_COUNT(string_table_for_ar),
        string_table_for_ar
    },
  
    {
        u8"bn",
        ARRAY_ELEMENT_COUNT(string_table_for_bn),
        string_table_for_bn
    },
  
    {
        u8"br",
        ARRAY_ELEMENT_COUNT(string_table_for_br),
        string_table_for_br
    },
  
    {
        u8"cs",
        ARRAY_ELEMENT_COUNT(string_table_for_cs),
        string_table_for_cs
    },
  
    {
        u8"dag",
        ARRAY_ELEMENT_COUNT(string_table_for_dag),
        string_table_for_dag
    },
  
    {
        u8"de",
        ARRAY_ELEMENT_COUNT(string_table_for_de),
        string_table_for_de
    },
  
    {
        u8"dga",
        ARRAY_ELEMENT_COUNT(string_table_for_dga),
        string_table_for_dga
    },
  
    {
        u8"el",
        ARRAY_ELEMENT_COUNT(string_table_for_el),
        string_table_for_el
    },
  
    {
        u8"en",
        ARRAY_ELEMENT_COUNT(string_table_for_en),
        string_table_for_en
    },
  
    {
        u8"es",
        ARRAY_ELEMENT_COUNT(string_table_for_es),
        string_table_for_es
    },
  
    {
        u8"fi",
        ARRAY_ELEMENT_COUNT(string_table_for_fi),
        string_table_for_fi
    },
  
    {
        u8"fr",
        ARRAY_ELEMENT_COUNT(string_table_for_fr),
        string_table_for_fr
    },
  
    {
        u8"ha",
        ARRAY_ELEMENT_COUNT(string_table_for_ha),
        string_table_for_ha
    },
  
    {
        u8"he",
        ARRAY_ELEMENT_COUNT(string_table_for_he),
        string_table_for_he
    },
  
    {
        u8"hi",
        ARRAY_ELEMENT_COUNT(string_table_for_hi),
        string_table_for_hi
    },
  
    {
        u8"hu",
        ARRAY_ELEMENT_COUNT(string_table_for_hu),
        string_table_for_hu
    },
  
    {
        u8"hy",
        ARRAY_ELEMENT_COUNT(string_table_for_hy),
        string_table_for_hy
    },
  
    {
        u8"ia",
        ARRAY_ELEMENT_COUNT(string_table_for_ia),
        string_table_for_ia
    },
  
    {
        u8"id",
        ARRAY_ELEMENT_COUNT(string_table_for_id),
        string_table_for_id
    },
  
    {
        u8"ig",
        ARRAY_ELEMENT_COUNT(string_table_for_ig),
        string_table_for_ig
    },
  
    {
        u8"it",
        ARRAY_ELEMENT_COUNT(string_table_for_it),
        string_table_for_it
    },
  
    {
        u8"ja",
        ARRAY_ELEMENT_COUNT(string_table_for_ja),
        string_table_for_ja
    },
  
    {
        u8"ko",
        ARRAY_ELEMENT_COUNT(string_table_for_ko),
        string_table_for_ko
    },
  
    {
        u8"ku_latn",
        ARRAY_ELEMENT_COUNT(string_table_for_ku_latn),
        string_table_for_ku_latn
    },
  
    {
        u8"lb",
        ARRAY_ELEMENT_COUNT(string_table_for_lb),
        string_table_for_lb
    },
  
    {
        u8"mk",
        ARRAY_ELEMENT_COUNT(string_table_for_mk),
        string_table_for_mk
    },
  
    {
        u8"ms",
        ARRAY_ELEMENT_COUNT(string_table_for_ms),
        string_table_for_ms
    },
  
    {
        u8"nb",
        ARRAY_ELEMENT_COUNT(string_table_for_nb),
        string_table_for_nb
    },
  
    {
        u8"nl",
        ARRAY_ELEMENT_COUNT(string_table_for_nl),
        string_table_for_nl
    },
  
    {
        u8"nqo",
        ARRAY_ELEMENT_COUNT(string_table_for_nqo),
        string_table_for_nqo
    },
  
    {
        u8"or",
        ARRAY_ELEMENT_COUNT(string_table_for_or),
        string_table_for_or
    },
  
    {
        u8"pl",
        ARRAY_ELEMENT_COUNT(string_table_for_pl),
        string_table_for_pl
    },
  
    {
        u8"pt_br",
        ARRAY_ELEMENT_COUNT(string_table_for_pt_br),
        string_table_for_pt_br
    },
  
    {
        u8"pt",
        ARRAY_ELEMENT_COUNT(string_table_for_pt),
        string_table_for_pt
    },
  
    {
        u8"ro",
        ARRAY_ELEMENT_COUNT(string_table_for_ro),
        string_table_for_ro
    },
  
    {
        u8"ru",
        ARRAY_ELEMENT_COUNT(string_table_for_ru),
        string_table_for_ru
    },
  
    {
        u8"sc",
        ARRAY_ELEMENT_COUNT(string_table_for_sc),
        string_table_for_sc
    },
  
    {
        u8"sk",
        ARRAY_ELEMENT_COUNT(string_table_for_sk),
        string_table_for_sk
    },
  
    {
        u8"skr_arab",
        ARRAY_ELEMENT_COUNT(string_table_for_skr_arab),
        string_table_for_skr_arab
    },
  
    {
        u8"sl",
        ARRAY_ELEMENT_COUNT(string_table_for_sl),
        string_table_for_sl
    },
  
    {
        u8"sq",
        ARRAY_ELEMENT_COUNT(string_table_for_sq),
        string_table_for_sq
    },
  
    {
        u8"sv",
        ARRAY_ELEMENT_COUNT(string_table_for_sv),
        string_table_for_sv
    },
  
    {
        u8"sw",
        ARRAY_ELEMENT_COUNT(string_table_for_sw),
        string_table_for_sw
    },
  
    {
        u8"te",
        ARRAY_ELEMENT_COUNT(string_table_for_te),
        string_table_for_te
    },
  
    {
        u8"test",
        ARRAY_ELEMENT_COUNT(string_table_for_test),
        string_table_for_test
    },
  
    {
        u8"tr",
        ARRAY_ELEMENT_COUNT(string_table_for_tr),
        string_table_for_tr
    },
  
    {
        u8"zh_hans",
        ARRAY_ELEMENT_COUNT(string_table_for_zh_hans),
        string_table_for_zh_hans
    },
  
    {
        u8"zh_hant",
        ARRAY_ELEMENT_COUNT(string_table_for_zh_hant),
        string_table_for_zh_hant
    }
};

extern const size_t langCount = 48;

} // namespace i18n
} // namespace kiwix
